#-----------------------------------------------------------------------------
# Enhydra Java Application Server
# Copyright 1997-2000 Lutris Technologies, Inc.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in
#    the documentation and/or other materials provided with the distribution.
# 3. All advertising materials mentioning features or use of this software
#    must display the following acknowledgement:
#      This product includes Enhydra software developed by Lutris
#      Technologies, Inc. and its contributors.
# 4. Neither the name of Lutris Technologies nor the names of its contributors
#    may be used to endorse or promote products derived from this software
#    without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
#-----------------------------------------------------------------------------
# $Id: config.mk,v 1.128.2.7 2000/04/14 21:23:47 josh Exp $
#-----------------------------------------------------------------------------

#
# **** BEFORE EDITING, READ THIS! THIS MEANS YOU ****
#  
# If you want to set variables local to your tree, create a file
#    config.local.mk
# and set the make variables there.  This way, you will not accidently
# check in the changes.
#
# The most common variables that you will need to override are:
# JDKDIR - the location of the JDK.
# JAVACCDIR - the location of the Sun JavaCC (Java Compiler Compiler).
# SWINGDIR - the location of the Sun Swing Set (JFC).  This is only necessary
#	if you are using a 1.1 JDK or you wish to use the Enhydra Debugger
#	under other servlet runners like Apache JServ.
#

#
# WARNING: Modify this version string and the constant in
#     modules/EnhydraAppManager/src/com/lutris/Enhydra.java
# when changing Enhydra versions.
#
# *WARNING*: read above notice before changing the version number.
#
ENHYDRA_VERSION = 3.0.1

#
# CVS information for making a source distribution.  This is only used by the
# make dist target.  One only need modify this if one is building a full
# enhydra distribution outside of Lutris.
#
#   ENHYDRA_CVS_REPOSITORY - The -d string
#   ENHYDRA_CVS_MODULE - The CVS module containing Enhydra.
#
ENHYDRA_CVS_REPOSITORY = naish:/u/cvs
ENHYDRA_CVS_MODULE = Projects/EnhydraOrg/Enhydra

#
# Override defined for since we are compiling the Enhydra tree rather
# than a app.
# NOTE:  Absolute paths to the class output directory and module class
# path components are used because long relative paths (lots of ../..)
# broke the NT compile of certain modules. Yea, don't know why, but
# using absolute paths fixed it.
#
RELEASE_NAME = enhydra
ENHYDRA_DIR = $(ROOT)/output/${RELEASE_NAME}${ENHYDRA_VERSION}
OUTPUT = $(ENHYDRA_DIR)

JOLTC = $(ENHYDRA_DIR)/bin/joltc
ifeq ($(JARNAME),)
    JARNAME = enhydra
endif
CLASS_OUTPUT = $(ABS_ROOT)/classes/$(JARNAME)
ENHYDRA_CLASSES = $(ABS_ROOT)/classes/enhydra

# Set to YES for apps, NO for Enhydra build.
ENHYDRA_CHECK = NO

# Only relevant for Enhydra build.
BUILD_CHECK = YES

#
# Scripts used in the build
#
EDIT_PATHS = ${ROOT}/build/scripts/edit-paths
COPY_FILE = ${ROOT}/build/scripts/copy-file

#
# Directories, etc.
#
DIST_OUTPUT = ${OUTPUT}/dist
DIST_BIN_OUTPUT = ${OUTPUT}/dist/bin

#
# Local override
#
ifeq ($(shell test -r $(ROOT)/config.local.mk && echo YES),YES)
    include $(ROOT)/config.local.mk
endif

#
# Internally to Lutris, we keep most Enhydra dependencies in a CVS
# repository.  We pick up the checked-out repository components here
# if they are available to ensure a correctly build binary distribution.
# This overrides the default settings in stdconf.mk.  Wish we could
# redistribute this stuff.
#
DEPEND_DIST_DIR = ${ABS_ROOT}/../../../Dist

ifeq (${SWINGDIR},)
    SWINGDIR=$(wildcard ${DEPEND_DIST_DIR}/Sun/Swing)
endif
ifeq (${JAVACCDIR},)
    JAVACCDIR=$(wildcard ${DEPEND_DIST_DIR}/Sun/JavaCC)
endif
ifeq (${JSSEDIR},)
    JSSEDIR=$(wildcard ${DEPEND_DIST_DIR}/Sun/JSSE)
endif
ifeq (${JBUILDER_DIR},)
    JBUILDER_DIR=$(wildcard ${DEPEND_DIST_DIR}/Borland/JBuilder)
endif
ifeq (${JBFOUNDATION_DIR},)
    JBFOUNDATION_DIR=$(wildcard ${DEPEND_DIST_DIR}/Borland/JBFoundation)
endif

#
# We point at the pre-install stdconf.mk to get around chicken & egg.
#
STDCONF=$(ROOT)/lib/make/stdconf.mk
include $(ROOT)/lib/make/stdrules.mk

#
# Must add all modules to the CLASSPATH so that javac can find them.
# Must be done after stdrules.mk to get ${PS}.
#
MODULES=${ABS_ROOT}/modules
ENHYDRA_CLASSPATH:=${MODULES}/HTTPClient/src${PS}${ENHYDRA_CLASSPATH}
ENHYDRA_CLASSPATH:=${MODULES}/HttpServerTest/src${PS}${ENHYDRA_CLASSPATH}
ENHYDRA_CLASSPATH:=${MODULES}/TestBed/src${PS}${ENHYDRA_CLASSPATH}
ENHYDRA_CLASSPATH:=${MODULES}/EnhydraAppManager/src${PS}${ENHYDRA_CLASSPATH}
ENHYDRA_CLASSPATH:=${MODULES}/Core/src${PS}${ENHYDRA_CLASSPATH}
ENHYDRA_CLASSPATH:=${MODULES}/DODS/src${PS}${ENHYDRA_CLASSPATH}
ENHYDRA_CLASSPATH:=${MODULES}/DODS${PS}${ENHYDRA_CLASSPATH}
ENHYDRA_CLASSPATH:=${MODULES}/DatabaseManager/src${PS}${ENHYDRA_CLASSPATH}
ENHYDRA_CLASSPATH:=${MODULES}/JDDI/src${PS}${ENHYDRA_CLASSPATH}
ENHYDRA_CLASSPATH:=${MODULES}/JTidy/src${PS}${ENHYDRA_CLASSPATH}
ENHYDRA_CLASSPATH:=${MODULES}/MultiServer/src${PS}${ENHYDRA_CLASSPATH}
ENHYDRA_CLASSPATH:=${MODULES}/MultiServerAdmin/src${PS}${ENHYDRA_CLASSPATH}
ENHYDRA_CLASSPATH:=${MODULES}/Xerces/src${PS}${ENHYDRA_CLASSPATH}
ENHYDRA_CLASSPATH:=${MODULES}/XMLC/src${PS}${ENHYDRA_CLASSPATH}
ENHYDRA_CLASSPATH:=${MODULES}/gnu.regexp/src${PS}${ENHYDRA_CLASSPATH}
ENHYDRA_CLASSPATH:=${MODULES}/NewApp/src${PS}${ENHYDRA_CLASSPATH}
ENHYDRA_CLASSPATH:=${MODULES}/Tomcat/src/share${PS}${ENHYDRA_CLASSPATH}
ENHYDRA_CLASSPATH:=${MODULES}/I18N/src${PS}${ENHYDRA_CLASSPATH}
ENHYDRA_CLASSPATH:=${MODULES}/ServletContainer/src${PS}${ENHYDRA_CLASSPATH}
ENHYDRA_CLASSPATH:=${JDKDIR}/lib/tools.jar${PS}${ENHYDRA_CLASSPATH}

