/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: HtmlString.java,v 1.7 2000/02/18 07:24:50 shawn Exp $
 *-----------------------------------------------------------------------------
 */





package com.lutris.html;

import java.lang.String;
import java.lang.StringBuffer;

/**
 * The <code>HtmlString</code> class contains a String and adds a
 * toHtml() method. It is intended to be used in Jolt presentations
 * and referenced through JoltFields. The presence of the toHtml()
 * method prevents the default behavour of HTML encoding
 * the string contents to take place.
 *
 * @author  Paul Morgan
 * @version 1.0 (File $Revision: 1.7 $)
 * @since   LBS1.8
 */
public
class HtmlString implements java.io.Serializable {
    /** The contained string. */
    private String value;

    /**
     * Allocates a new string that contains the same sequence of 
     * characters as the string argument. 
     *
     * @param   value   a <code>String</code>.
     */
    public HtmlString(String value) {
	this.value = value;
    }

    /**
     * Allocates a new <code>String</code> that contains the same sequence
     * characters contained in the string buffer argument. 
     *
     * @param   buffer   a <code>StringBuffer</code>.
     */
    public HtmlString(StringBuffer buffer) {
	this.value = buffer.toString();
    }

    /**
     * Returns the contained <code>String</code> object.
     */
    public String toString() {
	return this.value;
    }

    /**
     * Returns the contained <code>String</code> object.
     */
    public String toHtml() {
	return this.value;
    }
}
