/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: HtmlTable.java,v 1.8 2000/02/18 07:24:50 shawn Exp $
 *-----------------------------------------------------------------------------
 */





package com.lutris.html;

import java.util.Vector;
import java.util.Enumeration;

/**
 * This utility class is used to compose an HTML table.
 *
 * @see HtmlTableRow
 * @see HtmlTableDataCell
 * @see HtmlTableHeaderCell
 * @author Kyle Clark
 * @author Paul Morgan
 * @version 1.0 (File $Revision: 1.8 $)
 */
public class HtmlTable {

    private String caption = null;
    private int percentWidth = 0;
    private int borderWidth = -1;
    private int cellPadding = -1;
    private int cellSpacing = -1;
    private String bgColor = null;
    private String rules = null;
    private String frame = null;
    private Vector rows = new Vector();
    private Object thead = null;

    public HtmlTable()
    {
        this.caption = null;
    }

    public HtmlTable(String caption)
    {
        this.caption = caption;
    }

    public void setBorderWidth(int pixels)
    {
        this.borderWidth = pixels;
    }

    public void addRow(HtmlTableRow row)
    {
        rows.addElement(row);
    }

    public void addRow(String row)
    {
        rows.addElement(row);
    }

    public void setHeader(Object row)
    {
        thead = row;
    }

    public void setPercentWidth(int percent)
    {
        if (percent > 0 && percent <= 100)
            this.percentWidth = percent;
    }

    public void setCaption(String caption)
    {
        this.caption = caption;
    }

    public void setCellSpacing(int size)
    {
        if (size >= 0)
            cellSpacing = size;
    }

    public void setCellPadding(int size)
    {
        if (size >= 0)
            cellPadding = size;
    }

    public void setBackgroundColor(String bgColor)
    {
        this.bgColor = bgColor;
    }

    public void setFrame(String frame)
    {
        this.frame = frame;
    }

    public void setRules(String rules)
    {
        this.rules = rules;
    }

    public String toString()
    {
        StringBuffer html = new StringBuffer();

        html.append("<TABLE");
        if (borderWidth >= 0) 
            html.append(" BORDER=" + borderWidth);
        if (percentWidth > 0) 
            html.append(" WIDTH=" + percentWidth + "%");
        if (cellPadding >= 0) 
            html.append(" CELLPADDING=" + cellPadding);
        if (cellSpacing >= 0) 
            html.append(" CELLSPACING=" + cellSpacing);
        if (bgColor != null)
            html.append(" BGCOLOR=" + bgColor);
        if (rules != null)
            html.append(" RULES=" + rules);
        if (frame != null)
            html.append(" FRAME=" + frame);
        html.append(">\n");

        if (caption != null) {
            html.append("<CAPTION>");
            html.append(caption);
            html.append("</CAPTION>\n");
        }

        if (thead != null) {
            html.append("<THEAD>");
            html.append(thead.toString());
            html.append("</THEAD>\n");
        }
        
        Enumeration e = rows.elements();
        while (e.hasMoreElements()) {
            html.append(e.nextElement().toString());
        }
        html.append("</TABLE>\n");

        return html.toString();
    }
}
