/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: HtmlTableCell.java,v 1.9 2000/02/18 07:24:50 shawn Exp $
 *-----------------------------------------------------------------------------
 */





package com.lutris.html;

import java.util.Vector;
import java.util.Enumeration;

/**
 * This base class is extended to compose a particular type of cell
 * within a row within a HTML table. Normally the entire row will be
 * composed of either data or header cells.
 *
 * @see HtmlTable
 * @see HtmlTableRow
 * @see HtmlTableDataCell
 * @see HtmlTableHeaderCell
 * @author Kyle Clark
 * @author Paul Morgan
 * @version 1.0 (File $Revision: 1.9 $)
 */
public abstract class HtmlTableCell {

    public static final int ALIGN_LEFT = 1;
    public static final int ALIGN_CENTER = 2;
    public static final int ALIGN_RIGHT = 3;
    public static final int VALIGN_TOP = 1; 
    public static final int VALIGN_MIDDLE = 2;
    public static final int VALIGN_BOTTOM = 3;

    protected String caption;
    protected int rowSpan = 0;
    protected int colSpan = 0;
    protected String tdValue = null;
    protected String align = null;
    protected String valign = null;
    protected String bgColor = null;
    protected int percentWidth = 0;

    public HtmlTableCell(String tdValue)
    {
        this.tdValue = tdValue;
    }

    public HtmlTableCell(String tdValue, String defaultValue)
    {
	if (tdValue.equals("")) {
	    this.tdValue = defaultValue;
	} else {
	    this.tdValue = tdValue;
	}
    }

    public void setHorizontalAlignment(int alignment)
    {
        switch (alignment) {
        case ALIGN_CENTER:
            this.align = "CENTER";
            break;
        case ALIGN_RIGHT:
            this.align = "RIGHT";
            break;
        default:
            this.align = "LEFT";
            break;
        }
    }

    public void setVerticalAlignment(int alignment)
    {
        switch (alignment) {
        case VALIGN_TOP:
            this.valign = "TOP";
            break;
        case VALIGN_MIDDLE:
            this.valign = "MIDDLE";
            break;
        default:
            this.valign = "BOTTOM";
            break;
        }
    }

    public void setRowSpan(int rowSpan)
    {
        if (rowSpan > 0)
            this.rowSpan = rowSpan;
    }

    public void setColSpan(int colSpan)
    {
        if (colSpan > 0)
            this.colSpan = colSpan;
    }
    
    public void setValue(String tdValue)
    {
        this.tdValue = tdValue;
    }

    public void setBackgroundColor(String bgColor)
    {
        this.bgColor = bgColor;
    }

    public void setPercentWidth(int percent)
    {
        if (percent > 0 && percent <= 100)
            this.percentWidth = percent;
    }
}
