/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: HtmlTableDataCell.java,v 1.8 2000/02/18 07:24:50 shawn Exp $
 *-----------------------------------------------------------------------------
 */





package com.lutris.html;

import java.util.Vector;
import java.util.Enumeration;

/**
 * This utility class is used to compose an data cell within a
 * row within a HTML table. Normally the entire row will be
 * composed of either data or header cells.
 *
 * @see HtmlTable
 * @see HtmlTableRow
 * @see HtmlTableHeaderCell
 * @author Kyle Clark
 * @author Paul Morgan
 * @version 1.0 (File $Revision: 1.8 $)
 */
public class HtmlTableDataCell extends HtmlTableCell {

    public HtmlTableDataCell(String tdValue)
    {
	super(tdValue);
    }

    public HtmlTableDataCell(String tdValue, String defaultValue)
    {
	super(tdValue, defaultValue);
    }

    public String toString()
    {
        String html = "<TD";
        if (align != null)
            html += " ALIGN=" + align;
        if (valign != null)
            html += " VALIGN=" + valign;
        if (rowSpan > 0)
            html += " ROWSPAN=" + rowSpan;
        if (colSpan > 0)
            html += " COLSPAN=" + colSpan;
        if (bgColor != null)
            html += " BGCOLOR=" + bgColor;
        if (percentWidth > 0) 
            html += " WIDTH=" + percentWidth + "%";
        html += ">";
	html += tdValue;
        html += "</TD>\n";
        return html;
    }
}
