/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: HttpStatus.java,v 1.12 2000/02/18 07:24:50 shawn Exp $
 *-----------------------------------------------------------------------------
 */





package com.lutris.http;

public class HttpStatus {

    // Informational
    public final static int doContinue = 100;
    public final static int switchingProtocols = 101;

    // Success
    public final static int ok = 200;
    public final static int created = 201;
    public final static int accepted = 202;
    public final static int nonAuthoritativeInformation = 203;
    public final static int noContent = 204;
    public final static int resetContent = 205;
    public final static int partialContent = 206;

    // Redirection
    public final static int multipleChoices = 300;
    public final static int movedPermanently = 301;
    public final static int movedTemporarily = 302;
    public final static int seeOther = 303;
    public final static int notModified = 304;
    public final static int useProxy = 305;

    // Client error
    public final static int badRequest = 400;
    public final static int unauthorized = 401;
    public final static int paymentRequired = 402;
    public final static int forbidden = 403;
    public final static int notFound = 404;
    public final static int methodNotAllowed = 405;
    public final static int notAcceptable = 406;
    public final static int proxyAuthenticationRequired = 407;
    public final static int requestTimeout = 408;
    public final static int conflict = 409;
    public final static int gone = 410;
    public final static int lenghtRequired = 411;
    public final static int preconditionFailed = 412;
    public final static int requestEntityTooLarge = 413;
    public final static int requestUriTooLarge = 414;
    public final static int unsupportedMediaType = 415;

    // Server error
    public final static int internalServerError = 500;
    public final static int notImplemented = 501;
    public final static int badGateway = 502;
    public final static int serviceUnavailable = 503;
    public final static int gatewayTimeout = 504;
    public final static int httpVersionNotSupported = 505;

    /*
     * Table of default messages.  First dimension is indexed by
     * (code / 100) - 1 and second diminsion by the remainder, with
     * the last element of each class being a default value if
     * the status code is past the end.
     */
    private static final String[][] statusMsgs = {
        {
            /* 100 */  "Continue",
            /* 101 */  "Switching Protocols",
            /* 1xx */  "Informational",
        }, {
            /* 200 */  "OK",
            /* 201 */  "Created",
            /* 202 */  "Accepted",
            /* 203 */  "Non-Authoritative Information",
            /* 204 */  "No Content",
            /* 205 */  "Reset Content",
            /* 206 */  "Partial Content",
            /* 2xx */  "Success",
        }, {
            /* 300 */  "Multiple Choices",
            /* 301 */  "Moved Permanently",
            /* 302 */  "Moved Temporarily",
            /* 303 */  "See Other",
            /* 304 */  "Not Modified",
            /* 305 */  "Use Proxy",
            /* 3xx */  "Redirection",
        }, {
            /* 400 */  "Bad Request",
            /* 401 */  "Unauthorized",
            /* 402 */  "Payment Required",
            /* 403 */  "Forbidden",
            /* 404 */  "Not Found",
            /* 405 */  "Method Not Allowed",
            /* 406 */  "Not Acceptable",
            /* 407 */  "Proxy Authentication Required",
            /* 408 */  "Request Time-out",
            /* 409 */  "Conflict",
            /* 410 */  "Gone",
            /* 411 */  "Length Required",
            /* 412 */  "Precondition Failed",
            /* 413 */  "Request Entity Too Large",
            /* 414 */  "Request-URI Too Large",
            /* 415 */  "Unsupported Media Type",
            /* 4xx */  "Client Error",
        }, {
            /* 500 */  "Internal Server Error",
            /* 501 */  "Not Implemented",
            /* 502 */  "Bad Gateway",
            /* 503 */  "Service Unavailable",
            /* 504 */  "Gateway Time-out",
            /* 505 */  "HTTP Version not supported",
            /* 5xx */  "Server Error",
        }
    };

    /**
     * Get the default status message for a HTTP status code.
     */
    public static String getStatusMsg(int statusCode) {
        int codeSet = (statusCode / 100);
        int setIdx = statusCode - (codeSet * 100);
        if ((codeSet <= 0) || (codeSet > statusMsgs.length)) {
            return "Invalid status code";
        }
        if (setIdx >= statusMsgs[codeSet-1].length) {
            setIdx = statusMsgs[codeSet-1].length - 1;
        }
        return statusMsgs[codeSet-1][setIdx];
    }
}
