/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: CookieParserTests.java,v 1.8 2000/02/18 07:24:51 shawn Exp $
 *-----------------------------------------------------------------------------
 */




package com.lutris.http.tests;
import com.lutris.http.*;
import java.util.*;
import javax.servlet.http.*;

/**
 * Simple tests for cookie parser.
 *
 * @author Kyle Clark
 */
public class CookieParserTests
{
    /**
     * Where to print test results.
     */
    java.io.PrintStream out;

    /**
     * Constructor.
     */
    public CookieParserTests()
    {
        out = System.out;
        out.println("com.lutris.http.HttpCookieParser");
    }

    /**
     * Main entry point which executes all the tests.
     *
     * @param args
     *   Command line arguments.
     */
    public static void main(String [] args)
        throws Exception
    {
        CookieParserTests parserTests = new CookieParserTests();

        parserTests.testRequest("Test 1 (Request Header)",
                         "firstName=Kyle; lastName=Clark");

        parserTests.testResponse("Test 2 (Response Header)",
                         "firstName=Kyle, lastName=Clark");

        parserTests.testResponse("Test 3 (Response Header)",
                         "firstName=Kyle; " +
                         "path=/bogus/tmp; domain=lutris.com, " +
                         "lastName=Clark");

        parserTests.testResponse("Test 4 (Response Header)",
                         "firstName=Kyle; " +
                         "path=/bogus/tmp; domain=lutris.com; " +
                         "bogus=junk, " +
                         "lastName=Clark");

        parserTests.testResponse("Test 5 (Mixed header)",
                         "firstName=Kyle, " +
                         "path=/bogus/tmp; domain=lutris.com, " +
                         "bogus=junk; " +
                         "lastName=Clark");

    }

    public void testRequest(String testName, String header)
    {
        out.println();
        printTestName(testName);
        out.println("= Request Header  = ");
        out.println("    " + header);
        out.println("= Results = ");
        printResults(HttpCookieParser.parseRequestHeader(header));
        out.println();
    }

    public void testResponse(String testName, String header)
    {
        out.println();
        printTestName(testName);
        out.println("= Response Header  = ");
        out.println("    " + header);
        out.println("= Results = ");
        printResults(HttpCookieParser.parseResponseHeader(header));
        out.println();
    }

    private void printTestName(String s)
    {
        out.println();
        out.println("========== " + s + " ==========");
    }
        
    private void printResults(Vector v)
    {
        int i=0;
        Enumeration e = v.elements();
        while (e.hasMoreElements()) {
            i++;
            Cookie c = (Cookie)e.nextElement();
            out.println("    " + i + ") " + c);
        }
    }
}
