/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: ContentHeader.java,v 1.7 2000/02/18 07:24:52 shawn Exp $
 *-----------------------------------------------------------------------------
 */




package com.lutris.mime;

/**
 * Parses and represents Mime header fields that have the form of the
 * <code>Content-Type</code> header as defined in RFC2045 Section 5.1
 * Page 11.  The format of these headers is informally:
 * <PRE>
 * 	<Header-Type>: <value> [ ; <parameter> ... ]
 * </PRE>
 * Examples:
 * <PRE>
 * 	Content-Type: application/octet-stream
 * 	Content-Type: multipart/form-data; boundary="---123456"
 * 	Content-Disposition: form-data; name=upload; filename="/tmp/myfile"
 * </PRE>
 * In addition to the actual header syntax, RFC822 header comments are
 * allowed.  Such comments consist of text enclosed in parentheses.
 */
public class ContentHeader extends MimeHeader 
{
    /**
     * Constructs a new ContentTypeHeader object from an unparsed Mime 
     * <code>Content-Type</code> header line.  The header line should
     * include the <i>entire</i> line as read from the input source.
     * 
     * @param	headerLine	The entire line containing the Mime header.
     */
    public
    ContentHeader(String headerLine)
    {
	super(headerLine);
	int pos = headerLine.indexOf(';');
	if (pos >= 0) parseParameters(headerLine.substring(pos+1));
    }

    /**
     * Constructs a new ContentTypeHeader object from an existing
     * <code>MimeHeader</code> object.
     * 
     * @param	hdr		An existing <code>MimeHeader</code> object.
     */
    public
    ContentHeader(MimeHeader hdr)
    {
	super(hdr.getRawHeaderLine());
	String headerLine = hdr.getRawHeaderLine();
	int pos = headerLine.indexOf(';');
	if (pos >= 0) parseParameters(headerLine.substring(pos+1));
    }
}
