/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: MimeException.java,v 1.8 2000/02/18 07:24:52 shawn Exp $
 *-----------------------------------------------------------------------------
 */




package	com.lutris.mime;

/**
 * Public exception class to indicate an error in Mime data.
 * This is never thrown by <code>MultiparMimeInputStream</code> since
 * that class needs to look exactly like an <code>InputStream</code>.
 */
public class MimeException extends Exception
{
    /**
     * Indicates a general error in parsing Mime data.
     */
    public static final int	GENERIC = 0;
    
    /**
     * Indicates incorrect Mime header syntax or illegal parameters.
     */
    public static final int	INVALID_HEADER = 1;
    
    /**
     * Indicates an illegal Mime type for a particular operation.  For
     * example, this code is generated if an attempt is made to create
     * a <code>MultipartMimeInput</code> object with a Mime type other than
     * <b>multipart/*</b>.
     */
    public static final int	INVALID_MIME_TYPE = 2;
    
    /**
     * Holds the reason code for this exception instance.
     */
    public int			reason = GENERIC;

    /**
     * Creates a MimeException object with informational string
     * <code>s</code> and reason code <code>reason</code>.
     * 
     * @param s			Informational string.
     * @param reason		Reason code.
     */
    MimeException(String s, int reason)
    {
	super(s);
	this.reason = reason;
    }

    /**
     * Creates a MimeException object with informational string
     * <code>s</code> and the default reason code, <code>GENERIC</code>.
     * 
     * @param s			Informational string.
     */
    MimeException(String s)
    {
	super(s);
	reason = GENERIC;
    }
    
    /**
     * Creates a MimeException object with informational string
     * <code>s</code> and the default reason code, <code>GENERIC</code>.
     * 
     * @param s			Informational string.
     */
    MimeException()
    {
	super();
	reason = GENERIC;
    }
}
