/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: Sorter.java,v 1.11 2000/02/18 07:24:53 shawn Exp $
 *-----------------------------------------------------------------------------
 */

package com.lutris.testutil;

/*
 * Interface for ObjSort comparsions.
 */
interface Comparer {
    int compare(Object obj1, Object obj2);
}

/*
 * Generic sorting class.
 */
class ObjSort {
    /*
     * Sort object array.
     */
    public Object[] sort(Object[] objs,
                         Comparer comparer) {
        Object[] result = (Object[])objs.clone ();
        boolean sorted;

        do {
            sorted = true;
            for (int idx = 0; idx < objs.length - 1; idx++) {
                if (comparer.compare(result[idx],
                                     result[idx + 1]) > 0) {
                    Object tmp = result[idx];
                    result[idx] = result[idx + 1];
                    result[idx + 1] = tmp;
                    sorted = false;
                }
            }
        } while (!sorted);

        return result;
    }
}

/**
 * Result sorter.
 *
 * @version	$Revision: 1.11 $
 * @author	Mark Diekhans
 * @since	Jolt1.0
 */
public class Sorter {
    /**
     * Sort a string array in assending order.
     */
    public static String[] sort(String[] strings) {
        return (String[])new ObjSort().sort(strings,
            new Comparer() {
                public int compare(Object obj1, Object obj2) {
                    return ((String) obj1).compareTo((String)obj2);
                }
            });
    }

    /**
     * Sort a Float array in assending order.
     */
    public static Float[] sort(Float[] nums) {
        return (Float[]) new ObjSort().sort(nums,
            new Comparer() {
                public int compare(Object obj1, Object obj2) {
                    float num1 = ((Float)obj1).floatValue();
                    float num2 = ((Float)obj2).floatValue();
                    if (num1 < num2) {
                        return -1;
                    } else if (num1 > num2) {
                        return 1;
                    } else {
                        return 0;
                    }
                }
            });
    }
}
