/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: BytesToString.java,v 1.9 2000/02/18 07:24:54 shawn Exp $
 *-----------------------------------------------------------------------------
 */





package com.lutris.util;

/**
	This class has static methods which convert arrays of bytes to
	a strings. It remaps non-ascii bytes to ".". One use for this class is
	to convert raw data read in from a file or the net to a human-readable
	form, probably for debugging.

	@author Andy John
*/
public class BytesToString {

	/**
		Converts the array of bytes to a string. Non-ascii characters
		are converted to ".".

		@param b The array of bytes to convert.
		@return The bytes converted into a string.
	*/	
	public static String conv(byte[] b) {
		return conv(b, b.length);
	}


	/**
		Converts the array of bytes to a string. Non-ascii characters
		are converted to ".". Only the first len bytes are used.

		@param b The array of bytes to convert.
		@param len Only uses bytes b[0]..b[len-1].
		@return The bytes converted into a string.
	*/
	public static String conv(byte[] b, int len) {
		byte[] c = new byte[len];
		for(int i=0; i<len; i++) {
			byte n = b[i];
			if ((n < 32) || (n > 128))
				n = 65;
			c[i] = n;
		}
		return new String(c);
	}
}
	
