/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: ChainedThrowableUtil.java,v 1.2 2000/03/03 07:57:17 markd Exp $
 *-----------------------------------------------------------------------------
 */

package com.lutris.util;

import java.io.*;

/**
 * Utilities used to implement the Chained* throwables.
 */
class ChainedThrowableUtil {
    /**
     * Can't makes instances.
     */
    private ChainedThrowableUtil() {
    }

    /**
     * Generate the message to set for the exception message.
     * When not explicit message is supplied.
     */
    protected static String makeMessage(Throwable cause) {
        String causeMsg = cause.getMessage();
        if (causeMsg == null) {
            return cause.getClass().getName();
        } else {
            return causeMsg;
        }
    }
    

    /**
     * Get the message associated with this exception.
     */
    protected static String getMessage(ChainedThrowable except,
                                       String superMsg) {
        Throwable cause = except.getCause();
        if (cause == null) {
            return superMsg;
        } else {
            String causeMsg = cause.getMessage();
            if ((causeMsg == null) || (causeMsg.length() == 0)) {
                causeMsg = cause.getClass().getName();
            }
            return superMsg + ": " + causeMsg;
        }
    }

    /**
     * Prints stacktrace and cause stacktrace.
     */
    protected static void printCauseTrace(ChainedThrowable except) {
        PrintWriter pw = new PrintWriter(System.err);
        printCauseTrace(except, pw);
    }

    /**
     * Prints stacktrace and cause stacktrace.
     */
    protected static void printCauseTrace(ChainedThrowable except,
                                          PrintStream s) {
        PrintWriter pw = new PrintWriter(s);
        printCauseTrace(except, pw);
    }

    /**
     * Prints stacktrace and cause stacktrace.
     */
    public static void printCauseTrace(ChainedThrowable except,
                                       PrintWriter s) {
        Throwable cause = except.getCause();
        if (cause != null) {
            s.println("*** Caused by:");
            cause.printStackTrace(s);
        }
        s.flush();
    }
}
