/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-1999 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: HexEncoder.java,v 1.2 2000/02/18 07:24:56 shawn Exp $
 *-----------------------------------------------------------------------------
 */

package	com.lutris.util;
import	java.io.*;
import	java.text.*;

/**
 * Various conversion methods.
 * These methods are mostly used to convert internal java data
 * fields into byte arrays or strings for use in 8 bit ASCII fields.
 *
 * @author Mike Ward
 */
public class HexEncoder {
    /**
     * Hexadecimal characters corresponding to each half byte value.
     */
    private static final char[] HexChars = {
	'0', '1', '2', '3', '4', '5', '6', '7',
	'8', '9', 'a', 'b', 'c', 'd', 'e', 'f'
    };

    /**
     * Converts a long integer to an unsigned hexadecimal String.  Treats
     * the integer as an unsigned 64 bit value and left-pads with the
     * pad character of the caller's choice.
     * 
     * @param value The long integer to convert to a hexadecimal string.
     * @param len   The total padded length of the string.  If the number
     * 		    is larger than the padded length, then this length
     * 		    of the string will be the length of the number.
     * @param pad   The character to use for padding.
     * @return	    Unsigned hexadecimal numeric string representing 
     * 		    the specified value.
     */
    public static final String toHexString(long value, int len, char pad) {
	StringBuffer sb = new StringBuffer(Long.toHexString(value));
	int npad = len - sb.length();
	while (npad-- > 0) sb.insert(0, pad);
	return new String(sb);
    }

    /**
     * Converts an arbitrary array of bytes to ASCII hexadecimal string
     * form, with two hex characters corresponding to each byte.  The
     * length of the resultant string in characters will be twice the
     * length of the specified array of bytes.
     * 
     * @param bytes The array of bytes to convert to ASCII hex form.
     * @return	    An ASCII hexadecimal numeric string representing the
     * 		    specified array of bytes.
     */
    public static final String toHexString(byte[] bytes) {
	StringBuffer sb = new StringBuffer();
	int i;
	for (i=0; i < bytes.length; i++) {
	    sb.append(HexChars[(bytes[i] >> 4) & 0xf]);
	    sb.append(HexChars[bytes[i] & 0xf]);
	}
	return new String(sb);
    }
}


