/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: PersistentStore.java,v 1.8 2000/02/18 07:24:57 shawn Exp $
 *-----------------------------------------------------------------------------
 */





package com.lutris.util;
import java.io.*;
import java.util.*;

/**
 * Persitent storage interface.
 *
 * @author Kyle Clark
 */
public interface PersistentStore {

    /**
     * Method to store and object (persistent).
     *
     * @param key The key by which to identify the stored object.
     * @param obj The serializable object to store.
     * @exception com.lutris.util.PersistentStoreException
     *   if an error occurs.
     */
    public void store(String key, Serializable obj)
        throws com.lutris.util.PersistentStoreException;

    /**
     * Method to retrieve a stored object.
     *
     * @param key The key of the user whose session
     *   is to be retreived.
     * @return The stored object.  If an object is not
     *   stored under key, then <code>null</code> is returned.
     * @see #remove
     * @exception com.lutris.util.PersistentStoreException
     *   if an error occurs.
     */
    public Object retrieve(String key)
        throws com.lutris.util.PersistentStoreException;

    /**
     * Method to simultaneously retrieve and remove an
     * object from persistent store.  If an object is not
     * stored under key, then null is returned.
     *
     * @param key The key by which to identify the stored object
     *   that is to be removed.
     * @return The object that has been removed.
     * @exception com.lutris.util.PersistentStoreException
     *   if an error occurs.
     */
    public Object remove(String key)
        throws com.lutris.util.PersistentStoreException;

    /**
     * Method to delete a a key.  Any objects stored under
     * key are also removed.  If key is not defined, then
     * this method does nothing.
     *
     * @param key
     *   The key to remove.
     * @exception com.lutris.util.PersistentStoreException
     *   if an error occurs.
     */
    public void delete(String key)
        throws com.lutris.util.PersistentStoreException;


    /**
     * Method to query if an an object is stored.
     *
     * @param key The key by which to identify the stored object.
     * @exception com.lutris.util.PersistentStoreException
     *   if an error occurs.
     */
    public boolean exists(String key)
        throws com.lutris.util.PersistentStoreException;


    /**
     * Method that returns an enumration of the keys
     * of this persistent store.
     *
     * @exception com.lutris.util.PersistentStoreException
     *   if the enumeration could not be determined.
     */
    public java.util.Enumeration keys()
        throws com.lutris.util.PersistentStoreException;


}

