/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: FilePersistentStoreTests.java,v 1.9 2000/02/18 07:24:57 shawn Exp $
 *-----------------------------------------------------------------------------
 */





package com.lutris.util.tests;
import com.lutris.util.*;
import java.io.*;

/**
 * Class that tests the FilePersistentStore object.
 * TODO: more robust tests are needed.
 *
 * @author Kyle Clark
 */
public class FilePersistentStoreTests {

    private static final String INTEGER_KEY = "Integer Key !@#$%^&*()_++_";
    private static final String KEYWORD_VALUE_KEY = "KeywordValue";
    private static FilePersistentStore file;

    static void testInteger()
        throws Exception
    {
        Integer i = new Integer(4);
        file.delete(INTEGER_KEY);
        file.store(INTEGER_KEY, i);
        if (file.exists(INTEGER_KEY))
            System.out.println("Integer object was successfully archived.");
        System.out.println(i);
        i = (Integer)file.retrieve(INTEGER_KEY);
        System.out.println(i);
    }

    static void testKeywordValueTable()
        throws Exception
    {
        KeywordValueTable kv = new KeywordValueTable();
        kv.set("Integer4", new Integer(4));
        kv.set("Integer8", new Integer(8));
        // kv.set("KeywordValue", kv);  this will fail miserably and it should
        file.delete(KEYWORD_VALUE_KEY);
        file.store(KEYWORD_VALUE_KEY, kv);
        if (file.exists(KEYWORD_VALUE_KEY))
            System.out.println("KeywordValue object was successfully archived.");
        System.out.println(kv);
        kv = (KeywordValueTable)file.retrieve(KEYWORD_VALUE_KEY);
        System.out.println(kv);
    }

    public static void runTests()
        throws Exception
    {
        file = new FilePersistentStore();
        testInteger();
        testKeywordValueTable();
        java.util.Enumeration e = file.keys();
        System.out.println("Keys:");
        while(e.hasMoreElements()) {
            String k = (String)e.nextElement();
            System.out.println("\t" + k);
            file.delete(k);
        }

    }

    public static void main (String [] args)
        throws Exception
    {
        runTests();
    }
}
