/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: SourceGenerator_DataStruct.java,v 1.3 2000/01/29 07:01:36 markd Exp $
 *-----------------------------------------------------------------------------
 */




package com.lutris.dods.builder.generator.datastruct;

import com.lutris.dods.store.doa.DataObject;
import com.lutris.dods.store.doa.Attribute;
import com.lutris.dods.store.doa.DODSProject;

import com.lutris.dods.builder.engine.*;
import com.lutris.dods.builder.generator.base.*;

import java.io.File;
import java.io.StringWriter;

public class SourceGenerator_DataStruct extends SourceGenerator {

    final String CLONING_ASSIGNMENTS = "CLONING_ASSIGNMENTS";
    final String CLONE_VALUE         = "CLONE_VALUE";
    final String BEGIN_CONSTANT      = "BEGIN_CONSTANT";
    final String END_CONSTANT        = "END_CONSTANT";

    private TemplateFilter filterCloningAssignments;
    private StringWriter   CloningAssignments;

    public SourceGenerator_DataStruct() throws Exception {
    }

   /**
     * Adds tag values to the <CODE>TagSet</CODE>.
     * This method invokes 
     *    <CODE>TemplateFilter.process( tagSet )</CODE>
     * which will create the output source file.
     *
     * @param o
     *   DataObject for which source code will be generated by
     *    <CODE>writeFileHeader</CODE> and
     *    <CODE>writeFileFooter</CODE>
     * @exception Exception
     *   If an unrecoverable error occurs.
     *
     */
    public void objectPrep(	GeneratorInfo sgi,
				DODSProject project,
				DataObject o )
    throws Exception {
	super.objectPrep( sgi, project, o );
	TemplateReader reader = new TemplateReader(
	     info.templateDir + File.separator + "cloning.template" );
	CloningAssignments = new StringWriter();
	filterCloningAssignments = new TemplateFilter(
					reader, CloningAssignments );

    }

    public void memberPrep(	Attribute a ) throws Exception {
	super.memberPrep( a );
	String name = a.getName();

	// set the CLONE_VALUE tag
		// boolean, byte, short, int, long, float, double
		// String
		// java.sql.Date, java.sql.Time, java.sql.Timestamp
		// byte[]
		// java.math.BigDecimal
		// 
	String tagValue = null;
	String primitiveTypes = 
		":boolean:char:byte:short:int:long:float:double:";
	String timeTypes = 
		":java.sql.Date:java.sql.Time:java.sql.Timestamp:";
	String type  = a.getJavaType();
	if ( -1 != primitiveTypes.indexOf( ":" + type + ":" ) ) {
	    tagValue = name;
	} else if ( -1 != timeTypes.indexOf( ":" + type + ":" ) ) {
	    tagValue = "new " + type + "(" + name + ".getTime() )";
	} else if ( type.equals( "String" ) ) {
	    tagValue = name + " + \"\"";
	} else if ( type.equals( "byte[]" ) ) {
	    tagValue =  "copyByteArray(" + name + ")";
	} else if ( type.equals( "java.math.BigDecimal" ) ) {
	    tagValue =  "new java.math.BigDecimal(" + name + ".toString())";
	} else {
	    if ( a.isObjectRef() )
		tagValue = type + ".createCopy( " + name + " )";
	    else
		// assume data type is of a cloneable class
		tagValue = "(" + type + ") " + name + ".clone()";
	}
	tagSet.setTagValue( CLONE_VALUE, tagValue );
	tagSet.setTagValue( BEGIN_CONSTANT, 
		a.isConstant() ? TemplateFilter.skipStart : "" );
	tagSet.setTagValue( END_CONSTANT,
		a.isConstant() ? TemplateFilter.skipStop : "" );
    }

    public void writeFileHeader(  DataObject o ) throws Exception {
	defaultWriteFileHeader( o );
    }

    public void writeMemberStuff( Attribute  a ) throws Exception {
	defaultWriteMemberStuff( a );
	filterCloningAssignments.reset();
	filterCloningAssignments.process( tagSet );
    }

    public void writeFileFooter(  DataObject o ) throws Exception {
	if ( null != CloningAssignments )
	    tagSet.setTagValue( CLONING_ASSIGNMENTS,
		CloningAssignments.toString() );
	defaultWriteFileFooter( o );
	filterCloningAssignments.close();
    }
}
