/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: DataObjectException.java,v 1.3 2000/01/29 07:01:37 markd Exp $
 *-----------------------------------------------------------------------------
 */
package com.lutris.dods.builder.generator.query;
import com.lutris.util.ChainedException;

/**
 * DataObjectException class, used by Business Objects, catch all the 
 * DataObject Exceptions, will be passed to POs and handled there. 
 * Need to state the reasons.<p>
 * <b>Usage:</b><p>
 * <dd> import myapp.business.*;<p>
 *
 * <dd>	try {<br>
 * <dd>	some access of DOs<br>
 * <dd>	}<br>
 * <dd>     catch (SQLException sqlEx) {
 * <dd>        if (sqlEx.getSQLState().startsWith("02") &&
 * <dd>           (sqlEx.getErrorCode() == 100)) {
 * <dd>           String msg = "Update or delete DO is out of synch";
 * <dd>           throw new DataObjectException(msg, sqlEx);
 * <dd>        }
 * <dd>        else if (sqlEx.getSQLState().equals("S1000") &&
 * <dd>           (sqlEx.getErrorCode() == -268)) {
 * <dd>           String msg = "Integrity constraint violation";
 * <dd>           throw new DataObjectException(msg, sqlEx);
 * <dd>        }
 * <dd>        else {
 * <dd>            String msg = "Data Object Error";
 * <dd>           throw new DataObjectException(msg, sqlEx);
 * <dd>        }
 * <dd>     }
 * <dd>     catch (DatabaseManagerException connEx) {
 * <dd>        String msg = "Database connection Error";
 * <dd>        throw new DataObjectException(msg, connEx);
 * <dd>     }
 * <dd>     catch (ObjectIdException oidEx) {
 * <dd>        String msg = "Object ID Error";
 * <dd>        throw new DataObjectException(msg, oidEx);
 * <dd>     }
 *
 * @version	$Revision: 1.3 $
 */
public class DataObjectException extends ChainedException {

    /**
     * Construct a exception without a specified cause.
     *
     * @param msg The message associated with the exception.
     */
    public DataObjectException(String msg) {
	super(msg);
    }

    /**
     * Construct a exception with an associated causing exception.
     *
     * @param msg The message associated with the exception.
     * @param cause The error or exception that cause this
     *  exception.
     */
    public DataObjectException(String msg,
                               Throwable cause) {
        super(msg, cause);
    }
}
