/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: SourceGenerator_Query.java,v 1.3 2000/01/29 07:01:38 markd Exp $
 *-----------------------------------------------------------------------------
 */




package com.lutris.dods.builder.generator.query;

import com.lutris.dods.store.doa.DataObject;
import com.lutris.dods.store.doa.Attribute;
import com.lutris.dods.store.doa.DODSProject;

import com.lutris.dods.builder.engine.*;
import com.lutris.dods.builder.generator.base.*;

import java.io.File;
import java.io.StringWriter;
import java.util.Vector;

public class SourceGenerator_Query extends SourceGenerator {

    final String NULL_FLAG		= "NULL_FLAG";
    final String CAN_QUERY		= "CAN_QUERY";
    final String BEGIN_TYPE_DO		= "BEGIN_TYPE_DO";
    final String END_TYPE_DO		= "END_TYPE_DO";
    final String BEGIN_TYPE_STRING	= "BEGIN_TYPE_STRING";
    final String END_TYPE_STRING	= "END_TYPE_STRING";
    final String BEGIN_TYPE_BIGDECIMAL	= "BEGIN_TYPE_BIGDECIMAL";
    final String END_TYPE_BIGDECIMAL	= "END_TYPE_BIGDECIMAL";
    final String BEGIN_TYPE_DATE	= "BEGIN_TYPE_DATE";
    final String END_TYPE_DATE		= "END_TYPE_DATE";
    final String BEGIN_TYPE_BYTEARRAY	= "BEGIN_TYPE_BYTEARRAY";
    final String END_TYPE_BYTEARRAY	= "END_TYPE_BYTEARRAY";
    final String BEGIN_TYPE_PRIMITIVE	= "BEGIN_TYPE_PRIMITIVE";
    final String END_TYPE_PRIMITIVE	= "END_TYPE_PRIMITIVE";
    final String QUERY_COLUMN_NAMES	= "QUERY_COLUMN_NAMES";
    final String QUERY_OID_AND_VERSION	= "QUERY_OID_AND_VERSION";

    public SourceGenerator_Query() throws Exception {
    }

   /**
     * Adds tag values to the <CODE>TagSet</CODE>.
     * This method invokes
     *    <CODE>TemplateFilter.process( tagSet )</CODE>
     * which will create the output source file.
     *
     * @param o
     *   DataObject for which source code will be generated by
     *    <CODE>writeFileHeader</CODE> and
     *    <CODE>writeFileFooter</CODE>
     * @exception Exception
     *   If an unrecoverable error occurs.
     *
     */
    public void objectPrep(	GeneratorInfo sgi,
				DODSProject project,
				DataObject o )
    throws Exception {
	super.objectPrep( sgi, project, o );
    }

    public void memberPrep(	Attribute a ) throws Exception {
	if ( ! a.isUsedForQuery() ) return;
	super.memberPrep( a );
	tagSet.setTagValue( NULL_FLAG,
		a.canBeNull() ? "NULL_OK" : "NOT_NULL" );
	tagSet.setTagValue( CAN_QUERY,
		a.isUsedForQuery() ? "public" : "private" );

	tagSet.setTagValue( BEGIN_TYPE_DO,	   TemplateFilter.skipStart );
	tagSet.setTagValue( BEGIN_TYPE_STRING,	   TemplateFilter.skipStart );
	tagSet.setTagValue( BEGIN_TYPE_BIGDECIMAL, TemplateFilter.skipStart );
	tagSet.setTagValue( BEGIN_TYPE_BIGDECIMAL, TemplateFilter.skipStart );
	tagSet.setTagValue( BEGIN_TYPE_DATE,       TemplateFilter.skipStart );
	tagSet.setTagValue( BEGIN_TYPE_BYTEARRAY,  TemplateFilter.skipStart );
	tagSet.setTagValue( BEGIN_TYPE_PRIMITIVE,  TemplateFilter.skipStart );
	tagSet.setTagValue( END_TYPE_DO,	   TemplateFilter.skipStop );
	tagSet.setTagValue( END_TYPE_STRING,       TemplateFilter.skipStop );
	tagSet.setTagValue( END_TYPE_BIGDECIMAL,   TemplateFilter.skipStop );
	tagSet.setTagValue( END_TYPE_DATE,         TemplateFilter.skipStop );
	tagSet.setTagValue( END_TYPE_BYTEARRAY,    TemplateFilter.skipStop );
	tagSet.setTagValue( END_TYPE_PRIMITIVE,    TemplateFilter.skipStop );
	String type = a.getJavaType();
	if (	a.isObjectRef() ) {
	    tagSet.setTagValue(	BEGIN_TYPE_DO,		"" );
	    tagSet.setTagValue(	END_TYPE_DO,		"" );
	} else if (	type.equals( "String" ) ) {
	    tagSet.setTagValue(	BEGIN_TYPE_STRING,	"" );
	    tagSet.setTagValue(	END_TYPE_STRING,	"" );
	} else if (	type.equals( "BigDecimal" ) ) {
	    tagSet.setTagValue(	BEGIN_TYPE_BIGDECIMAL,	"" );
	    tagSet.setTagValue(	END_TYPE_BIGDECIMAL,	"" );
	} else if (	type.equals( "java.sql.Date" )      ||
			type.equals( "java.sql.Time" )	    ||
			type.equals( "java.sql.Timestamp" ) ) {
	    tagSet.setTagValue(	BEGIN_TYPE_DATE,	"" );
	    tagSet.setTagValue(	END_TYPE_DATE,		"" );
	} else if (	type.equals( "byte[]" ) ) {
	    tagSet.setTagValue(	BEGIN_TYPE_BYTEARRAY,	"" );
	    tagSet.setTagValue(	END_TYPE_BYTEARRAY,	"" );
	} else {
	    tagSet.setTagValue(	BEGIN_TYPE_PRIMITIVE,	"" );
	    tagSet.setTagValue(	END_TYPE_PRIMITIVE,	"" );
	}
    }

    private String sql_query_column_names = "";
    private String table_prefix = "";

    public void writeFileHeader(  DataObject o ) throws Exception {
	defaultWriteFileHeader( o );

	table_prefix = tagSet.getTagValue( TABLE_NAME ) + ".";

        Vector ancestors = o.getAncestors();
	if ( null != ancestors ) {
	    for ( int i = 0; i < ancestors.size(); i++ ) {
		DataObject p = (DataObject) ancestors.elementAt( i );
		if ( null != p ) {
		    Vector members = p.getAttributes();
		    for ( int j = 0; j < members.size(); j++ ) {
			Attribute attr = (Attribute) members.elementAt( j );
			memberPrep( attr );
			writeMemberStuff(   attr );
		    }
		}
	    }
	}
    }

    private String query_comma = "";

    public void writeMemberStuff( Attribute  a ) throws Exception {
	// Spell out the names of all columns, so that the generated code
	//  will not break if a new table definition changes the column order.
	sql_query_column_names += query_comma + table_prefix + a.getName();
	query_comma = ", ";

	if ( ! a.isUsedForQuery() ) return;
	defaultWriteMemberStuff( a );
    }

    public void writeFileFooter(  DataObject o ) throws Exception {
	tagSet.setTagValue( QUERY_COLUMN_NAMES,	sql_query_column_names );
	// When spelling out the names of the columns,
	// we do not automatically include "oid" and "version".
	// This is because some DOs are used as VIEWs
	// whose definitions are created by hand.
	tagSet.setTagValue( QUERY_OID_AND_VERSION,
	    ", " + table_prefix + oidDbColumnName + ", " + table_prefix + versionDbColumnName );

	defaultWriteFileFooter( o );
    }
}
