/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: CloneableDO.java,v 1.6 2000/01/29 07:01:46 markd Exp $
 *-----------------------------------------------------------------------------
 */





package	com.lutris.appserver.server.sql;
import com.lutris.appserver.server.LBS;
import java.sql.*;

/**
 * Base class from which the data objects are created.
 * Provides functionality for cloning data objects.  The cloned
 * data object will have a unique object identifier.
 *
 * @version $Revision: 1.6 $
 * @since LBS1.8
 * @author Kyle Clark
 */
abstract public class CloneableDO extends CoreDO implements Cloneable {

    /**
     * Public constructor.
     */
    public CloneableDO() {
        super();
    }
    
    /**
     * Public constructor.
     * @param rs a result set.
     * @exception SQLException if an error occurs while instantiating this
     * object from the result set.
     * @exception ObjectIdException if the object id for this object is
     * invalid.
     */
    public CloneableDO(ResultSet rs) throws SQLException, ObjectIdException {
        super(rs);
    }

    /**
     * Creates a clone of the object, but ensures that
     * a new and unique object id is created for the object
     * and that the version number is set to zero.
     * @exception DatabaseManagerException if an error occurs while
     * allocation a new object id from the default logical database.
     * @exception ObjectIdException if a new object id could not be
     * allocated.
     */
    public synchronized Object cloneUnique()
        throws DatabaseManagerException, ObjectIdException {

        CloneableDO dataObj = (CloneableDO)clone();
        dataObj.setOId(LBS.getApplication().getDatabaseManager().
                       allocateObjectId());
        dataObj.setVersion(0);
        dataObj.setPersistent(false);
        return dataObj;
    }

    /**
     * Will clone the existing object keeping a fields
     * the same, including the object id.
     */
    protected Object clone() {
        Object obj = this;
        try {
            obj = super.clone();
        } catch (CloneNotSupportedException ex) {
            // Should not happen
        }
        return obj;
    }
}

