/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * DBRowUpdateException thrown by CoreDO.executeUpdate()
 *-----------------------------------------------------------------------------
 * $Id: DBRowUpdateException.java,v 1.2 2000/01/29 07:01:48 markd Exp $
 *-----------------------------------------------------------------------------
 */

package com.lutris.appserver.server.sql;

/**
 * DBRowUpdateException is thrown when a CoreDO update fails.
 *
 * Two values are used to uniquely identify a row in a table:
 *    oId and version.
 * The executeUpdate() method creates an SQL UPDATE command
 * to write the new values in a CoreDO object back to
 * the correct row in the database.
 * The row is identifed by the oId and version values specified
 * in the WHERE-clause of the UPDATE command.
 *
 * So, if no row has the specified oId and version combination,
 * the UPDATE will fail, and report that 0 rows were updated.
 * Note: other database problems (e.g. disk full) can also cause
 * an UPDATE to fail, but these are rare.
 *
 * When versioning == true, the executeUpdate() method will increment
 * the version number in both the CoreDO object and in the updated row.
 *
 * When the same oId/version combination is used twice to create
 * two CoreDO objects (A and B) that refer to the same row,
 * it is possible for the version number of one of those objects
 * to become out-of-sync with the row in the database.
 * Object A is updated, and the version number in object A and
 * in the row is incremented.
 * When an attempt is made to update object B, the version number in
 * object B no longer matches the row in the database,
 * so the row is not found, and the update has no effect
 * (zero rows are updated).
 * In this case, the CoreDO.executeUpdate() method throws
 * a DBRowUpdateException describing the problem.
 *
 * The application code that catches this exception
 * should probably reload the Data Object from the database.
 *
 * @version	$Revision: 1.2 $
 * @see 	CoreDO
 * @author	Jay Gunter
 */
public class DBRowUpdateException extends java.sql.SQLException {

    /**
     * Construct a exception without a specified cause.
     *
     * @param msg The message associated with the exception.
     */
    public DBRowUpdateException(String msg) {
        super(msg);
    }
}



