/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: InformixObjectIdAllocator.java,v 1.8 2000/01/29 07:01:56 markd Exp $
 *-----------------------------------------------------------------------------
 */





package	com.lutris.appserver.server.sql.informix;

import com.lutris.appserver.server.LBS;
import java.util.Hashtable;
import java.math.BigDecimal;
import java.sql.*;
import com.lutris.appserver.server.sql.*;
import com.lutris.appserver.server.sql.standard.*;
import com.lutris.logging.*;
import com.lutris.util.*;

/**
 * Informix Object ids can only be created via this manager.
 * Ensures that all object ids are unique across all
 * objects in this logical database. Also ensures good performance
 * for allocating object ids.
 * <P>
 * The configuration data is specified in the section:
 * <CODE>DatabaseManager.DB.<I>dbName</I>.ObjectId</CODE>
 * <P>
 * Configuration fields are:
 * <UL>
 * <LI> <CODE>CacheSize</CODE> -
 *      The number of object id's to cache between database queries. Optional,
 *	if not specified, then it defaults to 1024.
 * <LI> <CODE>MinValue</CODE> -
 *      The starting number of Object ID allocation. This will only be used
 *	if the Object ID table is empty and thus is useful in development
 *	and testing. Optional, if not specified it defaults to
 *	100000000000000000. Note that the largest number that can be
 *	associated with an OID in LBS is "database: DECIMAL(19,0)"
 * </UL>
 *
 * @author	Kyle Clark
 * @since	LBS1.8
 * @version	$Revision: 1.8 $
 */
public class InformixObjectIdAllocator extends StandardObjectIdAllocator {

    /**
     * Initialize the object id manager.
     *
     * @param objCacheSize The number of object ids to cache between
     *  database queries.
     * @param objIdMinValue The starting number for object ids. Used
     *  only if object id table is empty.
     * @exception ConfigException if bad configuration information is
     *  given in the config file.
     */
    protected InformixObjectIdAllocator (LogicalDatabase logicalDatabase,
                                         Config objIdConfig)
	throws ConfigException
    {
        super(logicalDatabase, objIdConfig);
    }

}
