/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: Main.java,v 1.8 2000/01/29 07:02:08 markd Exp $
 *-----------------------------------------------------------------------------
 */





package	com.lutris.appserver.server.sql.tests;

import com.lutris.appserver.server.sql.*;
import java.sql.*;

public class Main {
    
    private static final String DBNAME = "kyle";
    private static final String DRIVER =
        "intersolv.jdbc.sequelink.SequeLinkDriver";
    private static final String CONNECTION =
        "jdbc:sequelink://ra:4004/[Informix];Database=" + DBNAME;
    private static final String USER = "informix";
    private static final String PASSWORD = "irilab!";
    private static final boolean LOGGING = false;
    private static final int MAXSIZE = 2;

    private static String [] product = {
        "toothbrush", "2.75",
        "underware", "4.50",
        "wax", "2.75",
        "ear plugs", "2.75",
        "surfboard", "475.00" };

    /**
     * Main entry point to tests.
     */
    public static void main (String [] args)
        throws Exception
    {
        DBConnection conn;
        String dropTable =
            "drop table PRODUCTS";
        String createTable =
            "create table PRODUCTS " +
            "(PROD_NAME varchar(32), " +
            "PRICE float)";

        ConnectionManager.initializeDatabase(DBNAME,
                                             DRIVER,
                                             CONNECTION,
                                             USER,
                                             PASSWORD,
                                             LOGGING,
                                             MAXSIZE);

        conn = ConnectionManager.allocate(DBNAME);

        //
        // Clean up existing tables from DB.
        //
        try {
            conn.execute(dropTable);
        }
        catch (SQLException ignore) {
            System.out.println("Table doesn't exist - OK");
        }

        //
        // Create a new table
        //
        conn.execute(createTable);

        DBQuery query = new DBQuery(DBNAME);
        DBTransaction transaction;

        //
        // Populate the table w/ data.
        //
        System.out.println();
        transaction = new DBTransaction(DBNAME);
        try {
            System.out.println("Populating table:");
            Product p = new Product();
            for (int idx=0; idx<product.length; idx+=2) {
                p.setName(product[idx]);
                p.setPrice(Float.valueOf(product[idx+1]).floatValue());
                transaction.insert(p);
                System.out.println("adding product: " +
                                   product[idx] + "\t" +
                                   product[idx + 1]);
            }
            transaction.commit();
        }
        catch (SQLException e) {
            System.out.println(e.toString());
            System.out.println("rolling back changes");
        }
        finally {
            transaction.release();
        }
        
        //
        // List the all products in table.
        //
        System.out.println("\nTEST: query all");
        try {
            int total = 0;
            System.out.println("Querying all products from table:");
            ProductQuery pQuery = new ProductQuery();
            query.query(pQuery);
            Product p;
            while ((p = (Product)query.next()) != null) {
                total++;
                System.out.println(p.toString());
            }
            if (total < product.length/2) {
                System.out.println("\n<<<<FAILURE>>>>> ** " +
                                   "unable to query all objects" +
                                   " ** <<<<</FAILURE>>>>>\n");
            }
            query.release();
        }
        catch (SQLException e) {
            System.out.println(e.toString());
        }
        finally {
            query.release();
        }

        //
        // List a subset of products.
        //
        System.out.println("\nTEST: query");
        try {
            boolean ok = false;
            System.out.println("Querying objects of price $2.75:");
            ProductQuery pQuery = new ProductQuery();
            pQuery.setQueryPrice((float)2.75);
            query.query(pQuery);
            Product p;
            while ((p = (Product)query.next()) != null) {
                ok = true;
                System.out.println(p.toString());
            }
            query.release();
            if (!ok) {
                System.out.println("\n<<<<FAILURE>>>>> ** " +
                                   "unable to query objects" +
                                   " ** <<<<</FAILURE>>>>>\n");
            }
        }
        catch (SQLException e) {
            System.out.println(e.toString());
        }
        finally {
            query.release();
        }

        
        //
        // Update fields in the table.
        //
        System.out.println("\nTEST: transaction commit");
        transaction = new DBTransaction(DBNAME);
        try {
            System.out.println("Update all products of price $2.75 " +
                               "to $3.25 - you know, inflation...");
            ProductQuery pQuery = new ProductQuery();
            pQuery.setQueryPrice((float)2.75);
            query.query(pQuery);
            Product p;
            while ((p = (Product)query.next()) != null) {
                System.out.println("Updating: " + p.getName());
                p.setPrice((float)3.25);
                transaction.update(p);
            }
            transaction.commit();

            // Now query the results.
            pQuery.reset();
            pQuery.setQueryPrice((float)2.75);
            query.query(pQuery);
            if (query.next() != null)
                System.out.println("\n<<<<FAILURE>>>>> ** " +
                                   "transaction did not commit" +
                                   " ** <<<<</FAILURE>>>>>\n");
        }
        catch (SQLException e) {
            System.out.println(e.toString());
        }
        finally {
            transaction.release();
            query.release();
        }
        
        //
        // Update fields in the table but rollback the transaction.
        //
        System.out.println("\nTEST: transactio rollback");
        transaction = new DBTransaction(DBNAME);
        try {
            System.out.println("Update all products of price $3.25 " +
                               "to $2.75 but rollback the transaction ...");
            System.out.println("you know, prices never drop.");
            ProductQuery pQuery = new ProductQuery();
            pQuery.setQueryPrice((float)3.25);
            query.query(pQuery);
            Product p;
            while ((p = (Product)query.next()) != null) {
                System.out.println("Updating: " + p.getName());
                p.setPrice((float)2.75);
                transaction.update(p);
            }
            transaction.rollback();

            // Now query the results.
            pQuery.reset();
            pQuery.setQueryPrice((float)2.75);
            query.query(pQuery);
            if (query.next() != null)
                System.out.println("\n<<<<FAILURE>>>>> ** " +
                                   "transaction did not roll back" +
                                   " ** <<<<</FAILURE>>>>>\n");
        }
        catch (SQLException e) {
            System.out.println(e.toString());
        }
        finally {
            transaction.release();
            query.release();
        }

        //
        // Drop the table.
        //
        conn.execute(dropTable);        
        conn.release();
    }

}
