/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: ProductQuery.java,v 1.7 2000/01/29 07:02:08 markd Exp $
 *-----------------------------------------------------------------------------
 */





package	com.lutris.appserver.server.sql.tests;

import com.lutris.appserver.server.sql.*;
import java.sql.*;

public class ProductQuery implements Query {
    
    private final String TABLE = "PRODUCTS";
    private final String ALL = "*";
    private boolean qName = false;
    private boolean qPrice = false;
    private String name = null;
    private float price = 0;

    public String getQueryName()
    {
        return name;
    }

    public float getQueryPrice()
    {
        return price;
    }

    public void setQueryName(String name)
    {
        this.name = name;
        this.qName = true;
    }

    public void setQueryPrice(float price)
    {
        this.price = price;
        this.qPrice = true;
    }

    public void reset()
    {
        this.qName = false;
        this.qPrice = false;
    }

    public ResultSet executeQuery(DBConnection conn)
        throws SQLException
    {
        PreparedStatement stmt;

        if (qName && qPrice) {
            String sql =
                "select * from " + TABLE + " " +
                "where PROD_NAME = ? and PRICE = ?";
            stmt = conn.prepareStatement(sql);
            stmt.setString(1, getQueryName());
            stmt.setFloat(2, getQueryPrice());
        }
        else if (qName) {
            String sql =
                "select * from " + TABLE + " " +
                "where PROD_NAME = ?";
            stmt = conn.prepareStatement(sql);
            stmt.setString(1, getQueryName());
        }
        else if (qPrice) {
            String sql =
                "select * from " + TABLE + " " +
                "where PRICE = ?";
            stmt = conn.prepareStatement(sql);
            stmt.setFloat(1, getQueryPrice());
        }
        else {
            String sql =
                "select * from " + TABLE;
            stmt = conn.prepareStatement(sql);
        }
        return conn.executeQuery(stmt, "product query");
    }

    public Object next(ResultSet rs)
        throws SQLException
    {
        if (rs.next()) {
            Product p = new Product();
            p.setName(rs.getString(1));
            p.setPrice(rs.getFloat(2));
            return (Object)p;
        }
        return null;
    }

}
