/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: CachedFilePresentation.java,v 1.10 2000/01/29 07:02:10 markd Exp $
 *-----------------------------------------------------------------------------
 */





package com.lutris.appserver.server.httpPresentation;

import java.io.*;
import com.lutris.util.*;

/**
 * Presentation for file data that is cached in memory.
 */
class CachedFilePresentation implements HttpPresentation {
    private String mimeType;
    private int contentLen = 0;
    private ByteArrayOutputStream fileData;

    private static final int READ_BUFFER_SIZE = 4096;

    /**
     * Construct a new static file presentation, given an input stream.
     */
    protected CachedFilePresentation(ClassLoader classLoader,
                                     String urlPath,
                                     String fileMimeType) 
            throws FilePresentationException {
        mimeType = fileMimeType;
        InputStream input = classLoader.getResourceAsStream(urlPath);
        if (input == null) {
            throw new FilePresentationException
                (new FileNotFoundException ("File \"" + urlPath
                                            + "\" not found on application class path"));
        }
            
        try {
            // Read in file.
            try {
                byte [] buffer = new byte[READ_BUFFER_SIZE];
                fileData = new ByteArrayOutputStream();
                while (true) {
                    int readLen = input.read(buffer, 0, READ_BUFFER_SIZE);
                    if (readLen < 0)
                        break;
                    fileData.write(buffer, 0, readLen);
                    contentLen += readLen;
                }
            } finally {
                input.close();
            }
        } catch (Exception except) {
            throw new FilePresentationException(except);
        }
    }
    
    /**
     * Entry point for static file presenation.
     */
    public void run(HttpPresentationComms comms)
            throws FilePresentationException {
        try {
            comms.response.setContentLength(contentLen);
            comms.response.setContentType(mimeType);

            if (!comms.request.getMethod().equals("HEAD")) {
                fileData.writeTo(comms.response.getOutputStream());
            }
        } catch (Exception except) {
            throw new FilePresentationException(except);
        }
    }
}
