/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: HttpPresentationComms.java,v 1.21 2000/02/15 08:55:05 markd Exp $
 *-----------------------------------------------------------------------------
 */





package com.lutris.appserver.server.httpPresentation;

import com.lutris.appserver.server.*;
import com.lutris.appserver.server.session.*;
import org.enhydra.xml.xmlc.XMLCFactory;


/**
 * Object passed to presentation objects that contains HTTP and Presentation
 * Manager access and control objects.
 */
public class HttpPresentationComms {
    /**
     * Object used to access HTTP request data.
     */
    public final HttpPresentationRequest request;

    /**
     * Object used to generate HTTP responses.
     */
    public final HttpPresentationResponse response;

    /**
     * Application object that this presentation is associated with.
     * If null, no application is associated.
     */
    public final Application application;

    /**
     * Session object that this presentation is associated with.
     * If null, no session has been associated by the application.
     */
    public Session session;

    /**
     * Session data object.  This is a handy reference to 
     * <CODE>session.getSessionData()</CODE>
     */
    public SessionData sessionData;

    /**
     * If an exception/error occured, this field is set to the exception
     *  object. This is only set for and used by `ErrorHandler' presentations.
     */
    public Throwable exception;

    /**
     * Reference to the XMLC factory object contained in the application.
     */
    public XMLCFactory xmlcFactory;

    /**
     * Construct an object, setting all of its fields.
     *
     * @param request Object used to access HTTP request data.
     * @param response Object used to generate HTTP responses.
     * @param application Application object that this presentation is
     * associated with or null if no application is associated.
     */
    protected HttpPresentationComms (HttpPresentationRequest request,
                                     HttpPresentationResponse response,
                                     Application application) {
        this.request = request;
        this.response = response;
        this.application = application;
        this.xmlcFactory = application.getXMLCFactory();
    }

}
