/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: HttpPresentationOutputStream.java,v 1.13 2000/01/29 07:02:11 markd Exp $
 *-----------------------------------------------------------------------------
 */





package com.lutris.appserver.server.httpPresentation;

import java.io.IOException;
import java.io.OutputStream;


/**
 * HTTP request output stream writter.
 */
public abstract class HttpPresentationOutputStream extends OutputStream {

    //FIX:  Need MIME-write functions.

    /**
     * Prints the string provided.
     *
     * @exception IOException if an I/O error has occurred
     */
    public abstract void print(String s) throws IOException;

    /**
     * Prints the boolean provided.
     *
     * @exception IOException if an I/O error has occurred.
     */
    public abstract void print(boolean b) throws IOException;

    /*
     * Prints the character provided.
     *
     * @exception IOException if an I/O error has occurred
     */
    public abstract void print(char c) throws IOException;

    /**
     * Prints the integer provided.
     *
     * @exception IOException if an I/O error has occurred
     */  
    public abstract void print(int i) throws IOException;
 
    /**
     * Prints the long provided.
     *
     * @exception IOException if an I/O error has occurred
     */
    public abstract void print(long l) throws IOException;

    /**
     * Prints the float provided.
     *
     * @exception IOException if an I/O error has occurred
     */
    public abstract void print(float f) throws IOException;

    /**
     * Prints the double provided.
     *
     * @exception IOException if an I/O error has occurred
     */
    public abstract void print(double d) throws IOException;

    /**
     * Prints a CRLF.
     *
     * @exception IOException if an I/O error has occurred
     */
    public abstract void println() throws IOException;

    /**
     * Prints the string provided, followed by a CRLF.
     *
     * @exception IOException if an I/O error has occurred
     */
    public abstract void println(String s) throws IOException;

    /**
     * Prints the boolean provided, followed by a CRLF.
     *
     * @exception IOException if an I/O error has occurred.
     */
    public abstract void println(boolean b) throws IOException;

    /**
     * Prints the character provided, followed by a CRLF.
     *
     * @exception IOException if an I/O error has occurred
     */
    public abstract void println(char c) throws IOException;

    /**
     * Prints the integer provided, followed by a CRLF.
     *
     * @exception IOException if an I/O error has occurred
     */
    public abstract void println(int i) throws IOException;

    /**  
     * Prints the long provided, followed by a CRLF.
     *
     * @exception IOException if an I/O error has occurred
     */  
    public abstract void println(long l) throws IOException;

    /**
     * Prints the float provided, followed by a CRLF.
     *
     * @exception IOException if an I/O error has occurred
     */
    public abstract void println(float f) throws IOException;

    /**
     * Prints the double provided, followed by a CRLF.
     *
     * @exception IOException if an I/O error has occurred
     */
    public abstract void println(double d) throws IOException;

    /*
     * We disallow closing the output stream, but don't export the
     * doc on this function.
     */
    public void close() throws IOException {
        throw new IOException("HttpPresentationOutputStream may not be closed");
    }
}
