/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: HttpUtil.java,v 1.16 2000/01/29 07:02:11 markd Exp $
 *-----------------------------------------------------------------------------
 */





package com.lutris.appserver.server.httpPresentation;

import com.lutris.util.*;
import com.lutris.http.*;
import java.util.*;
import java.io.*;
import java.lang.reflect.*;


/**
 * Class containing various static methods that are useful in implementing
 * presentations.
 */
public class HttpUtil {

    /**
     * Private constructor, prevent instantiation.
     */
    private HttpUtil() {}

    /**
     * Convert a HTTP query string object to a keyword/value table.
     * 
     * @param query Hash table containing the parsed key/value pairs.
     * @return A keyword/value table with the parsed string.
     */
    public static KeywordValueTable buildQueryTable(Hashtable query)
        throws KeywordValueException {
        Enumeration arguments = query.keys();
        KeywordValueTable table = new KeywordValueTable();
        while (arguments.hasMoreElements()) {
            String key = (String)(arguments.nextElement());
            table.set(key, query.get(key));
        }
        return table;
    }

    /**
     * Convert a HTTP query string to a keyword/value table.
     * 
     * @param queryString Query string.
     * @return A keyword/value table with the parsed string.
     * FIX: better description of format.
     */
    public static KeywordValueTable buildQueryTable(String queryString)
        throws KeywordValueException {
	return buildQueryTable(HttpUtils.parseQueryString(queryString));
    }

    /**
     * Read in post data return it as a string.  If content is not
     * "application/x-www-form-urlencoded", return an empty string.  FIX:
     * change mime type handling as part of form upload, should generate an
     * error if we get something we can't handle.  this should be part of a
     * module to handle input restructured.
     */
    private static String getPostData(HttpPresentationRequest httpRequest)
            throws HttpPresentationException {
        String cType = httpRequest.getContentType().toLowerCase();
        if (cType.indexOf("application/x-www-form-urlencoded") < 0) {
            return "";
        } else {
            byte[] buffer = new byte[httpRequest.getContentLength()];
            try {
		int count = 0;
		int c = 0;
		boolean done = false;
		while ((count < buffer.length) && !done) {
		    c = httpRequest.getInputStream().read(buffer,
				    count, buffer.length - count);
                    if (c == -1) {
                        done = true;
                    } else {
                        count += c;
                    }
		}
            } catch (IOException except) {
                throw new HttpPresentationException(except);
            }
	    return new String(buffer);
        }
    }

    /**
     * Get the query string for the request and save it in the page data.
     * If this is a post, read the query string first.
     *
     * @param request HTTP request data.
     * @exception HttpPresentationException
     *   If an error occurs accessing the request.
     */
    public static String getQueryFromRequest(HttpPresentationRequest httpRequest)
        throws HttpPresentationException {

        String queryString;
        if (httpRequest.getMethod().equals("POST")) {
            // POST method
            queryString = getPostData(httpRequest);
        } else {
            // GET method
            queryString = httpRequest.getQueryString();
        }
        if (queryString == null) {
            queryString = "";
        }
        return queryString;
    }
}
