/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: PageRedirect.java,v 1.19 2000/03/08 09:04:55 markd Exp $
 *-----------------------------------------------------------------------------
 */





package com.lutris.appserver.server.httpPresentation;

import java.net.URL;
import java.net.URLEncoder;
import java.net.MalformedURLException;
import java.util.Hashtable;
import java.util.Enumeration;
import java.io.*;
import javax.servlet.http.Cookie;

import com.lutris.logging.*;
import com.lutris.http.HttpUtils;
import com.lutris.appserver.server.StandardAppUtil;

/**
 * Static methods for processing a page redirect.
 *
 * @version	$Revision: 1.19 $
 * @author	Mark Diekhans
 * @since	Jolt1.3
 */
class PageRedirect {
    /**
     * Process a page redirection.
     *
     * @return Path of the presentation object to invoke for a server-side
     *  redirect or null if a redirect response has been sent to the
     *  client. NOTE: Currently always returns null.
     */
    protected static String handler(HttpPresentationComms comms,
                                    String presObjPath,
                                    PageRedirectException redirectExcept,
                                    LogChannel logChannel,
                                    long requestId)
            throws MalformedURLException,
		   HttpPresentationException,
		   IOException {

        //FIX: Break into two functions; one for client., one for server.
        logChannel.write(Logger.DEBUG,  "RID:" + requestId + ": "
                         + redirectExcept.getClass().getName()
                         + ": " + presObjPath + " => "
                         + redirectExcept.getUrl());

        if (redirectExcept instanceof ClientPageRedirectException) {
            String url = redirectExcept.getUrl();
            if (comms.request.isRequestedSessionIdFromUrl() &&
                    StandardAppUtil.pointsToPO(url)) {
                url = StandardAppUtil.encodeUrl(url, comms.session.getSessionKey());
                logChannel.write(Logger.DEBUG,  "RID:" + requestId + ": "
                                 + "Adding session ID to new URL: "
                                 + url);
            }
            comms.response.setHeader("Location", url);
            comms.response.setStatus(HttpPresentationResponse.SC_MOVED_TEMPORARILY,
                                     "Redirected to new location.");
            comms.response.flush();
            return null;
        } else {
            throw new HttpPresentationException("server side redirected not implemented yet");
            //FIXME: Should use the <BASE href="xxxx"> to set base when redirecting
            //to another directory

            //FIX: old logic..
            //rc.setRequestArgs(redirect.getQueryString());
            //rc.setRequestCookies(redirect.getCookieTable());
            //rc.setPathInfo(redirect.getPathInfo(rc.getHttpScriptName()));
            //return Run(rc); 
        }
    }
}
