/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: PageRedirectException.java,v 1.20 2000/01/29 07:02:11 markd Exp $
 *-----------------------------------------------------------------------------
 */





package com.lutris.appserver.server.httpPresentation;
import com.lutris.http.*;
import com.lutris.util.*;
import java.net.URLEncoder;


/**
 * Base class of page redirection classes.  It is a subclass of Error
 * rather than exception, as we only want the presentation manager
 * to catch it.
 */
abstract public class PageRedirectException extends Error {
    /**
     * URL that is the target of the redirect.
     */
    private String url;

    /**
     * Are there any arguments associated with the URL?
     */
    private boolean urlHasArgs = false;

    /**
     * Constructor a redirect, saving the URL..
     *
     * @param url The url where the request should be redirected.
     *  It may have arguments encoded and/or they may be added with
     *  <CODE>addArgument</CODE>.
     * @see PageRedirectException#addArgument
     */
    protected PageRedirectException(String url) {
        this.url = url;
        urlHasArgs = (url.lastIndexOf('?') >= 0);
    }
 
    /**
     * Add an argument to the URL.
     *
     * @param name Argument name.
     * @param value Argument value.
     */
    public void addArgument(String name,
                            String value) {
        StringBuffer argStr = new StringBuffer();
        if (urlHasArgs) {
            argStr.append("&");
        } else {
            argStr.append("?");
        }
        argStr.append(URLEncoder.encode(name));
        if (value != null) {
            argStr.append("=");
            argStr.append(URLEncoder.encode(value));
        }
        url += argStr;
        urlHasArgs = true;
    }
 
   /**
     * Get the redirection URL associated with this redirect.
     *
     * @return The URL string. 
     */
    public String getUrl() {
        return url;
    }
}
