/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: FilterableServlet.java,v 1.8 2000/02/21 23:50:38 markd Exp $
 *-----------------------------------------------------------------------------
 */





package com.lutris.appserver.server.httpPresentation.servlet;

import java.io.IOException;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.enhydra.servlet.filter.Filter;


/**
 *
 *  See the class AbstractFilterableServlet for a reference implementation 
 *  that demnonstrates the responsabilities of a <CODE>FilterableServlet</CODE>.
 *
 *  This capability is used to implement the debugging servlet.
 *
 * @see com.lutris.appserver.server.httpPresentation.servlet.ServletListener
 * @see com.lutris.appserver.server.httpPresentation.servlet.AbstractServletListener
 */
public interface FilterableServlet {

    /**
     *  Add a filter to the end of the list of filters.
     *
     *  @param filter
     *    The filter to add.
     */
    public void addFilter(Filter filter);

    /**
     *  Remove a filter from the list of current filters. 
     *  Silently fails if the filter is not in the list.
     *
     *  @param filter
     *    The filter to remove.
     */
    public void removeFilter(Filter filter);

    /**
     *  Perform the action <CODE>service()</CODE> would normally perform,
     *  without using the filters. This is needed so that at the end of
     *  the filter chain the glue object can call this method to actually
     *  do the work. If it tried to call the normal service() method that
     *  would result in an infinite loop of filter processing.
     */
    public void serviceDirect(HttpServletRequest request,
                              HttpServletResponse response)
                throws ServletException, IOException;


}

