/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: HttpPresentationServletGlue.java,v 1.7 2000/02/18 07:24:59 shawn Exp $
 *-----------------------------------------------------------------------------
 */


package com.lutris.appserver.server.httpPresentation.servlet;

import javax.servlet.*;
import javax.servlet.http.*;
import java.io.IOException;

/**
 *  This is a small helper class, used be HttpPresentationServlet when there
 *  are filters applied to the servlet. At the end of the filter chain lies
 *  one of these objects. When my service method is called, I pass the call
 *  straight through to the serviceDirect() method of my
 *  HttpPresentationServlet. Therefore this class is the glue that connects
 *  the filter chain to the HttpPresentationServlet. Consider this an
 *  internal use only class.
 */
public class HttpPresentationServletGlue extends HttpServlet {

    /**
     *  The real servlet to pass service() calls on to.
     */
    private FilterableServlet filterableServlet;

    /**
     *  Create a new glue servlet. Calling service() on me results in
     *  serviceDirect() being called on filterableServlet. Since this is
     *  an internal-use-only class, you should not normally need to instantiate 
     *  one of these.
     *
     *  @param filterableServlet
     *    The real servlet to use.
     */
    public HttpPresentationServletGlue(FilterableServlet filterableServlet) {
        this.filterableServlet = filterableServlet;
    }



    /**
     *  Calls to this method are passed straight on to the serviceDirect()
     *  method of the FilterableServlet passed into my constructor.
     */
    public void service(HttpServletRequest request,
                        HttpServletResponse response)
                throws ServletException, IOException {
        filterableServlet.serviceDirect(request, response);
    }


    /**
     *  Get the servlet I am gluing to.
     *
     *  @return
     *    The FilterableServlet passed into my constructor.
     */
    public FilterableServlet getServlet() {
        return filterableServlet;
    }

}

