/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: ServletHttpPresentationInputStream.java,v 1.12 2000/01/29 07:02:12 markd Exp $
 *-----------------------------------------------------------------------------
 */





package com.lutris.appserver.server.httpPresentation.servlet;

import java.io.IOException;
import javax.servlet.ServletInputStream;
import com.lutris.appserver.server.httpPresentation.*;

/**
 * HTTP request input stream reader for servlets.
 * This implements all methods that are defined in InputStream as calles
 * to the servlet object, since we don't know which ones are implemented by
 * ServletInputStream.
 *
 * @see javax.servlet.ServletInputStream
 */
public class ServletHttpPresentationInputStream
	extends HttpPresentationInputStream {
    private ServletInputStream inputStream;

    /**
     * Construct an object for accessing a servlet input stream.
     */
    protected ServletHttpPresentationInputStream(ServletInputStream inputStream) {
        this.inputStream = inputStream;
    }

    /**
     * Starting at the specified offset, reads into the given array of
     * bytes until all requested bytes have been read or a '\n' is
     * encountered, in which case the '\n' is read into the array as well.
     * @param b the buffer into which the data is read
     * @param off the start offset of the data
     * @param len the maximum number of bytes to read
     * @return the actual number of bytes read, or -1 if the end of the
     *         stream is reached
     * @exception IOException if an I/O error has occurred
     */
    public int readLine(byte[] b, int off, int len)
        throws IOException {
        try {
            return inputStream.readLine(b, off, len);
        } catch (IOException except) {
            throw new HttpPresentationIOException(except);
        }
    }

    /*
     * InputStream methods vectored off to the ServletInputStream.
     */
    public int read() throws IOException {
        try {
            return inputStream.read();
        } catch (IOException except) {
            throw new HttpPresentationIOException(except);
        }
    }

    public int read(byte b[]) throws IOException {
        try {
            return inputStream.read(b);
        } catch (IOException except) {
            throw new HttpPresentationIOException(except);
        }
    }

    public int read(byte b[], int off, int len) throws IOException {
        try {
            return inputStream.read(b, off, len);
        } catch (IOException except) {
            throw new HttpPresentationIOException(except);
        }
    }

    public long skip(long n) throws IOException {
        try {
            return inputStream.skip(n);
        } catch (IOException except) {
            throw new HttpPresentationIOException(except);
        }
    }

    public int available() throws IOException {
        try {
            return inputStream.available();
        } catch (IOException except) {
            throw new HttpPresentationIOException(except);
        }
    }

    public synchronized void mark(int readlimit) {
        inputStream.mark(readlimit);
    }

    public synchronized void reset() throws IOException {
        try {
            inputStream.reset();
        } catch (IOException except) {
            throw new HttpPresentationIOException(except);
        }
    }

    public boolean markSupported() {
        return inputStream.markSupported();
    }
}
