/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: ServletHttpPresentationOutputStream.java,v 1.13 2000/01/29 07:02:12 markd Exp $
 *-----------------------------------------------------------------------------
 */





package com.lutris.appserver.server.httpPresentation.servlet;

import java.io.IOException;
import javax.servlet.ServletOutputStream;
import com.lutris.appserver.server.httpPresentation.*;

/**
 * HTTP request output stream writter for servlets.
 * This implements all methods that are defined in OutputStream as calles
 * to the servlet object, since we don't know which ones are implemented by
 * ServletOutputStream.
 *
 * @see javax.servlet.ServletOutputStream
 */
public class ServletHttpPresentationOutputStream
	extends HttpPresentationOutputStream {

    private ServletHttpPresentationResponse response;
    private ServletOutputStream outputStream;

    /**
     * Construct an object for accessing a servlet output stream.
     */
    protected ServletHttpPresentationOutputStream(ServletHttpPresentationResponse response,
                                                  ServletOutputStream outputStream) {
        this.response = response;
        this.outputStream = outputStream;
    }

    /**
     * Prints the string provided.
     * @exception IOException if an I/O error has occurred
     */
    public void print(String s) throws IOException {
        try {
            outputStream.print(s);
        } catch (IOException except) {
            throw new HttpPresentationIOException(except);
        }
    }

    /**
     * Prints the boolean provided.
     * @exception IOException if an I/O error has occurred.
     */
    public void print(boolean b) throws IOException {
        try {
            outputStream.print(b);
        } catch (IOException except) {
            throw new HttpPresentationIOException(except);
        }
    }

    /*
     * Prints the character provided.
     * @exception IOException if an I/O error has occurred
     */
    public void print(char c) throws IOException {
        try {
            outputStream.print(c);
        } catch (IOException except) {
            throw new HttpPresentationIOException(except);
        }
    }

    /**
     * Prints the integer provided.
     * @exception IOException if an I/O error has occurred
     */  
    public void print(int i) throws IOException {
        try {
            outputStream.print(i);
        } catch (IOException except) {
            throw new HttpPresentationIOException(except);
        }
    }
 
    /**
     * Prints the long provided.
     * @exception IOException if an I/O error has occurred
     */
    public void print(long l) throws IOException {
        try {
            outputStream.print(l);
        } catch (IOException except) {
            throw new HttpPresentationIOException(except);
        }
    }

    /**
     * Prints the float provided.
     * @exception IOException if an I/O error has occurred
     */
    public void print(float f) throws IOException {
        try {
            outputStream.print(f);
        } catch (IOException except) {
            throw new HttpPresentationIOException(except);
        }
    }

    /**
     * Prints the double provided.
     * @exception IOException if an I/O error has occurred
     */
    public void print(double d) throws IOException {
        try {
            outputStream.print(d);
        } catch (IOException except) {
            throw new HttpPresentationIOException(except);
        }
    }

    /**
     * Prints a CRLF.
     * @exception IOException if an I/O error has occurred
     */
    public void println() throws IOException {
        try {
            outputStream.println();
        } catch (IOException except) {
            throw new HttpPresentationIOException(except);
        }
    }

    /**
     * Prints the string provided, followed by a CRLF.
     * @exception IOException if an I/O error has occurred
     */
    public void println(String s) throws IOException {
        try {
            outputStream.println(s);
        } catch (IOException except) {
            throw new HttpPresentationIOException(except);
        }
    }

    /**
     * Prints the boolean provided, followed by a CRLF.
     * @exception IOException if an I/O error has occurred.
     */
    public void println(boolean b) throws IOException {
        try {
            outputStream.println(b);
        } catch (IOException except) {
            throw new HttpPresentationIOException(except);
        }
    }

    /*
     * Prints the character provided, followed by a CRLF.
     * @exception IOException if an I/O error has occurred
     */
    public void println(char c) throws IOException {
        try {
            outputStream.println(c);
        } catch (IOException except) {
            throw new HttpPresentationIOException(except);
        }
    }

    /**
     * Prints the integer provided, followed by a CRLF.
     * @exception IOException if an I/O error has occurred
     */
    public void println(int i) throws IOException {
        try {
            outputStream.println(i);
        } catch (IOException except) {
            throw new HttpPresentationIOException(except);
        }
    }

    /**  
     * Prints the long provided, followed by a CRLF.
     * @exception IOException if an I/O error has occurred
     */  
    public void println(long l) throws IOException {
        try {
            outputStream.println(l);
        } catch (IOException except) {
            throw new HttpPresentationIOException(except);
        }
    }

    /**
     * Prints the float provided, followed by a CRLF.
     * @exception IOException if an I/O error has occurred
     */
    public void println(float f) throws IOException {
        try {
            outputStream.println(f);
        } catch (IOException except) {
            throw new HttpPresentationIOException(except);
        }
    }

    /**
     * Prints the double provided, followed by a CRLF.
     * @exception IOException if an I/O error has occurred
     */
    public void println(double d) throws IOException {
        try {
            outputStream.println(d);
        } catch (IOException except) {
            throw new HttpPresentationIOException(except);
        }
    }

    /*
     * OutputStream methods vectored off to the ServletOutputStream.
     */
    public void write(int b) throws IOException {
        try {
            outputStream.write(b);
        } catch (IOException except) {
            throw new HttpPresentationIOException(except);
        }
    }

    public void write(byte b[]) throws IOException {
        try {
            outputStream.write(b);
        } catch (IOException except) {
            throw new HttpPresentationIOException(except);
        }
    }

    public void write(byte b[], int off, int len) throws IOException {
        try {
            outputStream.write(b, off, len);
        } catch (IOException except) {
            throw new HttpPresentationIOException(except);
        }
    }

    public void flush() throws IOException {
        try {
            outputStream.flush();
        } catch (IOException except) {
            throw new HttpPresentationIOException(except);
        }
    }

    //FIX:  Need MIME-write functions.
}
