/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: StreamPO.java,v 1.10 2000/01/29 07:02:13 markd Exp $
 *-----------------------------------------------------------------------------
 */




/*
 * Test presentation object to send a stream of JavaScript tags to the
 * browers.  This is used as a test of streaming data.  It write to a single
 * frame.
 *
 * Expected arguments are:
 *    frame=name
 * N.B. jolt was not used since we don't want a dependency in these tests.
 */
package com.acme.gui.presObjs;

import com.lutris.appserver.server.httpPresentation.*;


public class StreamPO implements HttpPresentation {

    private static boolean stop = false;
    
    private String getParam (HttpPresentationComms comms,
                             String name) 
            throws HttpPresentationException {
        String param = comms.request.getParameter(name);
        if (param == null) {
            throw new HttpPresentationException("Required argument \"" +
                                                name + "\" not specified");
        }
        return param;
    }

    private void wasteTime(int factor) {
        String str = "";
        for (int cnt = 0; cnt < factor; cnt++) {
            str = str + "A";
        }
    }
    

    private void updateFrameText(HttpPresentationOutputStream out,
                                 String frame,
                                 String text) 
            throws java.io.IOException {
        out.println("<SCRIPT LANGUAGE=\"Javascript\">");
        if (false) {
        out.println("parent." + frame + ".document.open()");
        out.println("parent." + frame + ".document.write(\"" + text + "\")");
        out.println("parent." + frame + ".document.close()");
        }
        out.println("document.msgBox.msg.value=\"" + text + "\"");
        out.println("</SCRIPT>");
        out.flush();
    }
    
    public void run(HttpPresentationComms comms) throws Exception {
        comms.response.setStatus(HttpPresentationResponse.SC_OK, "Good job");

        HttpPresentationOutputStream out = comms.response.getOutputStream();

        // Handle stop button; set global stop flag.
        String stopRequest = comms.request.getParameter("stopButton");
        if (stopRequest != null) {
            out.println("<CENTER>Stopped</CENTER>\n");
            stop = true;
            return;
        }


        String frame = getParam(comms, "frame");
        int maxUpdate = 1000;

        stop = false;

        out.println("<Center>\n");
        out.println("<H2>Streaming Presentation Object " + frame  + "</H2>\n");
        out.println("<FORM NAME=\"msgBox\">");
        out.println("<INPUT TYPE=\"text\" NAME=\"msg\" VALUE=\"Nothing yet\">");
        out.println("</FORM>");
        out.println("</Center>\n");
        out.flush();

        for (int cnt = 0; (cnt < maxUpdate) && (!stop); cnt++) {
            updateFrameText(out, frame, "Frame " + frame + ", update " + cnt);
            wasteTime(1000);
        }

        System.err.println("Exit PO");
    }
}
