/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: PagedSession.java,v 1.3 2000/01/29 07:02:14 markd Exp $
 *-----------------------------------------------------------------------------
 */

package com.lutris.appserver.server.session;

import java.net.*;
import com.lutris.util.*;
import com.lutris.appserver.server.user.User;
import com.lutris.appserver.server.*;
import java.io.Serializable;

/**
 * PagedSession requires that all session data and the user
 * associated with the session be serializable.
 *
 * @version $Revision: 1.3 $
 * @author  Kyle Clark
 * @see PagedSessionHome
 */
public class PagedSession extends BasicSession {

    // Need the following constructor in order to serialize.
    public PagedSession() {
    }
    
    /**
     * Construct a new session.  Only called by
     * <CODE>PagedSessionHome</CODE>.
     *
     * @param sessionManager The session manager that will manage this session.
     * @param sessionKey The unique session key associated with the session.
     */
    protected PagedSession(StandardSessionManager sessionManager,
                           String sessionKey) {
        super(sessionManager, sessionKey, new PagedSessionData());
    }

    /**
     * Ensures that the user associated with the session is serializable.<p>
     * 
     * @param user
     *   the user object to associate with the session.
     * @exception SessionException
     *   if the user cannot be associated with the session.
     */
    public void setUser(User user) throws SessionException {
        if (!(user instanceof Serializable)) {
            throw new SessionException("Paged session user must be serializable.");
        }
        super.setUser(user);
    }

    /**
     * Called before the session is paged to disk.
     * Returns the transient data that should be restored
     * when the session is read from disk.
     *
     * @param data 
     *   array of transient data objects.
     * @see #restoreTransientData
     */
    Object [] getTransientData() {
        Object [] transientData = new Object[1];
        transientData[0] = sessionManager;
        return transientData;
    }

    /**
     * Called when the session is paged back into memory.
     * Allows it to restore references to the transient
     * data associated with the session.
     *
     * @param data 
     *   array of transient data objects.
     * @see #getTransientData
     */
    void restoreTransientData(Object [] data) {
        this.sessionManager = (StandardSessionManager)data[0];
    }

}




