/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: Session.java,v 1.16 2000/02/21 21:21:26 peterj Exp $
 *-----------------------------------------------------------------------------
 */

package com.lutris.appserver.server.session;

import com.lutris.appserver.server.*;
import com.lutris.appserver.server.user.*;
import java.net.*;
import javax.servlet.http.*;

/**
 * Defines the interface for the Session object expected by the SessionManager..
 * 
 * @version	$Revision: 1.16 $
 * @author	Shawn McMurdo
 */
public interface Session {
    /**
     * Obtain the user associated with this session.
     * 
     * @return The user object or <CODE>null</CODE> if the
     * session is not associated with a <CODE>User</CODE> objects.
     */
    public User getUser();
 
    /**
     * Set the user associated with this session.  This will register the
     * user with the <CODE>SessionManager</CODE>. <P>
     * 
     * If it is neccessary to prevent a user from logging on multiple times,
     * this can be accomplished by synchronizing on the
     * <CODE>Sessionmanager</CODE> object and enquiring about the number of
     * users associated with a session.  It is then possible to delete other
     * sessions before adding a new session.
     *
     * @param user
     *   The user object to associate with the session.
     * @exception SessionException
     *   If the user cannot be set.
     * @see
     *   SessionManager#getSessionKeys(User)
     */
    public void setUser(User user) throws SessionException;

    /**
     * Remove the user association with this session.  This will unregister the
     * user with the <CODE>SessionManager</CODE>.
     * @exception SessionException
     *   If the user cannot be cleared.
     */
    public void clearUser() throws SessionException;

    /**
     * Obtain the unique key associated with this session.
     *
     * @return A String containing the key for this session.
     */
    public String getSessionKey();

    /**
     * Obtain the session manager associated with this session.
     *
     * @return The session manager object.
     */
    public SessionManager getSessionManager();

    /**
     * Obtain the application specific data for this session.
     *
     * @return A SessionData object containing application specific
     *   data for this session.
     */
    public SessionData getSessionData();

    /**
     * Returns true if the session is new.  A session is new if it has
     * been created but a client cookie was never used to reference it.
     * In other words, the cookie associated with the session was
     * never submitted by a client.
     *
     * @return true if the session is new.
     */
    public boolean isNew();


    /**
     *
     *
     */

     public HttpSession getHttpSession();

}



