/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: SessionThread.java,v 1.2 2000/01/29 07:02:15 markd Exp $
 *-----------------------------------------------------------------------------
 */

package com.lutris.appserver.server.session;


/**
 * Represents a combination of a thread and a session key.
 * A session must be associated with a thread of execution
 * before a reference to the session can be obtained by the
 * application.  This object represents the existing thread
 * to session association.
 *
 * @version $Revision: 1.2 $
 * @author  Kyle Clark
 */
public class SessionThread {

    public Thread thread;
    public String sessionKey;

    /**
     * Creates an instance of a session-thread association.
     *
     * @param thread the thread to associate with a session.
     * @param sessionKey the session key.
     */
    public SessionThread(Thread thread, String sessionKey) {
        this.thread = thread;
        this.sessionKey = sessionKey;
    }

    /**
     * Compares equality of two objects.
     *
     * @param sessionThread the reference object with which
     *   compare.
     */
    public boolean equals(Object sessionThread) {
        if (!(sessionThread instanceof SessionThread)) {
            return false;
        }
        SessionThread s = (SessionThread)sessionThread;
        return (thread.equals(s.thread)
                && sessionKey.equals(s.sessionKey));
    }

    /**
     * Returns string representation.
     */
    public String toString() {
        return thread.toString() + "-" + sessionKey;
    }

    /**
     * Returns the hashcode for this object.
     */
    public int hashCode() {
        return sessionKey.hashCode();
    }
}

