/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: StandardSession.java,v 1.26 2000/02/21 21:21:26 peterj Exp $
 *-----------------------------------------------------------------------------
 */

package com.lutris.appserver.server.session;

import com.lutris.appserver.server.*;
import com.lutris.appserver.server.user.*;
import java.net.*;
import javax.servlet.http.HttpSession;

/**
 * Defines the interface for the Session object expected
 * by the StandardSessionManager.
 * 
 * @version	$Revision: 1.26 $
 * @author	Kyle Clark
 */
public interface StandardSession extends Session {

    /**
     * Set the "last used" timestamp to the current time, resetting the
     * idle period.
     */
    public void touch();

    /**
     * Obtain the creation time for this object.  The time is in
     * milliseconds since Midnight, Jan 1, 1970 (epoch).
     *
     * @return The creation time since epoch for this object.
     */
    public long getTimeCreated();

    /**
     * Obtain the time of last use for this object.  The time is in
     * milliseconds since Midnight, Jan 1, 1970 (epoch).
     *
     * @return The time of last use since epoch for this object.
     */
    public long getTimeLastUsed();

    /**
     * Obtain the time of expiry for this object.  The time is in
     * milliseconds since Midnight, Jan 1, 1970 (epoch).
     * Returns zero (or negative) if there is no expiration date.
     * Note: this is a maximum lifespan for the session, regardless of activity.
     *
     * @return The time of expiry since epoch for this object.
     */
    public long getTimeExpires();

    /**
     * Set the time of expiry for this object.  The time is in
     * milliseconds since Midnight, Jan 1, 1970 (epoch).
     * Set this value to zero (or less) to indicate that the session does not
     * have a maximum age.
     *
     * @param timeLastUsed The time of expiry since epoch.
     */
    public void setTimeExpires(long timeExpires);

    /**
     * Obtain the maximum idle time for this object. Zero (or negative)
     * indicates that sessions may be idle indefinetly.
     *
     * @return The maximum number of milliseconds this session
     *      may be idle.
     */
    public long getMaxIdleTime();

    /**
     * Set the maximum idle time for this object. Set this to zero
     * (or negative) to disable idle checking.
     *
     * @param maxIdleTime The maximum number of milliseconds this
     *  session may be idle, or zero (or negative) to allow sessions to be idle
     *  indefinetly.
     */
    public void setMaxIdleTime(long maxIdleTime);

    /**
     * Obtain the maximum idle time when a <CODE>User</CODE> object
     * is not associated with the session. Zero (or negative) indicates that
     * sessions may be idle indefinetly.
     *
     * @return The maximum number of milliseconds this session
     *      may be idle.
     */
    public long getMaxNoUserIdleTime();

    /**
     * set the maximum idle time when a <CODE>User</CODE> object
     * is not associated with the session. Set this to zero (or negative) to
     * disable idle checking.
     *
     * @param maxIdleTime The maximum number of milliseconds this
     *      session may be idle.
     */
    public void setMaxNoUserIdleTime(long maxIdleTime);

    /**
     * Expose the HttpSession interface
     */
    public HttpSession  getHttpSession() ;


}



