/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: StandardSessionUserTable.java,v 1.12 2000/01/29 07:02:16 markd Exp $
 *-----------------------------------------------------------------------------
 */

package com.lutris.appserver.server.session;
import com.lutris.appserver.server.Enhydra;
import java.util.Hashtable;
import java.util.Enumeration;
import com.lutris.logging.*;
import com.lutris.appserver.server.user.User;

/**
 * Table used by StandardSessionManager to cross reference <CODE>User</CODE>
 * objects and sessions.<p>
 *
 * N.B.  It is assumed that this interface is only used by
 * StandardSessionManager and that it is responsible for
 * providing high level locks instead of synchronizing
 *
 * @version	$Revision: 1.12 $
 * @author      Mark Diekhans
 * @author      Kyle Clark
 * @see         BasicSessionUserTable
 * @see         PagedSessionUserTable
 * @see         com.lutris.appserver.server.session.persistent.PersistentSessionUserTable
 */
public interface StandardSessionUserTable {

    /**
     * Add a session key to the user to session xref table.
     *
     * @param session
     *   The session key.  
     * @param user
     *   the user to associated with the session key.
     * @exception SessionException if an error occurs.
     */
    void add(String sessionKey, User user) throws SessionException;

    /**
     * Remove a session from the user to session mapping table.
     * If the session is not it the table, it is ignored.
     *
     * @param sessionKey The session object, with the user already
     * filled in. 
     * @exception SessionException if an error occurs.
     */
    void remove(String sessionKey, User user) throws SessionException;

    /**
     * Removes all references to a session from the user session table.
     *
     * @param sessionKey The session key.
     */
    void remove(String sessionKey) throws SessionException;

    /**
     * Get the number of sessions for a user.
     *
     * @param user The user object to check for.
     * @return The count of the number of sessions associated with this
     *  user.
     * @exception SessionException if an error occurs.
     */
    int numSessions(User user) throws SessionException;

    /**
     * Returns the session keys associated with a particular user.
     *
     * @param user The user object to check for.
     * @return An enumeration of the session keys associated
     *   with the user.
     * @exception SessionException if an error occurs.
     */
    Enumeration getSessionKeys(User user) throws SessionException;

    /**
     * Shutdown this session user table as required.  The session
     * user table should not be used after this method has been called
     */
    public void shutdown();

}
