/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: KeysQuery.java,v 1.2 2000/01/29 07:02:16 markd Exp $
 *-----------------------------------------------------------------------------
 */

package com.lutris.appserver.server.session.persistent;

import com.lutris.appserver.server.sql.*;
import com.lutris.appserver.server.session.*;
import java.util.*;
import java.sql.*;

/**
 * Returns an enumeration of all the session keys.
 *
 * @version $Revision: 1.2 $
 * @author  Kyle Clark
 */
class KeysQuery implements Query {

    private String sessionKey;

    KeysQuery() {
    }

    /**
     * Method to query objects from the database.
     *
     * @param conn Handle to database connection.
     * @exception java.sql.SQLException If a database access error occurs. 
     */
    public ResultSet executeQuery(DBConnection conn)
        throws SQLException {
        String sql = "select sessionKey from " + PersistentSessionHome.dbTableName;
        PreparedStatement stmt = conn.prepareStatement(sql);
        return conn.executeQuery(stmt, sql);
    }

    /**
     * Method to get next object from query results.  
     *
     * @param rs
     *   result set from which the session key will be instantiated.
     * @exception java.sql.SQLException
     *   if a database access error occurs. 
     */
    public Object next(ResultSet rs) throws SQLException {
        Vector v = new Vector();
        while (rs.next()) {
            v.addElement(rs.getString("sessionKey"));
        }
        return v.elements();
    }

}
