/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: PersistentSession.java,v 1.4 2000/01/29 07:02:16 markd Exp $
 *-----------------------------------------------------------------------------
 */

package com.lutris.appserver.server.session.persistent;

import com.lutris.appserver.server.session.*;
import com.lutris.appserver.server.user.User;
import com.lutris.appserver.server.*;
import java.io.Serializable;

/**
 * A serializable version of BasicSession that
 * can be written to persistent store.
 *
 * @version $Revision: 1.4 $
 * @author  Kyle Clark
 */
public class PersistentSession extends PagedSession {

    transient PersistentSessionHome sessionHome;

    /**
     * Need the following constructor in order to serialize?
     */
    public PersistentSession() {
    }
    
    /**
     * Construct a new session.  Only called by <CODE>PersistentSessionHome</CODE>.
     *
     * @param sessionManager The session manager that will manager this session.
     * @param sessionKey The unique session key associated with the session.
     */
    protected PersistentSession(StandardSessionManager sessionManager,
                                String sessionKey,
                                PersistentSessionHome sessionHome) {
        super(sessionManager, sessionKey);
        this.sessionHome = sessionHome;
    }

    /**
     * Ensures that the user associated with the session is serializable.<p>
     * 
     * @param user
     *   the user object to associate with the session.
     * @exception SessionException
     *   if the user cannot be associated with the session.
     */
    public void setUser(User user) throws SessionException {
        if (!(user instanceof Serializable)) {
            throw new SessionException("Persistent session user must be serializable.");
        }
        super.setUser(user);
        // Need to synchronize any changes to user since
        // the session user table is maintained in the database.
        DBUtil.dbUpdate(this, sessionHome.getDatabaseName());
    }

    /**
     * Called when the session is read back into memory.
     * Restores the (transient) session manager.
     *
     * @param mgr
     *   the session manager.
     */
    void restoreSessionManager(StandardSessionManager mgr) {
        this.sessionManager = mgr;
    }

    /**
     * Called when the session is read back into memory.
     * Restores the (transient) session manager.
     *
     * @param mgr
     *   the session manager.
     */
    void restoreSessionHome(PersistentSessionHome home) {
        this.sessionHome = home;
    }

}




