/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: SessionDeleteDO.java,v 1.2 2000/01/29 07:02:16 markd Exp $
 *-----------------------------------------------------------------------------
 */

package com.lutris.appserver.server.session.persistent;

import com.lutris.appserver.server.sql.*;
import com.lutris.appserver.server.session.*;
import java.util.*;
import java.sql.*;
import java.io.*;

/**
 * Database interface that is used to delete a session
 * from the database.
 *
 * @version $Revision: 1.2 $
 * @author  Kyle Clark
 */
public class SessionDeleteDO implements Transaction {

    /**
     * The session represented by this object.
     */
    private String sessionKey;

    /**
     * @param sessionKey the key identifying the session
     *   that should be deleted.
     */
    protected SessionDeleteDO(String sessionKey) {
        this.sessionKey = sessionKey;
    }

    /**
     * Inserts the session into the database.
     *
     * @param conn Database connection.
     * @exception java.sql.SQLException If a database access error
     *  occurs.
     */
    public void executeInsert(DBConnection conn)
        throws SQLException {
        throw new Error("not supported");
    }

    /**
     * If this object's <code>executeInsert</code> method was
     * called then <code>finalizeInsert</code> is called with
     * the status of the database transaction.  This method
     * allows the data object to perform any post processing
     * if the transaction succeeded or failed.
     *
     * @param success true if the transaction succeeded
     *   and this object was successfully inserted into the database.
     */
    public void finalizeInsert(boolean success) {
    }

    /**
     * Method to update contents of object in database.
     *
     * @param conn Database connection.
     * @exception java.sql.SQLException If a database access error
     *  occurs.
     */
    public void executeUpdate(DBConnection conn)
        throws SQLException {
        throw new Error("not supported");
    }

    /**
     * If this object's <code>executeUpdate</code> method was
     * called then <code>finalizeUpdate</code> is called with
     * the status of the database transaction.
     * For instance the data object may want to
     * increment its version number once it has successfully
     * been commited to the database.  
     *
     * @param success true if the transaction succeeded
     *   and this object was successfully updated in the database.
     */
    public void finalizeUpdate(boolean success) {
    }

    /**
     * Method to delete an object from the database.
     *
     * @param conn Database connection.
     * @exception java.sql.SQLException If a database access error
     *  occurs.
     */
    public void executeDelete(DBConnection conn)
        throws SQLException {
        String sql = "delete from " + PersistentSessionHome.dbTableName 
            +  " where sessionKey = ?";
        PreparedStatement stmt = conn.prepareStatement(sql);
        stmt.setString(1,sessionKey);
        conn.executeUpdate(stmt, sql);
    }

    /**
     * If this object's <code>executeDelete</code> method was
     * called then <code>finalizeDelete</code> is called with
     * the status of the database transaction.
     *
     * @param success true if the transaction succeeded
     *   and this object was successfully deleted from the
     *   database.
     */
    public void finalizeDelete(boolean success) {
        // ignore?
    }

}
