/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: Welcome.java,v 1.1 2000/03/08 02:33:41 markd Exp $
 *-----------------------------------------------------------------------------
 */

package com.lutris.appserver.welcome.presentation;

import com.lutris.xml.xmlc.*;
import com.lutris.xml.xmlc.html.*;
import com.lutris.appserver.server.httpPresentation.*;
import com.lutris.appserver.server.session.*;
import com.lutris.util.*;
import java.io.*;
import org.w3c.dom.*;
import org.w3c.dom.html.*;

/**
 * Output the welcome page.
 */
public class Welcome implements HttpPresentation {
    /*
     * Used to keep track of the total number of times this page has been
     * served.
     */
    private static int counter = 0;

    /*
     * Set counters in the page.
     */
    public void setCounters(Session session,
                            WelcomeHTML htmlObj)
        throws KeywordValueException {
        /*
         * Fill the tag that holds the total number of times this page has
         * been served, to all users. We use a static variable to hold this
         * information.
         */
        counter++;
        htmlObj.setTextTotalHits(Integer.toString(counter));

        /*
         * Fill in the tag that holds the number of times this user
         * has been served this page. Since this is a per-user thing, 
         * we use session data. The first time a user loads this page,
         * the session data will not contain the counter, treat this
         * as if the counter was zero.
         */
        SessionData sessionData = session.getSessionData();
        String userCounterString = sessionData.getString("counter");
        int userCounter = 0;
        if (userCounterString != null) {
            userCounter = Integer.parseInt(userCounterString);
        }
        userCounter++;
        userCounterString = Integer.toString(userCounter);
        sessionData.set("counter", userCounterString);

        htmlObj.setTextUserHits(userCounterString);
    }

    /**
     * Entry.
     */
    public void run(HttpPresentationComms comms)
        throws HttpPresentationException {
        try {
            WelcomeHTML htmlObj
                = (WelcomeHTML)comms.xmlcFactory.create(WelcomeHTML.class);
            setCounters(comms.session, htmlObj);
            comms.response.writeHTML(htmlObj);
        } catch (KeywordValueException except) {
            throw new HttpPresentationException(except);
        }
    }   
}
