/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: DebugResponse.java,v 1.11 2000/01/29 07:02:17 markd Exp $
 *-----------------------------------------------------------------------------
 */





package com.lutris.http.debug;

import java.util.Enumeration;
import javax.servlet.http.Cookie;

/**
 * Object used to access HTTP response data for debugging purposes.
 * 
 * @author	Paul Morgan
 * @since	LBS1.7
 * @version	$Revision: 1.11 $
 */
public interface DebugResponse {
    /**
     * Returns the size of the response entity data, or -1 if not known.
     */
    public int getContentLength();

    /**
     * Returns the Internet Media Type of the response entity data, or null
     * if not known.
     */
    public String getContentType();

    /**
     * Returns the status code for the response.
     */
    public int getStatusCode();

    /**
     * Returns the status message for the response.
     */
    public String getStatusMessage();

    /**
     * Returns an array of cookies to be set by this response.
     *
     * @return The array of cookies found in this response.
     */
    public Cookie[] getCookies();

    /**
     * Returns the values of the specified header for the response as
     * an array of strings, or a 0 length array if the named header does
     * not exist.
     *
     * @param name the case-insensitive header field name
     */
    public String getHeader(String name);

    /**
     * Returns an array of strings representing the header names
     * for this response. This does not have return cookies - use
     * getCookies().
     */
    public Enumeration getHeaderNames();

    /**
     * Returns the number of bytes associated with the response.
     */
    public int getTotalBytes();

    /**
     * Returns the data written to the output stream associated with this
     * request, or null if that data was not kept. Due to the potential
     * size of the data, this is an optional feature.
     */
    public String getResponseData();
}
