/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *-----------------------------------------------------------------------------
 * $Id: ThreadResultsCollectorImpl.java,v 1.3.2.1 2000/03/31 19:04:11 mikew Exp $
 *-----------------------------------------------------------------------------
 */

package org.enhydra.httpServerTest.client;

import java.util.Enumeration;
import java.util.Vector;

/**
 * This class provides a basic implementation of the ThreadResultsCollector
 * interface.
 * 
 * @see org.enhydra.httpServerTest.client.ThreadResultsCollector
 *
 * @author Mike Ward
 **/
public class ThreadResultsCollectorImpl
    implements ThreadResultsCollector {
    
    /**
     * A repository for all failed assertions.
     **/
    private Vector failedAsserts = null;

    /**
     * The state of failed assertions.
     **/
    private boolean failedAssertsState = false;

    /**
     * Constructor initializes a new failed assertion vector.
     **/
    public ThreadResultsCollectorImpl() {
	failedAsserts = new Vector();
    }

    /**
     * This function adds any failed assertion to the failed assertion vector
     * and changes the failed assertion state to true.
     *
     * @param success
     *        The assertion state, only 'false' assertions are typically
     *        logged.
     * @param message
     *        The error message associated with this assesrtion.
     * @param thread
     *        The client thread making this assertion call, used to gather
     *        thread identification for error reporting.
     **/
    public void assert(boolean success, 
		       String message, 
		       BaseTestThread thread) {

	if (!success) {
	    failedAssertsState = true;
	    failedAsserts.addElement("Thread Failed! ID: " + 
				     thread.getId() +
				     " Time: " + 
				     (System.currentTimeMillis() - 
				      thread.getStartTime()) +
				     " milliseconds Message: " + message);
	}
    }

    /**
     * Returns an enumeration of the failed assertion vector.
     *
     * @return Enumeration
     *         All failed assertions.
     **/
    public Enumeration getFailedAsserts() {
	return failedAsserts.elements();
    }
    
    /**
     * The state of failed assertions, should return 'true' if assertions
     * have failed, 'false' otherwise.
     *
     * @return boolean
     *         The state of failed assertions.
     **/
    public boolean failedAssertsState() {
	return failedAssertsState;
    }
}


