/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *-----------------------------------------------------------------------------
 * $Id: FileUploadMangler.java,v 1.3.2.1 2000/03/31 19:04:22 mikew Exp $
 *-----------------------------------------------------------------------------
 */

package org.enhydra.httpServerTest.server.common;

import HTTPClient.FilenameMangler;

/**
 * This file implements the FilenameMangler to ensure that files uploaded
 * to the server are save with unique file names on the file system.
 *
 * @see HTTPClient.FilenameMangler
 * @see HTTPClient.Codecs
 *
 * @author Mike Ward
 **/
public class FileUploadMangler
    implements FilenameMangler {

    /**
     * A static counter variable that increments for every time the 
     * mangleFilename is called.  This object is synchronized on for
     * thread safty.
     **/
    public static Long fileNameCnt = new Long(0);
    
    /**
     * This function is automatically invoked by the Codecs class when
     * parsing multi-part mime encodings.  This function will produce a 
     * unique extension to the supplied file name.
     *
     * @see HTTPClient.Codecs
     *
     * @param filename
     *        The file name specified in the mime encoding.
     * @param fieldname
     *        The field name specified in the mime encoding.
     * @return String
     *         The new, unique file name.
     **/
    public String mangleFilename(String filename, 
				 String fieldname) {
 	synchronized (fileNameCnt) { 
	    fileNameCnt = new Long(fileNameCnt.longValue() + (long)1);
	    return filename + fileNameCnt.toString();
	}
    }
}

