/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: Javac.java,v 1.9 2000/01/29 07:02:19 markd Exp $
 *-----------------------------------------------------------------------------
 */





package com.lutris.appserver.server.jolt.joltc;

import java.io.*;

/**
 * Run the Java compiler as a child process and allow 
 * the filtering of stderr.  This is somewhat crudely
 * done.
 */
class Javac {
    String javacProg = "javac";

    /**
     * Construct a javac runner.  If JAVAC property is defined
     * it is used as the java compiler, otherwise "javac" is used
     */
    Javac() {
        String prog = System.getProperty("JAVAC");
        if ((prog != null) && (prog.length() > 0)) {
            javacProg = prog;
        }
    }
    
    /**
     * Monitor the running process, doing I/O filtering.
     */
    private void monProc(Process jproc,
                         OutputFilter stderrFilter) 
        throws IOException, InterruptedException {
        OutputFilterThread outMon =
            new OutputFilterThread(jproc.getInputStream(),
                                   System.out, null);
        OutputFilterThread errMon =
            new OutputFilterThread(jproc.getErrorStream(),
                                   System.err, stderrFilter);
        try {
            outMon.start();
            errMon.start();
            jproc.waitFor();
        } catch (InterruptedException except) {
            try {
                // Last ditch effort to clean up proc
                jproc.destroy();
                jproc.waitFor();
            } catch (InterruptedException drop) {
                // Already have an error...
            }
            outMon.stop();
            errMon.stop();
        } finally {
            outMon.join();
            errMon.join();
        }
        if (outMon.getException() != null) {
            throw outMon.getException();
        }
        if (errMon.getException() != null) {
            throw errMon.getException();
        }
    }

    /**
     * Run a javac process.
     *
     * @param args Arguments to pass to Javac.
     * @return Exit code of javac; or 1 if an error was detected
     *  internally.
     */
    int javac(String[] args,
              OutputFilter stderrFilter) {
        String [] cmd = new String[args.length+1];
        cmd[0] = javacProg;
        System.arraycopy(args, 0, cmd, 1, args.length);
        
        Process jproc;
        try {
            jproc = Runtime.getRuntime().exec(cmd);
            monProc(jproc, stderrFilter);
        } catch (IOException except) {
            except.printStackTrace();
            return 1;
        } catch (InterruptedException except) {
            except.printStackTrace();
            return 1;
        }
        return jproc.exitValue();
    }

    // FIX: for debugging
    public static void main(String[] args) {
        Javac javac = new Javac();
        
        int code = javac.javac(args, null);
        System.exit(code);
    }

}
