/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: JoltDebug.java,v 1.19 2000/01/29 07:02:19 markd Exp $
 *-----------------------------------------------------------------------------
 */





package com.lutris.appserver.server.jolt.joltpo;

import com.lutris.http.debug.*;

/**
 * This class generates html formatted output that
 * can be used for debugging purposes in a JOLT (.jhtml)
 * page. It displays either the request, response or both.
 * <P>
 * Insert the line:
 *
 * <pre>
 *     &lt;JOLT JAVACALL=JoltDebug.displayRequest&gt;&lt;/JOLT&gt;
 *     &lt;JOLT JAVACALL=JoltDebug.displayResponse&gt;&lt;/JOLT&gt;
 *     &lt;JOLT JAVACALL=JoltDebug.displayAll&gt;&lt;/JOLT&gt;
 * </pre>
 *
 * in a jolt page causes the appropriate information to be
 * displayed within the page.
 *
 * @see lutris.jolt.HttpDebug
 * @author Kyle Clark
 */
public class JoltDebug {
    /**
     * Display the httpRequest object.
     *
     * @param page Page to which data should be written.
     * @exception Exception Throws all exceptions.
     */
    public static void displayRequest(JoltPage page)
        throws Exception {

        page.append("<HR>\n");
        page.append(HttpDebug.getRequestDebugInfo(
			(DebugRequest)page.presentationComms.request));
    }

    /**
     * Display the httpResponse object.
     *
     * @param page Page to which data should be written.
     * @exception Exception Throws all exceptions.
     */
    public static void displayResponse(JoltPage page)
        throws Exception {

        page.append("<HR>\n");
        page.append(HttpDebug.getResponseDebugInfo(
			(DebugResponse)page.presentationComms.response));
    }

    /**
     * Display the httpRequest object.
     *
     * @param page Page to which data should be written.
     * @exception Exception Throws all exceptions.
     */
    public static void displayAll(JoltPage page)
	throws Exception {

	displayRequest(page);
	displayResponse(page);
    }
}
