/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: JoltDumpVisitor.java,v 1.9 2000/01/29 07:02:21 markd Exp $
 *-----------------------------------------------------------------------------
 */




package com.lutris.appserver.server.jolt.parser;

/**
 * The Visitor for the Jolt parser that dumps out the tree.
 *
 * @author Shawn McMurdo
 * @version $Revision: 1.9 $
 */
public class JoltDumpVisitor implements JoltParserVisitor
{
    private int indent = 0;

    private String indentString()
    {
        StringBuffer sb = new StringBuffer();
        for (int i = 0; i < indent; ++i) {
            sb.append(" ");
        }
        return sb.toString();
    }

    public Object visit(SimpleNode node, Object data)
    {
        System.out.println(indentString() + indent + " " + node +
		       ": acceptor not implemented in subclass?");
        ++indent;
        data = node.childrenAccept(this, data);
        --indent;
        return data;
    }

    public Object visit(ASTStart node, Object data)
    {
        System.out.println(indentString() + indent + " " + node);
        ++indent;
        data = node.childrenAccept(this, data);
        --indent;
        return data;
    }

    public Object visit(ASTHtmlSection node, Object data)
    {
        System.out.println(indentString() + indent + " " + node);
        ++indent;
        data = node.childrenAccept(this, data);
        --indent;
        return data;
    }

    public Object visit(ASTJoltContents node, Object data)
    {
        System.out.println(indentString() + indent + " " + node);
        ++indent;
        data = node.childrenAccept(this, data);
        --indent;
        return data;
    }

    public Object visit(ASTJoltParsedContents node, Object data)
    {
        System.out.println(indentString() + indent + " " + node);
        ++indent;
        data = node.childrenAccept(this, data);
        --indent;
        return data;
    }

    public Object visit(ASTJavadef node, Object data)
    {
        System.out.println(indentString() + indent + " " + node);
        ++indent;
        data = node.childrenAccept(this, data);
        --indent;
        return data;
    }

    public Object visit(ASTHtmldef node, Object data)
    {
        System.out.println(indentString() + indent + " " + node);
        ++indent;
        data = node.childrenAccept(this, data);
        --indent;
        return data;
    }

    public Object visit(ASTAnyCall node, Object data)
    {
        System.out.println(indentString() + indent + " " + node);
        ++indent;
        data = node.childrenAccept(this, data);
        --indent;
        return data;
    }

    public Object visit(ASTArgList node, Object data)
    {
        System.out.println(indentString() + indent + " " + node);
        ++indent;
        data = node.childrenAccept(this, data);
        --indent;
        return data;
    }

    public Object visit(ASTArg node, Object data)
    {
        System.out.println(indentString() + indent + " " + node);
        ++indent;
        data = node.childrenAccept(this, data);
        --indent;
        return data;
    }

    public Object visit(ASTBooleanConditional node, Object data)
    {
        System.out.println(indentString() + indent + " " + node);
        ++indent;
        data = node.childrenAccept(this, data);
        --indent;
        return data;
    }

    public Object visit(ASTDefinedConditional node, Object data)
    {
        System.out.println(indentString() + indent + " " + node);
        ++indent;
        data = node.childrenAccept(this, data);
        --indent;
        return data;
    }

    public Object visit(ASTMethodConditional node, Object data)
    {
        System.out.println(indentString() + indent + " " + node);
        ++indent;
        data = node.childrenAccept(this, data);
        --indent;
        return data;
    }

    public Object visit(ASTJoltHtml node, Object data)
    {
        System.out.println(indentString() + indent + " " + node);
        ++indent;
        data = node.childrenAccept(this, data);
        --indent;
        return data;
    }

    public Object visit(ASTJavaImport node, Object data)
    {
        System.out.println(indentString() + indent + " " + node);
        ++indent;
        data = node.childrenAccept(this, data);
        --indent;
        return data;
    }

    public Object visit(ASTInclude node, Object data)
    {
        System.out.println(indentString() + indent + " " + node);
        ++indent;
        data = node.childrenAccept(this, data);
        --indent;
        return data;
    }

    public Object visit(ASTSource node, Object data)
    {
        System.out.println(indentString() + indent + " " + node);
        ++indent;
        data = node.childrenAccept(this, data);
        --indent;
        return data;
    }

    public Object visit(ASTJavaCatch node, Object data)
    {
        System.out.println(indentString() + indent + " " + node);
        ++indent;
        data = node.childrenAccept(this, data);
        --indent;
        return data;
    }

    public Object visit(ASTJavaFinally node, Object data)
    {
        System.out.println(indentString() + indent + " " + node);
        ++indent;
        data = node.childrenAccept(this, data);
        --indent;
        return data;
    }

    public Object visit(ASTJoltField node, Object data)
    {
        System.out.println(indentString() + indent + " " + node);
        ++indent;
        data = node.childrenAccept(this, data);
        --indent;
        return data;
    }
}

