/*
 * @(#)AttVal.java   1.3 1999/07/30
 *
 */

package org.w3c.tidy;

/**
 *
 * Attribute/Value linked list node
 *
 * (c) 1998, 1999 (W3C) MIT, INRIA, Keio University
 * See Tidy.java for the copyright notice.
 * Derived from <a href="http://www.w3.org/People/Raggett/tidy">
 * HTML Tidy Release 26 Jul 1999</a>
 *
 * @author  Dave Raggett <dsr@w3.org>
 * @author  Andy Quick <ac.quick@sympatico.ca> (translation to Java)
 * @version 1.0, 1999/05/22
 * @version 1.0.1, 1999/05/29
 * @version 1.1, 1999/06/18 Java Bean
 * @version 1.2, 1999/07/10 Tidy Release 7 Jul 1999
 * @version 1.3, 1999/07/30 Tidy Release 26 Jul 1999
 */

public class AttVal extends Object implements Cloneable {

    public AttVal    next;
    public Attribute dict;
    public Node      asp;
    public int       delim;
    public String    attribute;
    public String    value;

    public AttVal()
    {
        this.next = null;
        this.dict = null;
        this.asp = null;
        this.delim = 0;
        this.attribute = null;
        this.value = null;
    }

    public AttVal(AttVal next, Attribute dict, int delim,
                  String attribute, String value)
    {
        this.next = next;
        this.dict = dict;
        this.asp = null;
        this.delim = delim;
        this.attribute = attribute;
        this.value = value;
    }

    public AttVal(AttVal next, Attribute dict, Node asp, int delim,
                  String attribute, String value)
    {
        this.next = next;
        this.dict = dict;
        this.asp = asp;
        this.delim = delim;
        this.attribute = attribute;
        this.value = value;
    }

    protected Object clone()
    {
        AttVal av = new AttVal();
        if (next != null) {
            av.next = (AttVal)next.clone();
        }
        if (attribute != null)
            av.attribute = new String(attribute);
        if (value != null)
            av.value = new String(value);
        av.delim = delim;
        if (asp != null) {
            av.asp = (Node)asp.clone();
        }
        av.dict =
          AttributeTable.getDefaultAttributeTable().findAttribute(this);
        return av;
    }

    public boolean isBoolAttribute()
    {
        Attribute attribute = this.dict;
        if ( attribute != null ) {
            if (attribute.attrchk == AttrCheckImpl.getCheckBool() ) {
                return true;
            }
        }

        return false;
    }

    /* ignore unknown attributes for proprietary elements */
    public Attribute checkAttribute( Lexer lexer, Node node )
    {
        Attribute attribute = this.dict;
        if ( attribute != null ) {
            /* title is vers 2.0 for A and LINK otherwise vers 4.0 */
            if (attribute == AttributeTable.attrTitle &&
                    (node.tag == TagTable.tagA || node.tag == TagTable.tagLink))
                    lexer.versions &= Dict.VERS_ALL;
            else if ((attribute.versions & Dict.VERS_XML) != 0)
            {
                if (!(lexer.configuration.XmlTags || lexer.configuration.XmlOut))
                    Report.attrError(lexer, node, this.attribute, Report.XML_ATTRIBUTE_VALUE);
            }
            else
                lexer.versions &= attribute.versions;
        
            if (attribute.attrchk != null)
                attribute.attrchk.check(lexer, node, this);
        }
        else if (!lexer.configuration.XmlTags && !(node.tag == null) && this.asp == null &&
                 !(node.tag != null && ((node.tag.versions & Dict.VERS_PROPRIETARY) != 0)))
            Report.attrError(lexer, node, this.attribute, Report.UNKNOWN_ATTRIBUTE);

        return attribute;
    }
}
