/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: KeyValuePair.java,v 1.7 2000/01/29 07:03:09 markd Exp $
 *-----------------------------------------------------------------------------
 */





package com.lutris.appserver.admin.business;


/**
 * A record that stores key/value pairs.
 * If the value of a key was origionally an array of strings, then
 * the array will be joined together into one string with newlines.
 * Any newlines in the origional strings will be turned into "\n".
 * If this has happened, the flag isArray will be set, and the
 * string should be shown to the user in a multi-line text editing box.
 * 
 * @version	$Revision: 1.7 $
 * @author	Andy John
 */
public class KeyValuePair {

    /**
     *  The name of the key. For example, if the line from the config
     *  file was "App.param1 = some_value", then this variable would
     *  be set to "App.param1". If the line was 
     *  "App.param1[] = 9.95, 14.99", then this variable would also
     *  be set to "App.param1".
     */    
    public String key;

    /**
     *  The value of the key. For example, if one line from a config
     *  file was "App.param1 = some_value", then this variable would
     *  be set to "some_value". If the line was 
     *  "App.param1[] = 9.95, 14.99", then this variable would be set
     *  to "9.95\n14.99" (where \n is a newline character).
     */    
    public String value;

    /**
     *  In the config file, was this origionally an array?
     *  This is only needed to know how to display the string. 
     *  The array will already have been turned into a single String.
     *  For example, if the line in the config file was
     *  "App.param1 = some_value" this would be false. If the line was 
     *  "App.param1[] = 9.95, 14.99", then this variable would be true.
     */
    public boolean isArray;



    /**
     *  Constructor. Only the class <CODE>ConfEditor</CODE> needs to
     *  call this.
     */
    protected KeyValuePair(String key, String value, boolean isArray) {
        this.key = key; 
        this.value = value;
        this.isArray = isArray;
    }

}



