/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: Utils.java,v 1.19.2.2 2000/04/07 12:17:28 shawn Exp $
 *-----------------------------------------------------------------------------
 */





package	com.lutris.appserver.admin.business;

import java.util.StringTokenizer;
import java.util.Enumeration;
import java.util.Properties;
import javax.servlet.Servlet;
import javax.servlet.ServletException;
import org.enhydra.servlet.servletManager.ServletStatus;
import com.lutris.appserver.server.httpPresentation.servlet.HttpPresentationServlet;
import com.lutris.appserver.server.Application;
import com.lutris.appserver.server.jolt.joltpo.JoltPage;
import com.lutris.appserver.server.session.Session;
import com.lutris.appserver.server.session.SessionData;
import com.lutris.util.KeywordValueException;
import com.lutris.multiServer.MultiServer;
import org.enhydra.servlet.ServletContainer;
import org.enhydra.servlet.servletManager.ServletManager;



/**
 * Utility methods used by the admin app.
 *
 * @version	$Revision: 1.19.2.2 $
 * @author	Andy John
 */
public class Utils
{

    /**
     * The class name for the servlet that is the root of Enhydra applications.
     */
    public static String applicationClassName =
        "com.lutris.appserver.server.httpPresentation.servlet." +
                                           "HttpPresentationServlet";


    /**
     *  Is the servlet represented by the given ServletStatus an
     *  Enhydra application or just a generic third party servlet?
     *
     * @param ss The ServletStatus retuned from the ServetManager.
     * @return true if the servlet is an Enhydra application.
     */
    public static boolean isApplication(ServletStatus ss) {
        return isApplication(ss.className);
    }

    /**
     *  Is the given class the root servlet of an Enhydra application?
     *
     * @param className The name of the servlet's class.
     * @return true if the servlet is an Enhydra application.
     */
    public static boolean isApplication(String className) {
        if (className == null)
            return false;
        return className.equals("com.lutris.appserver.server.httpPresentation.servlet.HttpPresentationServlet");
    }


    public static boolean isApplication(Servlet s) {
        return (s instanceof com.lutris.appserver.server.httpPresentation.servlet.HttpPresentationServlet);
    }

    /**
     *  Is the context represented by the given ServletStatus an
     *  Servlet 2.2 War
     *
     * @param ss The ServletStatus retuned from the ServetManager.
     * @return true if the contextis a war
     */
    public static boolean isWar(ServletStatus ss) {
        return ss.isWar;
    }




    public static Application getApplication(Servlet s) {
        if (s == null)
            return null;
        if (!isApplication(s)) {
            return null;
        }
        HttpPresentationServlet hps = (HttpPresentationServlet) s;
        return hps.getApplication();
    }

    /**
     * Convert a comma separated list back into an array.
     * No special quoting is handled, the string is simply split at
     * the commas, and a leading space is removed if present.
     *
     * @param s The string generated by <CODE>classPathToString</CODE>.
     * @return The array of strings.
     * @see com.lutris.appserver.admin.business.Utils#classPathToString
    public static String[] stringToClassPath(String s) {
        StringTokenizer stok = new StringTokenizer(s, ",");
        int num = stok.countTokens();
        String[] result = new String[num];
        for (int i=0; i<num; i++) {
            result[i] = stok.nextToken();
            if ((i > 0) && result[i].startsWith(" "))
                result[i] = result[i].substring(1);
        }
        return result;
    }
*/


    /**
     *  Turn an array of strings into a single string, by adding
     *  newlines. See <CODE>splitString()</CODE>.
     *
     * @param strings The array of strings.
     * @result The array joined into a single string.
     * @see com.lutris.appserver.admin.business.Utils#splitString
     */
    public static String joinArray(String[] strings) {
        String result = "";
        if (strings.length > 0)
            result += strings[0];
        for (int i=1; i<strings.length; i++)
            result += "\n" + strings[i];
        return result;
    }


    /**
     *  Breaks a string up into pieces, and returns an array of the
     *  pieces. The string is chopped at newlines (<CODE>\n</CODE>
     *  or <CODE>\r</CODE>) or <CODE>, ; : </CODE>, and whitespace 
     *  is trimmed off the ends of each piece. See <CODE>joinArray()</CODE>.
     *
     * @param string The string to chop up.
     * @return An array of pieces of the string.
     * @see com.lutris.appserver.admin.business.Utils#joinArray
     */
    public static String[] splitString(String string) {
        if (string == null)
            return null;
        StringTokenizer stok = new StringTokenizer(string, ",;:\n\r");
        int num = stok.countTokens();
        String[] results = new String[num];
        for (int i=0; i<num; i++)
            results[i] = stok.nextToken();
        return results;
    }



    /**
     *  Convert a Properties object into a newline separated string.
     */
    public static String propertiesToString(Properties props) {
        String result = "";
        if (props == null)
            return result;
        boolean first = true;
        Enumeration e = props.propertyNames();
        while (e.hasMoreElements()) {
            String key = (String) e.nextElement();
            String value = props.getProperty(key);
            if (value == null)
                continue;
            if (!first)
                result += "\n";
            result += key + "=" + value;
            first = false;
        }
        return result;
    }


    /**
     *   Convert the a newline-separated string into a Properties
     *   object.
     */
    public static Properties stringToProperties(String s) {
        Properties theProps = new Properties();
        if (s == null)
            return theProps;
        StringTokenizer pairs = new StringTokenizer(s, "\n\r");
        while (pairs.hasMoreTokens()) {
            String pair = pairs.nextToken();
            if (pair.startsWith(" "))
                pair = pair.substring(1);
            int i = pair.indexOf("=");
            if (i == -1)
                continue;
            String key = pair.substring(0, i).trim();
            String value = pair.substring(i + 1).trim();
            theProps.put(key, value);
        }
        return theProps;
    }


    /**
     * Compare two Properties objects to see if they are different.
     * Returns true if they hold the same keys and values.
     */
    public static boolean compareProperties(Properties p1, Properties p2) {
        /*
         * First compare size.
         */
        Enumeration e = p1.propertyNames();
        int p1Size = 0;
        while (e.hasMoreElements()) {
            p1Size++;
            e.nextElement();
        }
        e = p2.propertyNames();
        int p2Size = 0;
        while (e.hasMoreElements()) {
            p2Size++;
            e.nextElement();
        }
        if (p1Size != p2Size)
            return false;
        /*
         * Now compare p2 against p1.
         */
        e = p1.propertyNames();
        while (e.hasMoreElements()) {
            String key = (String) e.nextElement();
            String val1 = p1.getProperty(key);
            String val2 = p2.getProperty(key);
            if ((val1 == null) && (val2 == null))
                continue;
            if ((val1 == null) || (val2 == null))
                return false;
            if (!val1.equals(val2))
                return false;
        }
        return true;
    }
    /*
     * Given a symbolic id string, look up the servlet. Returns null if
     * not found, or not currently running.
     * DO NOT CALL SERVICE() ON THE SERVLET.
     */
    public static Servlet getServlet(String servletID) {
	ServletContainer sc = (ServletContainer)
		MultiServer.getService("ServletContainer");
        ServletManager srvltMgr = sc.getServletManager();
        if (srvltMgr == null)
            return null;
        ServletStatus ss = srvltMgr.getStatus(servletID);
        if (ss == null)
            return null;
        if (!ss.running)
            return null;
        Servlet target = null;
        try {
            target = srvltMgr.get(servletID, false);
        } catch (ServletException se) {
            return null;
        }
        return target;
    }
}

