/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: RemoteControl.java,v 1.10 2000/02/27 05:06:09 shawn Exp $
 *-----------------------------------------------------------------------------
 */




package com.lutris.appserver.admin.presentation;

import java.net.*;
import java.io.*;
import java.util.Vector;
import com.lutris.appserver.admin.business.*;
import com.lutris.multiServer.MultiServer;
import org.enhydra.servlet.ServletContainer;
import org.enhydra.servlet.servletManager.ServletManager;
import org.enhydra.servlet.servletManager.ServletStatus;
import javax.servlet.ServletException;
import com.lutris.http.*;
import com.lutris.appserver.server.httpPresentation.*;

/**
 * This is an http presentation object, designed for communicating with
 * another program. This object starts and stops servlets.<P>
 * 
 * There is one required argument, <CODE>action</CODE>. It must have
 * one of three values: list, start or stop. For start and stop, an
 * additional argument <CODE>id</CODE> is required. <P>
 * 
 * The input is assumed to be HTTP, with URL encoded arguments.
 * The output will be HTTP, with the mime type "text/plain". There will
 * be an HTTP response code, and HTTP headers (perhaps a session
 * cookie). Inside the body of the response is the machine readable text.<P>
 *
 * Expected query string inputs: <BR>
 *     <CODE>action</CODE>	One of: <CODE>start</CODE>, 
 *              <CODE>stop</CODE> or <CODE>list</CODE>.<BR>
 *     <CODE>id</CODE>  The name of the servlet to stop or start.
 *        Not requred if <CODE>action</CODE> = <CODE>list</CODE>.
 * 
 * @author Andrew John
 * @version $Revision: 1.10 $
 */
public class RemoteControl implements HttpPresentation {

    public void run(HttpPresentationComms comms)
            throws IOException, Exception {
        //
        // Get the action from the query string.
        //
        String action = comms.request.getParameter("action");
        //
        // Get ready 
        //
        comms.response.setContentType("text/plain");
        HttpPresentationOutputStream out = comms.response.getOutputStream();
	ServletContainer sc = (ServletContainer)
		MultiServer.getService("ServletContainer");
        ServletManager sm = sc.getServletManager();
        if ((sm == null) || (action == null)) {
            out.println("ERROR");
            out.flush();
            return;
        }
        //
        // Switch off the action requested.
        //
        if (action.equalsIgnoreCase("list")) {
            String[] srvIDs = sm.getServletIDs();
            for (int i=0; i<srvIDs.length; i++) {
                ServletStatus ss = sm.getStatus(srvIDs[i]);
                if (ss == null)
                    continue; 
                if (ss.running)
                    out.println(srvIDs[i] + " RUNNING");
                else
                    out.println(srvIDs[i] + " STOPPED");
            }
        } else if (action.equalsIgnoreCase("start")) {
            String id = comms.request.getParameter("id");
            if (id == null) {
                out.println("ERROR");
                out.flush();
                return;
            }
            try {
                sm.start(id);
            } catch (ServletException e) {
                out.println("ERROR");
                out.flush();
                return;
            }
            EnhydraAdmin.setServletChannelStatus(id, true);
            out.println("OK");
        } else if (action.equalsIgnoreCase("stop")) {
            String id = comms.request.getParameter("id");
            if (id == null) {
                out.println("ERROR");
                out.flush();
                return;
            }
            EnhydraAdmin.setServletChannelStatus(id, false);
            try {
                sm.stop(id);
            } catch (ServletException e) {
                out.println("ERROR");
                out.flush();
                return;
            }
            out.println("OK");
        }
    out.flush();
    }
}

