
/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: MonitorChart.java,v 1.7 2000/01/29 07:03:12 markd Exp $
 *-----------------------------------------------------------------------------
 */





/* This file was created and edited with tabstops set to 8.
 * If you are using "vi" to edit this file, enter the command:
 * 
 *        :set ts=8
 *
 * to set the tabstops to 8.
 */
package com.lutris.appserver.admin.presentation.monitor.gui;


import java.awt.*;
import java.util.*;
import jclass.chart.*;


/**
 * This class is a subclass of the KLG JClass JCChart object.
 * It sets some values that all the charts on the Monitor
 * panel will want.  It also has utility functions they use.
 */
class MonitorChart
extends JCChart
{
    boolean dataLineColorSet = false;
    boolean peakLineColorSet = false;


    MonitorChart() {
	super();

        this.getChartArea().getXAxis(0).setAnnotationMethod(
            JCAxis.TIME_LABELS);
        this.getChartArea().getXAxis(0).setAnnotationRotation(
            JCAxis.ROTATE_90);
        //this.getChartArea().getXAxis(0).setTimeFormat11("yyyy.MM.dd G 'at' hh:mm:ss a z");
        this.getChartArea().getXAxis(0).setTimeFormat11("h:mm a");
        //this.getChartArea().getXAxis(0).setTimeAnnotationLocale();

	this.getLegend().setIsShowing(true);
	this.getLegend().setOrientation(JCLegend.HORIZONTAL);
	this.getLegend().setAnchor(JCLegend.SOUTH);
	this.getLegend().setBorderType(jclass.base.Border.ETCHED_IN);
	this.getLegend().setBorderWidth(MonitorPanel.LEGEND_BORDER_WIDTH);
    }


    void setChartAxisBounds() {

	MonitorDataSource dataSource =
		(MonitorDataSource)(getDataView(0).getDataSource());

	double xMin = 0;
	double xMax = 3600;
	double yMin = 0;
	double yMax = 100;

	if (dataSource != null) {

	    Vector row = dataSource.getRow(0);

	    if ((row != null) && (row.size() > 0)) {
		xMin = ((Double)(row.firstElement())).doubleValue();
	    }
	    if ((row != null) && (row.size() > 0)) {
		xMax = ((Double)(row.lastElement())).doubleValue();
	    }

	    yMin = 0;

	    /* Find the maximum Y value.  Set yMax to the
	     * first element in the list to start with, and
	     * then compare it to all the other elements.
	     */

	    row = dataSource.getRow(1);
	    if ((row != null) && (row.size() > 0)) {
		yMax = ((Double)(row.firstElement())).doubleValue();
	    }

	    for (Enumeration elements = row.elements();
		 elements.hasMoreElements();) {
		double value = ((Double)(elements.nextElement())).doubleValue();

		if (value > yMax) {
		    yMax = value;
		}
	    }

	    if (dataSource.getMax() > yMax) {
		yMax = dataSource.getMax();
	    }
	}

        this.getChartArea().getXAxis(0).setMin(xMin);
        this.getChartArea().getXAxis(0).setMax(xMax);
        this.getChartArea().getYAxis(0).setMin(yMin);
        this.getChartArea().getYAxis(0).setMax(yMax);
    }

 
    /**
     * Set the line colors.
     */
    void setLineColors() {

	if ((this.getDataView(0).getNumSeries() > 0) &&
	    (dataLineColorSet == false)) {

	    /* The data we are displaying has been initialized,
	     * so set its line color.
	     */
	    this.getDataView(0).getSeries(0).getStyle().
		setLineColor(Color.blue);
	    //this.getDataView(0).getSeries(0).getStyle().
	    //	setSymbolShape(JCSymbolStyle.NONE);
	    this.getDataView(0).getSeries(0).getStyle().
		setSymbolColor(Color.blue);

	    dataLineColorSet = true;
	}

	if ((this.getDataView(0).getNumSeries() > 1) &&
	    (peakLineColorSet == false)) {
	    /* A peak line has been added to the data, so set its
	     * color.
	     */
	    this.getDataView(0).getSeries(1).getStyle().
		setLineColor(Color.red);
	    this.getDataView(0).getSeries(1).getStyle().
		setSymbolShape(JCSymbolStyle.NONE);

	    peakLineColorSet = true;
	}
    }
}
