
/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: PreferencesPanel.java,v 1.9 2000/01/29 07:03:12 markd Exp $
 *-----------------------------------------------------------------------------
 */





/* This file was created and edited with tabstops set to 8.
 * If you are using "vi" to edit this file, enter the command:
 * 
 *        :set ts=8
 *
 * to set the tabstops to 8.
 */
package com.lutris.appserver.admin.presentation.monitor.gui;


import java.awt.*;
import java.util.*;
import java.text.*;
import javax.swing.event.*;
import javax.swing.border.*;
import javax.swing.*;
import jclass.chart.*;


/**
 */
class PreferencesPanel
extends JPanel
implements DynamicPanel, ChangeListener {

    private static final String UPDATE_PANEL_TITLE = "Update Interval";

    MonitorPanel monitorPanel;
    JSlider updateIntervalSlider;
    JPanel updatePanel;
    TitledBorder updatePanelBorder;


    PreferencesPanel(MonitorPanel newMonitorPanel) {
        super(new GridBagLayout());

	monitorPanel = newMonitorPanel;

	updatePanel = new JPanel(new GridBagLayout());
	updatePanel.setMinimumSize(new Dimension(300, 80));
	
	GridBagConstraints gc = new GridBagConstraints();
	gc.gridx = 0;
	gc.gridy = 0;
	//gc.weightx = 1;
	//gc.fill = GridBagConstraints.HORIZONTAL;
	gc.insets = new Insets(MonitorPanel.GRAPH_PANEL_INSET_TOP,
			       MonitorPanel.GRAPH_PANEL_INSET_LEFT,
			       MonitorPanel.GRAPH_PANEL_INSET_BOTTOM,
			       MonitorPanel.GRAPH_PANEL_INSET_RIGHT);
	add(updatePanel, gc);

	updatePanelBorder = new TitledBorder(UPDATE_PANEL_TITLE+" = "+
	monitorPanel.getUpdateIntervalInSeconds()+" seconds");
	updatePanel.setBorder(updatePanelBorder);

	updateIntervalSlider = new JSlider(MonitorPanel.UPDATE_INTERVAL_MIN,
					   MonitorPanel.UPDATE_INTERVAL_MAX,
				   monitorPanel.getUpdateIntervalInSeconds());
	/*
	updateIntervalSlider.setPaintTicks(true);
	updateIntervalSlider.setMajorTickSpacing(30);
	updateIntervalSlider.setMinorTickSpacing(5);
	updateIntervalSlider.setPaintLabels(true);
	updateIntervalSlider.setSnapToTicks(true);

	updateIntervalSlider.getLabelTable().put(new Integer(10),
						 new JLabel("XX"));
	*/

	updateIntervalSlider.addChangeListener(this);

	gc = new GridBagConstraints();
	gc.gridx = 0;
	gc.gridy = 0;
	gc.weightx = 1;
	gc.fill = GridBagConstraints.HORIZONTAL;
	updatePanel.add(updateIntervalSlider, gc);
    }


    public void stateChanged(ChangeEvent e) {

	if (e.getSource() == updateIntervalSlider) {

	    if (updateIntervalSlider.getValueIsAdjusting() == true) {

		updatePanelBorder.setTitle(UPDATE_PANEL_TITLE+" = "+
		updateIntervalSlider.getValue()+" seconds");
		updatePanel.repaint();

		/* Don't set the update interval until the user
		 * stops dragging it.
		 */
		return;
	    }

	    System.out.println("Setting interval to "+
		updateIntervalSlider.getValue()+" seconds.");

	    monitorPanel.setUpdateIntervalInSeconds(
		updateIntervalSlider.getValue());
	}

    }


    public void startUpdate() {
    }


    public void stopUpdate() {
    }


    public void setUpdateIntervalInSeconds(int updateIntervalInSeconds) {
    }
}
