
/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: RequestsResponse.java,v 1.11 2000/01/29 07:03:12 markd Exp $
 *-----------------------------------------------------------------------------
 */





package com.lutris.appserver.admin.presentation.monitor.io;

import java.util.*;
import java.io.*;

/**
 * This object is sent in response to a RequestsRequest object that
 * the Monitor applet sent to the MonitorDataServer.
 * <P></P>
 * We probably should have a base class that all response objects
 * are subclassed from.  (Similar to the way we have a BaseRequest object.)
 */
public class RequestsResponse
implements Serializable {

    /**
     * This is the total number of requests that have been
     * made by an application since the Multiserver started keeping
     * track of them.
     */
    public long total;


    /**
     * This is the number of requests that have been
     * made over the last time interval by an application.
     * <P></P>
     * The length of the time interval is stored in
     * this object's timeIntervalInSeconds member data.
     * For example, if timeIntervalInSeconds is 60, and
     * current is 25, that means that there were 25 requests
     * over the last 60 second interval that was recorded.
     */
    public int current;


    /**
     * This is the maximum number of requests that have been
     * made over any time interval by an application since the
     * Multiserver started keeping track of them.
     * <P></P>
     * The length of the time interval is stored in
     * this object's timeIntervalInSeconds member data.
     */
    public int max;


    /**
     * This is the when the max value occurred.
     * This value is milliseconds since January 1, 1970 GMT.
     */
    public Calendar maxTime;


    /**
     * This is the length of the time interval in seconds.
     * i.e. The data being collected is at this granularity.
     */
    public int timeIntervalInSeconds;


    /**
     * This array contains the actual data values.
     * These are the graph data point Y values.
     * Each value in this values array corresponds to
     * a time value in the times array.
     *
     * i.e. the number of requests that the application
     * made over a time interval.
     */
    public int[] values;


    /**
     * This is the time of the first data point in the
     * timeValues array.  The values in the timeValues
     * array are offsets in seconds from this base time.
     */
    public Calendar baseTime;


    /**
     * This array contains the times that the data values
     * were collected.  These are the graph data point X values.
     * The values in this array are actually a number of
     * seconds offset from baseTime.
     * Each value in this times array corresponds to
     * a data value in the values array.
     *
     * For example, if data is collected every 5 minutes,
     * the first value in this array would be 0, and the
     * second value would be 300, the third 600, etc.
     */
    public int[] times;

    public String toString() {

	String returnValue =
		"total("+total+") current("+current+") max("+max+")";

	if (values == null) {
	    returnValue += " values(null)";
	}
	else {
	    returnValue += " values.length("+values.length+")";
	}

	if (baseTime == null) {
	    returnValue += " baseTime(null)";
	}
	else {
	    long millis = baseTime.getTime().getTime();
	    returnValue += " baseTime("+(millis / 1000)+")";
	}

	return(returnValue);
    }
}
