
/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes Enhydra software developed by Lutris
 *      Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * $Id: MonitorDataServer.java,v 1.9 2000/01/29 07:03:12 markd Exp $
 *-----------------------------------------------------------------------------
 */





/* This file was created and edited with tabstops set to 8.
 * If you are using "vi" to edit this file, enter the command:
 * 
 *        :set ts=8
 *
 * to set the tabstops to 8.
 */
package com.lutris.appserver.admin.presentation.monitorServer;

import com.lutris.appserver.admin.presentation.monitor.io.*;
import com.lutris.appserver.server.httpPresentation.*;

import java.util.*;
import java.io.*;

/**
 * A graph displayed on the Monitor applet will eventually
 * talk to this object on the server to get the data that
 * it is displaying.
 */
public class MonitorDataServer
implements HttpPresentation {

    RequestsResponse[] hackData;
    int hackCountMax = 2;

    public MonitorDataServer() {
	System.out.println("Enter MonitorDataServer constructor");

	createHackData();
    }


    /**
     * Main method to handle the requests.
     */
    public void run(HttpPresentationComms comms) throws Exception {

	System.out.println("Enter MonitorDataServer.run");

	/* Read the socket to get the request object.
	 * The request object will be a subclass of
	 * BaseRequest.
	 */
	BaseRequest request = getRequest(comms);

	if (request == null) {
	    System.out.println("Request was null.");
	    return;
	}

        processRequest(request, comms);
    }


    private BaseRequest getRequest(HttpPresentationComms comms)
	throws Exception {

	    System.out.println("Enter getRequest");

	    InputStream inStream = comms.request.getInputStream();
	    if (inStream == null) {
		System.out.println("inStream is null");
		return(null);
	    }
	
	    ObjectInputStream objInputStream = new ObjectInputStream(inStream);

	    System.out.println("Calling objInputStream.readObject()");
	    Object o = objInputStream.readObject();

	    /* Do not close the stream.  Doing this is not allowed
	     * on a HttpPresentationInputStream.
	     */
	    //objInputStream.close();

	    return((BaseRequest)o);
    }


    /**
     * Figure out what kind of data the applet is requesting
     * and return the requested data.
     */
    private void processRequest(BaseRequest request, 
				HttpPresentationComms comms)
	throws Exception {

	if (request instanceof RequestsRequest) {
            writeRequestsData((RequestsRequest)request, comms);
	}
	/*
	else if (request instanceof SessionsRequest) {
	}
	else if (request instanceof ConnectionsRequest) {
	}
	*/
	else {
	    System.err.println("I don't understand this request.");
	}
    }
 

    /**
     *  We send the applet the response message object
     *  in serialized form.
     */
    private void writeRequestsData(RequestsRequest request,
				   HttpPresentationComms comms) 
	throws HttpPresentationException {

	System.out.println("Enter MonitorDataServer.writeRequestsData");

	System.out.println("request.hackValue("+request.hackValue+")");

        RequestsResponse response = hackData[request.hackValue];

        HttpSerialized.writeSerializedObject(comms, response);
    }


    private void createHackData() {

	hackData = new RequestsResponse[hackCountMax+1];

	/****************/

	RequestsResponse response = new RequestsResponse();
	response.total = 4321;
	response.current = 1234;
	response.max = 23;
	response.maxTime = Calendar.getInstance();

	response.values = new int[3];
	response.values[0] = 3;
	response.values[1] = 1;
	response.values[2] = 5;
	response.times = new int[3];
	response.times[0] = 0;
	response.times[1] = 1800;
	response.times[2] = 3600;

	response.baseTime = Calendar.getInstance();
	response.baseTime.set(1998, 0, 1, 14, 30, 0);

	hackData[0] = response;

	/****************/

	response = new RequestsResponse();
	response.total = 4322;
	response.current = 1235;
	response.max = 25;
	response.maxTime = Calendar.getInstance();

	response.values = new int[3];
	response.values[0] = 30;
	response.values[1] = 10;
	response.values[2] = 15;
	response.times = new int[3];
	response.times[0] = 0;
	response.times[1] = 1800;
	response.times[2] = 3600;

	response.baseTime = Calendar.getInstance();
	response.baseTime.set(1998, 0, 1, 12, 0, 0);

	hackData[1] = response;

	/****************/

	response = new RequestsResponse();
	response.total = 4323;
	response.current = 1236;
	response.max = 29;
	response.maxTime = Calendar.getInstance();

	response.values = new int[3];
	response.values[0] = 60;
	response.values[1] = 70;
	response.values[2] = 85;
	response.times = new int[3];
	response.times[0] = 3500;
	response.times[1] = 7100;
	response.times[2] = 14300;

	response.baseTime = Calendar.getInstance();
	response.baseTime.set(1998, 0, 1, 11, 0, 0);

	hackData[2] = response;

	/****************/

    }
}
