/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: PrintTransactionInputStream.java,v 1.4 2000/02/21 23:50:50 markd Exp $
 */

package org.enhydra.servlet.filter;

import java.io.PrintWriter;
import java.io.IOException;
import javax.servlet.ServletInputStream;
import com.lutris.util.BytesToString;

class PrintTransactionInputStream extends ServletInputStream {

    private String              prefix;
    private PrintWriter         out;
    private ServletInputStream  realStream;

    PrintTransactionInputStream(String prefix, 
            PrintWriter out, ServletInputStream realStream) {
        this.prefix = prefix;
        this.out = out;
        this.realStream = realStream;
    }


    public int readLine(byte b[],
                     int off,
                     int len) throws IOException {
        int rc;
        try {
            rc = realStream.readLine(b, off, len);
        } catch (IOException e) {
            out.println(prefix + "readLine(byte[], " + off + 
                    ", " + len + ") threw " + e);
            throw(e);
        }
        out.println(prefix + "readLine(byte[], " + off + 
                    ", " + len + ") = " + rc);
        out.println(prefix + "readLine read: " + BytesToString.conv(b, rc));
        return rc;
    }


    public int read() throws IOException {
        int rc;
        try {
            rc = realStream.read();
        } catch (IOException e) {
            out.println(prefix + "read() threw " + e);
            throw(e);
        }
        out.println(prefix + "read() = " + rc);
        return rc;
    }
}
    

