/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: PrintTransactionOutputStream.java,v 1.4 2000/02/21 23:50:50 markd Exp $
 */

package org.enhydra.servlet.filter;

import java.io.PrintWriter;
import java.io.IOException;
import javax.servlet.ServletOutputStream;

class PrintTransactionOutputStream extends ServletOutputStream {

    private String                  prefix;
    private PrintWriter             out;
    private ServletOutputStream     realOut;

    PrintTransactionOutputStream(String prefix, PrintWriter out,
                ServletOutputStream realStream) {
        this.prefix = prefix;
        this.out = out;
        this.realOut = realStream;
    }

    public void print(String s) throws IOException {
        out.println(prefix + s);
        realOut.print(s);
    }

    public void print(boolean b) throws IOException {
        out.println(prefix + b);
        realOut.print(b);
    }

    public void print(char c) throws IOException {
        out.println(prefix + c);
        realOut.print(c);
    }

    public void print(int i) throws IOException {
        out.println(prefix + i);
        realOut.print(i);
    }

    public void print(long l) throws IOException {
        out.println(prefix + l);
        realOut.print(l);
    }

    public void print(float f) throws IOException {
        out.println(prefix + f);
        realOut.print(f);
    }

    public void print(double d) throws IOException {
        out.println(prefix + d);
        realOut.print(d);
    }


    public void println() throws IOException {
        out.println(prefix);
        realOut.println();
    }

    public void println(String s) throws IOException {
        out.println(prefix + s);
        realOut.println(s);
    }

    public void println(boolean b) throws IOException {
        out.println(prefix + b);
        realOut.println(b);
    }

    public void println(char c) throws IOException {
        out.println(prefix + c);
        realOut.println(c);
    }

    public void println(long l) throws IOException {
        out.println(prefix + l);
        realOut.println(l);
    }

    public void println(float f) throws IOException {
        out.println(prefix + f);
        realOut.println(f);
    }

    public void println(double d) throws IOException {
        out.println(prefix + d);
        realOut.println(d);
    }

    public void write(int n) {
        try {
            realOut.print(n);
        } catch (IOException e) {
            out.println(prefix + "write(" + n + ") threw " + e);
            out.println(prefix + "(servlet does not see the exception)");
            return;
        }
        out.println(prefix + n);
    }
}


