/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: CGIServlet.java,v 1.4 2000/02/21 23:50:53 markd Exp $
 */

package org.enhydra.servlet.servlets;

import java.io.*;
import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;


/**
 * This Servlet is for the purpose of executing a CGI program that resides on
 *  the system.  In order to use this servlet in the Multiserver please
 *  remember to specify the fully qualified classname 
 *   org.enhydra.servlet.servlets.CGIServlet in the Classname field and specify
 *  the directory of the CGI to run in the DocRoot field.
 *
 * @version $Revision: 1.4 $
 * @author  Kent Henneuse
 * @author  Paul Morgan
 */
public class CGIServlet extends HttpServlet { 

    /**
     * Overide the service method of HttpServelet.  This method executes a CGI
     *  program that is specified on the URL line of a browser.
     *
     * @param request the request that is sent by a browser
     * @param response the response that is sent back to the browser after 
     *    processing the CGI
     */
    public void service(HttpServletRequest request, 
		       HttpServletResponse response) 
	throws ServletException, IOException {


	// Get the full path of the CGI program to execute, the simple
	// script name and the path info...
	String strBuffer, progName, scriptPath, scriptName, pathInfo;
	int pathLength, sp, sp2;

	progName = request.getPathTranslated();
	pathLength = request.getServletPath().length();
	strBuffer = request.getRequestURI().substring(pathLength);
	sp = progName.indexOf(strBuffer);

	scriptPath = progName;
	sp2 = 0;
	while (sp2 < progName.length()) {
	    sp2 = progName.indexOf("/", sp);
	    scriptPath = progName.substring(0, sp2==-1?progName.length():sp2);
	    File file = new File(scriptPath);
	    if (!file.isDirectory()) {
		break;
	    }
	    sp = sp2 + 1;
	}

	pathInfo = progName.substring(scriptPath.length());
	scriptName = scriptPath.substring(scriptPath.lastIndexOf("/") + 1);

	// Check that the script pathname is valid i.e. no ".."
        if (!isAuthorized(scriptPath)) {
            response.sendError(response.SC_NOT_FOUND);
            return;
        }

        
        CgiProcessor cgi = new CgiProcessor();
        try {
            cgi.processCgiRequest(request, response, scriptPath, pathInfo, scriptName);
        } catch (IOException e) {
            cgi.cgiError(response);
            System.err.println("ERROR: CGI: " + e);
        }
    }



    /**
     *  Test if a path is authorized. Currently the only limitations
     *  are that the pathname must not contain "..".
     *
     * @param path requested path
     * @return true if the path is authorized
     */
    private boolean isAuthorized(String path) {
        if ((path != null) && (path.indexOf("..") != -1))
            return false;
        return true;
    }





}

