/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: CgiProcessor.java,v 1.4 2000/02/21 23:50:53 markd Exp $
 */

package org.enhydra.servlet.servlets;

import java.io.*;
import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;


/**
 * This Servlet is for the purpose of executing a CGI program that resides on
 *  the system.  In order to use this servlet in the Multiserver please
 *  remember to specify the fully qualified classname 
 *   org.enhydra.servlet.servlets.CGIServlet in the Classname field and specify
 *  the directory of the CGI to run in the DocRoot field.
 *
 * @version $Revision: 1.4 $
 * @author  Kent Henneuse
 * @author  Paul Morgan
 */
class CgiProcessor {

    /**
     * Buffer size for writeing one stream to another.
     */
    private static final int buffer_size = 1024;


    /**
     * Html text to send clent for a file not found.
     */
    private final static String NOT_FOUND_MSG = 
        "<TITLE>Not Found</TITLE><H1>Not Found</H1> " +
        "The requested object does not exist on this Enhydra Multiserver. " +
        "The link you followed is either outdated, inaccurate, " +
        "or the server has been instructed not to let you have it.";


    /**
     *
     */
    public void processCgiRequest(HttpServletRequest request, HttpServletResponse response, String scriptPath, String pathInfo, String scriptName) 
	throws IOException {

	ServletOutputStream out;
	String strBuffer;
	String name, value;
	byte buffer[] = new byte[buffer_size];
	int bytesRead;

        // Execute the CGI & report on errors...
	Process process = null;
	Runtime runner = Runtime.getRuntime();
        String envVars[] = getCgiEnv(request, scriptPath, pathInfo, scriptName);
        File script = new File(scriptPath);
        if (! (script.exists() && script.isFile())) {
            // script doesn't exist
            response.sendError(response.SC_NOT_FOUND, NOT_FOUND_MSG);
            return;
        }
        process = runner.exec(scriptPath, envVars);

        InputStreamReader tempIn 
            = new InputStreamReader(process.getInputStream());
	BufferedReader in = new BufferedReader(tempIn);

        strBuffer = in.readLine();
        if (scriptName.toLowerCase().startsWith("nph-")) {
            String code = strBuffer.substring(strBuffer.indexOf(" "));
            response.setStatus(Integer.parseInt(code));
            strBuffer = in.readLine();
        }

        // Set the response header fields...
        while ((strBuffer != null) && (strBuffer.length() != 0)) {
            int colon = strBuffer.indexOf(":");
            if (colon != -1) {
                name = strBuffer.substring(0, colon);
                value = strBuffer.substring(colon + 1);
		String lName = name.toLowerCase();
		if (lName.equals("status")) {
		    String tValue = value.trim();
		    if (tValue.indexOf(" ") != -1) {
		        String nValue = tValue.substring(0, tValue.indexOf(" "));
		        response.setStatus(Integer.parseInt(nValue));
		    } else {
		        response.setStatus(Integer.parseInt(tValue));
		    }
		} else {
		    response.setHeader(name, value);
		}
            }
            strBuffer = in.readLine();
        }
	
        bytesRead = in.read();
        // then write the data of the response
        out = response.getOutputStream();
	
        while(bytesRead != -1) {
            out.write(bytesRead);
            bytesRead = in.read();
        }
        in.close();
        tempIn.close();
        out.flush();
        out.close();
    }

    /**
     *
     */
    private String[] getCgiEnv(HttpServletRequest request, 
                               String scriptPath, 
                               String pathInfo,
                               String scriptName) {

	Vector envList = new Vector();
        String strBuffer = null;

        // Get all of the Environment Variables that can not be gotten from
        //  the servlet request
        
        // FIXME: The following code is commented out currently as 
        // it may not be required.  Have not found a CGI to really test 
        // this functionality
        /*	    
         process = runner.exec("env");
         tempIn = new InputStreamReader(process.getInputStream());
	 in = new BufferedReader(tempIn);

         strBuffer = in.readLine();
         while(strBuffer != null) {
         envList.addElement(strBuffer);
         strBuffer = in.readLine();
         }
        */

        // Add the request variables to the list to be passed
        strBuffer = request.getServerName();
        if (strBuffer != null) {
            envList.addElement("SERVER_NAME=" + strBuffer);
        }

        strBuffer = request.getProtocol();
        if (strBuffer != null) {
            envList.addElement("SERVER_PROTOCOL=" + strBuffer);
        }

        envList.addElement("SERVER_PORT=" + request.getServerPort());
        
        strBuffer = request.getMethod();
        if (strBuffer != null) {
            envList.addElement("REQUEST_METHOD=" + strBuffer);
        }

        if (pathInfo != null && pathInfo.length() != 0) {
            envList.addElement("PATH_INFO=" + pathInfo);
        }

        strBuffer = request.getPathTranslated();
        if (strBuffer != null) {
            envList.addElement("PATH_TRANSLATED=" + strBuffer);
            envList.addElement("SCRIPT_FILENAME=" + strBuffer);
        }
	
        if (scriptPath != null || scriptPath.equals("")) {
            envList.addElement("SCRIPT_NAME=" + request.getServletPath()
                               + scriptName);
        }

        strBuffer = request.getRealPath("/");
        if (strBuffer != null) {
            envList.addElement("DOCUMENT_ROOT=" + strBuffer);
        }

        strBuffer = request.getQueryString();
        if(strBuffer != null) {
            envList.addElement("QUERY_STRING=" + strBuffer);
        }

        strBuffer = request.getRemoteHost();
        if (strBuffer != null) {
            envList.addElement("REMOTE_HOST=" + strBuffer);
        }

        strBuffer = request.getRemoteAddr();
        if (strBuffer != null) {
            envList.addElement("REMOTE_ADDR=" + strBuffer);
        }

        strBuffer = request.getAuthType();
        if (strBuffer != null) {
            envList.addElement("AUTH_TYPE=" + strBuffer);
        }

        strBuffer = request.getRemoteUser();
        if (strBuffer != null) {
            envList.addElement("REMOTE_USER=" + strBuffer);
        }

        if (request.getContentLength() != -1) {
            envList.addElement("CONTENT_LENGTH="
                               + request.getContentLength());
        }

        strBuffer = request.getContentType();
        if (strBuffer != null) {
            envList.addElement("CONTENT_TYPE=" + strBuffer);
        } 

        strBuffer = request.getHeader("Accept");
        if (strBuffer != null) {
            envList.addElement("HTTP_ACCEPT=" + strBuffer);
        }

        strBuffer = request.getHeader("User-Agent");
        if (strBuffer != null) {
            envList.addElement("HTTP_USER_AGENT=" + strBuffer);
        }

        envList.addElement("SERVER_SOFTWARE=Enhydra/2.0");
        
        // Create the needed array of environment variables
        String envVars[] = new String[envList.size()];
        envList.copyInto(envVars);
        return envVars;
    }

    /**
     *
     */
    public static void cgiError(HttpServletResponse response) 
        throws IOException {
        
        ServletOutputStream out = response.getOutputStream();
        response.setContentType("text/html");

        out.println("<HTML>");
        out.println("<HEAD>");
        out.println("<TITLE>CGIServlet Error</TITLE>\n</HEAD>");
        out.println("<BODY>");
        out.println("<H1>CGIServlet Error</H1>");
        out.println("A CGI program to execute was not specified or could not be found.");
        out.println("</BODY>\n</HTML>");
        out.flush();
        out.close();
    }

}
