/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is David Li. 
 * Portions created by David Li are Copyright (C) 1997-2000 Topware Technology
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 */

package org.enhydra.wireless.wml;

import java.util.Hashtable;
import java.util.StringTokenizer;

import org.w3c.dom.*;

import org.enhydra.xml.xmlc.XMLCError;
import org.enhydra.xml.xmlc.dom.XMLCDomFactory;
import org.enhydra.xml.xmlc.dom.DefaultXMLDomFactory;
import org.enhydra.wireless.wml.dom.xerces.WMLDOMImplementationImpl;

import org.apache.xerces.dom.DocumentTypeImpl;

/**
 * XMLC DOM factory for creating WML-specified DocumentType and Document
 * objects.  Specifying this class as the <code>XMLCDomFctory</code> to xmlc
 * will produce XMLC document class that are <code>WMLDocument</code> classes.
 * This is specified using:
 *
 * <pre>
 * xmlc&nbsp;-dom-factory&nbsp;org.enhydra.wireless.wml.WMLDomFactory
 * </pre>
 */
public class WMLDomFactory extends DefaultXMLDomFactory {
    
    private static final String IMPL_CLASS_SUFFIX = "Impl";
    private static final String WML_IMPLEMENTATION_DOT = "org.enhydra.wireless.wml.dom.xerces";
    private static final String WML_INTERFACE_DOT = "org.enhydra.wireless.wml.dom";

    /**
     * @see XMLCDomFactory#createDocumentType
     */
    public DocumentType createDocumentType(String qualifiedName,
                                           String publicId, 
                                           String systemId,
                                           String internalSubset) {
        DOMImplementation domImpl = WMLDOMImplementationImpl.getDOMImplementation();
        return domImpl.createDocumentType(qualifiedName, publicId, systemId, internalSubset);
    }

    /**
     * @see XMLCDomFactory#createDocument
     */
    public Document createDocument(String qualifiedName, DocumentType docType) {
	DOMImplementation domImpl = WMLDOMImplementationImpl.getDOMImplementation();
	Document doc = domImpl.createDocument(null, qualifiedName, docType);
	return domImpl.createDocument(null, qualifiedName, docType);
    }

    /**
     * @see XMLCDomFactory#nodeClassToInterface
     */
    public String nodeClassToInterface(Node node) {
	String ret = null;

        String className = node.getClass().getName();
	if (className.startsWith(WML_IMPLEMENTATION_DOT)) {
	    int suffixIdx = className.lastIndexOf(IMPL_CLASS_SUFFIX);
	    if (suffixIdx < 0) {
		throw new XMLCError("Class \"" + className
				    + "\" does not have suffix \"" + IMPL_CLASS_SUFFIX
				    + "\" (maybe be mismatch between XMLC code DOM implementation)");
	    }
	    ret = WML_INTERFACE_DOT + 
		className.substring(WML_IMPLEMENTATION_DOT.length(), suffixIdx);
	} else 
	    ret = super.nodeClassToInterface(node);
	return ret;
    }

    /**
     * @see XMLCDomFactory#getElementClassNames
     */
    public String[] getElementClassNames(Element elem) {
	String classNames = elem.getAttribute("class");
        if ((classNames == null) || (classNames.length() ==0)) {
            return null;
        }

        // Parse the class name.
        StringTokenizer tokens = new StringTokenizer(classNames);
        String[] names = new String[tokens.countTokens()];
        for (int idx = 0; idx < names.length; idx++) {
            names[idx] = tokens.nextToken();
        }
        return names;
    }

    /**
     * @see XMLCDomFactory#getElementURLAttrs
     */
    public String[] getElementURLAttrs(Element elem) {
	String[] urlattrs = {"onenterforward",
			     "onenterbackward",
			     "ontimer",
			     "href",
			     "onpick",
			     "src" };
	return urlattrs;
    }
}
