/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: Encoding.java,v 1.1.2.1 2000/03/12 00:25:29 markd Exp $
 */
package org.enhydra.xml.io;

import java.util.Hashtable;
import org.apache.xerces.readers.MIME2Java;

/**
 * Do mapping between Java and XML encodings.
 */
public class Encoding {
    /**
     * Table of XML to Java encodings that correct MIME2Java problems.
     */
    private static final Hashtable xml2JavaMappings = new Hashtable();

    /**
     * Table of Java to XML encodings that correct MIME2Java problems.
     */
    private static final Hashtable java2XmlMappings = new Hashtable();

    /**
     * Initialize static mappings
     */
    static {
        //                    XML           Java
        xml2JavaMappings.put("US-ASCII",   "ASCII");
        xml2JavaMappings.put("ASCII",      "ASCII");
        xml2JavaMappings.put("ISO-8859-1", "ISO8859_1");
        xml2JavaMappings.put("ISO-8859-2", "ISO8859_2");
        xml2JavaMappings.put("ISO-8859-3", "ISO8859_3");
        xml2JavaMappings.put("ISO-8859-4", "ISO8859_4");
        xml2JavaMappings.put("ISO-8859-5", "ISO8859_5");
        xml2JavaMappings.put("ISO-8859-6", "ISO8859_6");
        xml2JavaMappings.put("ISO-8859-7", "ISO8859_7");
        xml2JavaMappings.put("ISO-8859-8", "ISO8859_8");
        xml2JavaMappings.put("ISO-8859-9", "ISO8859_9");
        
        //                    Java         XML
        java2XmlMappings.put("ASCII",     "US-ASCII");
        java2XmlMappings.put("ISO8859_1", "ISO-8859-1");
        java2XmlMappings.put("ISO8859_2", "ISO-8859-2");
        java2XmlMappings.put("ISO8859_3", "ISO-8859-3");
        java2XmlMappings.put("ISO8859_4", "ISO-8859-4");
        java2XmlMappings.put("ISO8859_5", "ISO-8859-5");
        java2XmlMappings.put("ISO8859_6", "ISO-8859-6");
        java2XmlMappings.put("ISO8859_7", "ISO-8859-7");
        java2XmlMappings.put("ISO8859_8", "ISO-8859-8");
        java2XmlMappings.put("ISO8859_9", "ISO-8859-9");
    }

    /**
     * Disallow instantiation.
     */
    private Encoding() {
    }

    /**
     * Convert a Java encoding to a XML encoding.
     * @return the XML encoding, or null if the encoding couldn't
     *  be converted.
     */
    public static String java2XmlEncoding(String jEncoding) {
        String xEncoding = (String)java2XmlMappings.get(jEncoding.toUpperCase());
        if (xEncoding == null) {
            xEncoding = MIME2Java.reverse(jEncoding);
        }
        return xEncoding;
    }

    /**
     * Convert a XML encoding to a Java encoding.
     * @return the Java encoding, or null if the encoding couldn't
     *  be converted.
     */
    public static String xml2JavaEncoding(String xEncoding) {
        String jEncoding = (String)xml2JavaMappings.get(xEncoding.toUpperCase());
        if (jEncoding == null) {
            jEncoding = MIME2Java.convert(xEncoding);
        }
        return jEncoding;
    }
}
