/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: XMLFormatter.java,v 1.8.2.1 2000/04/04 05:29:48 markd Exp $
 */

package org.enhydra.xml.io;

import org.apache.xml.serialize.XMLSerializer;
import org.apache.xml.serialize.OutputFormat;
import java.io.Writer;
import java.io.IOException;
import java.io.OutputStream;
import org.w3c.dom.Node;
import org.w3c.dom.Document;
import org.w3c.dom.Node;

/**
 * Serializer class that overrides some undesirable behavior in the
 * Xerces XMLSerializer.  This makes the following changes:
 * <UL>
 * <LI> Don't expand entity references.
 * </UL>
 */
class XMLFormatter extends XMLSerializer implements Formatter {
    /**
     * The output options.
     */
    private OutputOptions options;
    
    /**
     * Constructor.
     */
    public XMLFormatter() {
        setOutputFormat(new OutputFormat());
    }

    /**
     * Output header and doctype.  This implements the omitEncoding option.
     */
    protected void startDocument(String rootTagName) {
        // If we are omitting encoding header, setting the encoding to null
        // will do the trick.
        if (options.getOmitEncoding()) {
            String savedEncoding = _format.getEncoding();
            _format.setEncoding(null);
            try {
                super.startDocument(rootTagName);
            } finally {
                _format.setEncoding(savedEncoding);
            }
        } else {
            super.startDocument(rootTagName);
        }
    }

    /**
     * Serialize the DOM node.
     */
    protected void serializeNode(Node node) {
        switch (node.getNodeType()) {
	case Node.ENTITY_REFERENCE_NODE:
	    // Entity reference print directly in text, do not break or pause.
            endCDATA();
	    content();
	    printText('&' + node.getNodeName() + ';');
	    break;

        default:
            super.serializeNode(node);
            break;
        }
    }

    /**
     * Get the default Java encoding.
     * @see Formatter#getDefaultEncoding
     */
    public String getDefaultJavaEncoding() {
        return "UTF8";
    }

    /**
     * Format any Node and children to the specified writer.
     */
    public void write(OutputOptions outputOptions,
                      Node node, 
                      Writer writer) throws IOException {
        options = outputOptions;
        setOutputFormat(XercesUtil.makeFormat(options, node.getOwnerDocument()));
        setOutputCharStream(writer);
        serializeNode(node);
    }
}
