/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: XercesUtil.java,v 1.1 2000/03/02 05:30:51 markd Exp $
 */

package org.enhydra.xml.io;

import org.apache.xml.serialize.XMLSerializer;
import org.apache.xml.serialize.OutputFormat;
import org.w3c.dom.DocumentType;
import org.w3c.dom.Document;

/**
 * Common utilities for interfacing to Xerces serializers.
 */
class XercesUtil {
    /**
     * Prevent instanciation
     */
    private XercesUtil() {
    }

    /**
     * Create an OutputFormat from the OutputOptions.  Note we
     * can't just modify the values in the current format, as setFormat()
     * modifies other attributes based on the format.
     */
    protected static OutputFormat makeFormat(OutputOptions options,
                                             Document document) {
        OutputFormat format = new OutputFormat();

        // Pass along options
        if (options.getIndenting()) {
            format.setIndent(options.getIndentSize());
            format.setLineWidth(options.getLineWidth());
        } else {
            format.setIndenting(false);
        }
        format.setPreserveSpace(options.getPreserveSpace());
        
        format.setEncoding(options.getXmlEncoding());
        format.setMethod(OutputFormat.whichMethod(document));
        
        // Set standalone flag if no public or system identifier
        DocumentType docType = document.getDoctype();
        format.setStandalone((docType != null) && (docType.getPublicId() == null)
                             && (docType.getSystemId() == null));
        return format;
    }
}
