/*
 * Enhydra XMLC
 * Copyright (C) 1999, Lutris Technologies, Inc.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * For more information:
 * http://www.enhydra.org
 * http://www.lutris.com
 * mailto:info@lutris.com
 *
 * $Id: BasicTests.java,v 1.1 2000/02/21 18:55:41 markd Exp $
 */

package org.enhydra.xml.io.tests;

import org.enhydra.xml.io.*;
import org.enhydra.xml.xmlc.html.HTMLDocumentFactory;
import com.lutris.util.FatalExceptionError;
import org.w3c.dom.*;
import org.w3c.dom.html.*;
import java.io.*;

/**
 * Basic DOMFormatter tests, mostly of special cases.  More extensive 
 * tests are needed, however its well excerised by the XMLC tests.
 */
public class BasicTests {
    // Output directory
    public static final String OUTDIR = "output";

    // Character encodings.
    private final String UTF8 = "UTF8";
    private final String ISO8859_1 = "ISO8859_1";
    

    /**
     * Create skeleton html object with the specified text
     * in the body.
     */
    private HTMLDocument createHtml1(String title,
                                     String text) {
        HTMLDocument doc = HTMLDocumentFactory.createBasicDocument(title);
        HTMLElement body = doc.getBody();
        body.appendChild(doc.createTextNode(text));
        return doc;
    }

    /**
     * Write string to file using the specified encoding.
     */
    private void output(String fname,
                        String data,
                        String encoding) throws Exception {
        System.err.println(data);
        OutputStream out = new FileOutputStream(new File(OUTDIR, fname));

        out.write(data.getBytes(encoding));
        out.close();
    }

    /**
     * HTML formatting tests with special characters.
     */
    private void test1() throws Exception {
        DOMFormatter fmt;

        // &#146; = 0122 = 0x96
        String data = "One\u0096s check";
        HTMLDocument doc = createHtml1("", data);

        // Test 1.1, not encoding, to string
        doc.setTitle("test-1.1");
        fmt = new DOMFormatter();  // Defaults
        output("test-1.1.html", fmt.toString(doc), ISO8859_1);
    }

    /**
     * Run the tests.
     */
    private void runTests(String[] args) throws Exception {
        new File(OUTDIR).mkdirs();
        test1();
    }

    /**
     * Entry.
     */
    public static void main(String[] args) {
        try {
            new BasicTests().runTests(args);
        } catch (Throwable except) {
            except.printStackTrace();
            System.exit(1);
        }
    }
}
