/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: XMLCFactory.java,v 1.6 2000/03/07 19:36:15 markd Exp $
 */

package org.enhydra.xml.xmlc;

import java.io.File;
import java.io.IOException;
import com.lutris.classloader.MultiClassLoader;
import com.lutris.logging.LogChannel;
import com.lutris.logging.StandardLogger;
import com.lutris.util.FatalExceptionError;

/**
 * Interface for factories for instances of XMLC generated classes.
 */
public interface XMLCFactory {
    /**
     * XMLC log level.  May be used by various factory implementations.
     */
    public static final String XMLC_LOG_LEVEL = "XMLC";

    /**
     * XMLC debug log level.  May be used by various factory implementations.
     */
    public static final String XMLC_DEBUG_LOG_LEVEL = "XMLC_DEBUG";

    /**
     * Create an instance of a XMLC-generated class or a class derived
     * from one, given the name of the class.
     * <P>
     * The class must have a constructor that takes a single boolean argument
     * that will disable the immediate build of the DOM if false.  XMLC
     * creates such a constructor in the classes it generates.
     *
     * @param xmlcClassName The name of the XMLC class or derived class.
     * @return The new object.
     * @see #create(Class)
     */
    public XMLObject create(String xmlcClassName);

    /**
     * Create an instance of a XMLC-generated class or a class derived
     * from one, given either a class or an interface object.  
     * <P>
     * If a class is given, then it should be either the XMLC generated class
     * or a class derived from it.  This is useful for factories that create
     * the given class then preform some operation with it, such as automatic
     * recompilation.
     * <P>
     * If an interface is given, it is converted to the implementation name
     * by appending "Impl" to the name.  In this case, the implementation
     * must be in the same package. 
     * <P>
     * The class must have a constructor that takes a single boolean argument
     * that will disable the immediate build of the DOM if false.  XMLC
     * creates such a constructor in the classes it generates.
     *
     * @param xmlcBasedClass The Class object for the class or interface.
     * @return The new object.
     */
    public XMLObject create(Class xmlcBasedClass);
}
