/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: MultiResourceLoader.java,v 1.4 2000/03/07 19:36:16 markd Exp $
 */

package org.enhydra.xml.xmlc.autocomp;

import java.io.File;
import java.net.URL;
import com.lutris.classloader.MultiClassLoader;
import com.lutris.classloader.Resource;
import com.lutris.classloader.LocalDirResource;

// Need to add NetworkClassLoader.findResource() function to
// MultiClassLoader.

/**
 * ResourceLoader that contains a MultiClassLoader.  It also contains
 * some utilities for dealing with the MultiClassLoader.
 */
public class MultiResourceLoader implements ResourceLoader {
    /**
     * Class loader we are associated with.
     */
    private MultiClassLoader classLoader;

    /**
     * Utility function a File object associated with a class
     * from a MultiClassLoader.
     */
    public static File getClassFile(MultiClassLoader loader,
                                    Class classObj) throws ClassNotFoundException {
        Resource resource = loader.getClassResource(classObj.getName());
        if (!(resource instanceof LocalDirResource)) {
            throw new XMLCAutoCompException("class \"" + classObj.getName()
                                            + "\" must be in a local directory, not an archive, found in: "
                                            + resource.getName());
        }
        return ((LocalDirResource)resource).getFile();
    }

    /**
     * Utility function a File object associated with a resource
     * from a MultiClassLoader.
     */
    public static File getResourceFile(MultiClassLoader loader,
                                       String name) throws ClassNotFoundException {
        Resource resource = loader.getResourceObject(name);
        if (resource == null) {
            throw new ClassNotFoundException(name);
        }
        if (!(resource instanceof LocalDirResource)) {
            throw new XMLCAutoCompException("resource \"" + name
                                            + "\" must be in a local directory, not an archive, found in: "
                                            + resource.getName());
        }
        return ((LocalDirResource)resource).getFile();
    }

    /**
     * @see ResourceLoader#setClassLoader
     */
    public void setClassLoader(ClassLoader classLoader) {
        this.classLoader = (MultiClassLoader)classLoader;
    }

    /**
     * @see ResourceLoader#getClassPath
     */
    public URL[] getClassPath() {
        return classLoader.getClassPath();
    }

    /**
     * @see ResourceLoader#getSystemClassPath
     */
    public URL[] getSystemClassPath() {
        return classLoader.getSystemClassPath();
    }

    /**
     * @see ResourceLoader#getClassLoader
     */
    public ClassLoader getClassLoader() {
        return classLoader;
    }

    /**
     * @see ResourceLoader#getClassFile
     */
    public File getClassFile(Class classObj) throws ClassNotFoundException {
        return getClassFile(classLoader, classObj);
    }

    /**
     * @see ResourceLoader#getResourceFile
     */
    public File getResourceFile(String name) throws ClassNotFoundException {
        return getResourceFile(classLoader, name);
    }

    /**
     * @see ResourceLoader#loadClass
     */
    public Class loadClass(String className)
        throws ClassNotFoundException {
        return classLoader.loadClass(className);
    }
}
