/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: RecompilationHandler.java,v 1.4 2000/02/26 18:30:50 markd Exp $
 */

package org.enhydra.xml.xmlc.autocomp;

//FIXME: Maybe just pass needed objs and dump ClassInfo interface.

/**
 * Interface for a recompilation handler.  A recompilation handler is used
 * to check if a class is out-of-date relative to its source file and to
 * recompile the class if it is out-of-date.
 */
public interface RecompilationHandler {
    /**
     * Bind to a factory.  This is done so that loggers, etc
     * can be grabbed from the factory.
     *
     * @param factory Factory that is creating the object.  Useful
     *  for getting logging object.
     */
    public void init(XMLCAutoCompFactory factory);

    /**
     * Determine if the specified class file is out-of-date relative
     * to its class file.  This should check the class file, not
     * the in-memory class.
     *
     * @param classInfo Object containing originally loaded class and
     *  the current class.
     */
    public boolean isOutOfDate(ClassInfo classInfo)
        throws XMLCAutoCompException;

    /**
     * Recompile a class file from its source file.  Compilation
     * of the file will already be synchronized by the factory.
     *
     * @param classInfo Object containing originally loaded class and
     *  the current class.
     */
    public void recompile(ClassInfo classInfo)
        throws XMLCAutoCompException;
}
