/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: ResourceLoader.java,v 1.2 2000/02/27 09:08:40 markd Exp $
 */

package org.enhydra.xml.xmlc.autocomp;

import java.io.File;
import java.net.URL;

/**
 * Interface for object that is used to load the primary classes and find the
 * source files.  This provides methods for loading a class that are not found
 * in the default classLoader interface.  This is necessary as this This is
 * not used to load the delegate classes.  The lookup of File objects
 * is cached by the caller, so there is no need to do caching in implementations
 * of this interface.
 */
public interface ResourceLoader {
    /**
     * Set the class loader this class is associated with.
     */
    public void setClassLoader(ClassLoader loader);

    /**
     * Get the class path associate with this resource loader.
     */
    public URL[] getClassPath();

    /**
     * Get the system class path.
     */
    public URL[] getSystemClassPath();

    /**
     * Get the class loader associated with this resource loader.
     */
    public ClassLoader getClassLoader();

    /**
     * Get a File object associated with a class.
     */
    public File getClassFile(Class classObj) throws ClassNotFoundException;

    /**
     * Get a File object associated with a resource.
     */
    public File getResourceFile(String name) throws ClassNotFoundException;

    /**
     * Load the specified class.
     *
     * @exception ClassNotFoundException if the class could not be load.
     */
    public Class loadClass(String className)
        throws ClassNotFoundException;
}
