/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: XMLCAutoCompException.java,v 1.2 2000/02/07 00:44:08 markd Exp $
 */

package org.enhydra.xml.xmlc.autocomp;

import org.enhydra.xml.xmlc.XMLCRuntimeException;

/**
 * Runtime exception associated with an autocompilation
 */
public class XMLCAutoCompException extends XMLCRuntimeException {
    /**
     * Output of compiled process, carried along, but not
     * used in messages.
     */
    private String errorOutput;

    /**
     * Construct an exception without a specified cause.
     *
     * @param msg The message associated with the exception.
     */
    public XMLCAutoCompException(String msg) {
        super(msg);
    }

    /**
     * Construct an exception with an associated causing exception.
     *
     * @param msg The message associated with the exception.
     * @param cause The exception or exception that cause this
     *  exception.
     */
    public XMLCAutoCompException(String msg,
                                 Throwable cause) {
        super(msg, cause);
    }

    /**
     * Construct an exception from a causing exception.
     *
     * @param cause The exception or exception that cause this
     *  exception. The message will be take be this object's
     *  messasge.
     */
    public XMLCAutoCompException(Throwable cause) {
        super(cause);
    }

    /**
     * Set the error output.
     */
    public void setErrorOutput(String out) {
        errorOutput = out;
    }

    /**
     * Get the error output or null if it was not set.
     */
    public String getErrorOutput() {
        return errorOutput;
    }
}
