/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: BooleanOption.java,v 1.2 2000/01/22 07:11:31 markd Exp $
 */

package org.enhydra.xml.xmlc.commands.options;

import org.enhydra.xml.xmlc.XMLCException;
import java.io.File;

/**
 * An option that takes a boolean value of true/false/yes/no.
 */
public class BooleanOption extends Option {
    /**
     * Name of option.
     */
    private final String name;

    /**
     * The method used to option's value.
     */
    private final String setMethod;

    /**
     * Construct a new object.
     *
     * @param optSet The option set this option is associated with.
     * @param optName The name of the option.
     * @param optSetMethod The method in the optionSet to set the value.
     *  value.
     * @param optHelp Help string for the option.
     */
    public BooleanOption(OptionSet optSet, String optName,
                         String optSetMethod, String help) {
        super(optSet, optName, 1, false, help);
        setMethod = optSetMethod;
        name = optName;
    }

    /**
     * Parse an instance of the option and set the field in the Options
     * object using Java reflection.
     *
     * @param args The option's arguments.
     */
    public void parse(String[] args) throws XMLCException {
        String strValue = args[0];
        try {
            boolean value;
            if (strValue.equalsIgnoreCase("yes")) {
                value = true;
            } else if (strValue.equalsIgnoreCase("no")) {
                value = false;
            } else if (strValue.equalsIgnoreCase("true")) {
                value = true;
            } else if (strValue.equalsIgnoreCase("false")) {
                value = false;
            } else {
                throw new XMLCException("Illegal value for " + name
                                        + ", expected yes, no, true, or false");
            }

            setOption1(optionSet, setMethod, new Boolean(value));
        } catch (Exception except) {
            throw new XMLCException(except);
        }
    }
}
