/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: FileOption.java,v 1.2 2000/01/22 07:11:31 markd Exp $
 */

package org.enhydra.xml.xmlc.commands.options;

import org.enhydra.xml.xmlc.XMLCException;
import java.io.File;

/**
 * An option that takes a single file name value and can not be repeated.
 */
public class FileOption extends Option {
    /**
     * The method used to option's value.
     */
    private final String setMethod;

    /**
     * Construct a new object.
     *
     * @param optSet The option set this option is associated with.
     * @param optName The name of the option.
     * @param optSetMethod The method in the optionSet to set the value.
     * @param optHelp Help string for the option.
     */
    public FileOption(OptionSet optSet, String optName,
                      String optSetMethod, String help) {
        super(optSet, optName, 1, false, help);
        setMethod = optSetMethod;
    }

    /**
     * Parse an instance of the option and set the field in the Options
     * object using Java reflection.
     *
     * @param args The option's arguments.
     */
    public void parse(String[] args) throws XMLCException {
        try {
            setOption1(optionSet, setMethod, new File(args[0]));
        } catch (Exception except) {
            throw new XMLCException(except);
        }
    }
}
