/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: OptionFileParser.java,v 1.3.2.1 2000/04/04 05:29:49 markd Exp $
 */

package org.enhydra.xml.xmlc.commands.options;

import org.enhydra.xml.xmlc.XMLCException;
import java.io.File;
import java.io.Reader;
import java.io.FileReader;
import java.io.StreamTokenizer;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.Vector;

/**
 * Parse an XMLC options file.
 */
class OptionFileParser {
    // Vector of entries in the file.
    private Vector entries = new Vector();

    /**
     * Parse a line in the file.
     *
     * @return true if a line was parsed, false on EOF.
     */
    private boolean parseLine(StreamTokenizer in) throws IOException {
        in.nextToken();
        if (in.ttype == StreamTokenizer.TT_EOF) {
            return false;  // EOF
        }

        // Check for comment or blank line.
        if (in.ttype == StreamTokenizer.TT_EOL) {
            return true; // EOL
        }
        if (in.sval.startsWith("#")) {
            // Eat comment line
            do {
                in.nextToken();
            } while (!((in.ttype == StreamTokenizer.TT_EOF)
                     || (in.ttype == StreamTokenizer.TT_EOL)));
            return true;
        }
        
        // Parse option and arguments.
        Vector tokens = new Vector();
        do {
            tokens.addElement(in.sval);
            in.nextToken();
        } while (!((in.ttype == StreamTokenizer.TT_EOF)
                   || (in.ttype == StreamTokenizer.TT_EOL)));
        if (tokens.size() >= 0) {
            String[] optEntry = new String[tokens.size()];
            tokens.copyInto(optEntry);
            entries.addElement(optEntry);
        }
        return true;
    }

    /**
     * Parse an open options file.
     */
    private void parse(Reader inReader) throws XMLCException, IOException {
        StreamTokenizer in = new StreamTokenizer(inReader);
        in.resetSyntax();
        in.eolIsSignificant(true);
        in.whitespaceChars('\u0000', '\u0020');
        in.wordChars('\u0021', '\uffff');
        in.quoteChar('"');
        in.quoteChar('\'');

        while (parseLine(in)) {
            continue;
        }
    }

    /**
     * Construct, parsing contents of file, but not validing options.
     */
    public OptionFileParser(Reader inReader)
        throws XMLCException, IOException {
        parse(inReader);
    }

    /**
     * Construct, parsing contents of file, but not validing options.
     */
    public OptionFileParser(File optFile)
        throws XMLCException, IOException {
        Reader inReader = new FileReader(optFile);
        try {
            parse(inReader);
        } finally {
            inReader.close();
        }
    }

    /**
     * Get the options that were parsed.
     *
     * @return An array of string arrays, each representing an
     *  option and its arguments.
     */
    public String[][] getOptions() {
        String[][] opts = new String[entries.size()][];
        entries.copyInto(opts);
        return opts;
    }
}
