/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: OptionSet.java,v 1.3 2000/03/07 19:36:16 markd Exp $
 */

package org.enhydra.xml.xmlc.commands.options;

import org.enhydra.xml.xmlc.XMLCException;
import java.util.Enumeration;

/**
 * Interface for a set of XMLC options.
 *
 * @see Option
 * @see OptionsParser
 */
public interface OptionSet {
    /**
     * Get an enumeration of all options in the set.
     */
    public Enumeration getOptions();

    /**
     * Get displayable string of valid options for use in error messages.
     */
    public String getOptionsMsg();

    /**
     * Lookup an option.
     *
     * @param name The option name, including the leading `-'.
     * @return The Option object or null if name is not found. 
     */
    public Option findOption(String name);

    /**
     * Parse the positional arguments.  This is called before the 
     * options have been parsed, so those values should not be relied on.
     * Options files (.xmlc) will have been removed from the arguments.
     */
    public void processPositionalArgs(String[] posArgs) throws XMLCException;

    /**
     * Do any follow up processing that is needed. Often used  to default
     * any options in the set that have not been specified and need
     * the context of other options and position parameters to be
     * set.
     */
    public void complete() throws XMLCException;

}
