/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: StringHashOption.java,v 1.2 2000/01/22 07:11:32 markd Exp $
 */

package org.enhydra.xml.xmlc.commands.options;

import org.enhydra.xml.xmlc.XMLCException;
import java.util.Hashtable;

/**
 * An option that takes one or two option arguments and places them
 * in a hash table.
 */
public class StringHashOption extends Option {
    /**
     * The method used to option's value.
     */
    private final String setMethod;

    /**
     * Construct a new object.
     *
     * @param optSet The object set this option is associated with.
     * @param optName The name of the option.
     * @param optSetMethod The method in the optionSet to set the value.
     * @param singleValue - If true, the argument takes a single option,
     *  which is saved as both the key and the value in the hash table.
     *  If false, the option takes two arguments.
     * @param optHelp Help string for the option.
     */
    public StringHashOption(OptionSet optSet, String optName,
                            String optSetMethod, boolean singleValue,
                            String optHelp) {
        super(optSet, optName, singleValue ? 1 : 2, true, optHelp);
        setMethod = optSetMethod;
    }

    /**
     * Parse an instance of the option and set the field in the Options
     * object using Java reflection.
     *
     * @param args The option's arguments.
     */
    public void parse(String[] args) throws XMLCException {
        if (args.length == 1) {
            setOption2(optionSet, setMethod, args[0], args[0]);
        } else {
            setOption2(optionSet, setMethod, args[0], args[1]);
        }
    }
}
