/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: PrintInfo.java,v 1.3 2000/02/21 01:27:32 markd Exp $
 */

package org.enhydra.xml.xmlc.commands.xmlc;

import org.enhydra.xml.xmlc.compiler.*;
import org.enhydra.xml.xmlc.dom.XMLCDocument;
import java.io.*;
import java.util.Vector;
import org.w3c.dom.*;

/**
 * Gather and print information about an document.
 */
class PrintInfo {
    /**
     * Table URLs.
     */
    private Vector urls = new Vector();
    

    /**
     * Table of element ids.
     */
    private Vector ids = new Vector();
    
    /**
     * Construct document info from document.
     */
    public PrintInfo(Document doc, XMLCDocument xmlcDoc) {
        getNodeInfo(doc, xmlcDoc);
    }

    /**
     * Append URLs from an element.
     */
    private void getElementURLs(Element element, XMLCDocument xmlcDoc) {
        String[] attrs = xmlcDoc.getElementURLAttrs(element);
        if (attrs == null) {
            return;  // No URLs in this node.
        }
        for (int idx = 0; idx < attrs.length; idx++) {
            String url = element.getAttribute(attrs[idx]);
            if ((url != null) && (url.length() > 0)) {
                urls.addElement(url);
            }
        }
    }

    /**
     * Recursively scan nodes nodes and accumulate information.
     */
    private void getNodeInfo(Node node, XMLCDocument xmlcDoc) {
        if (node instanceof Element) {
            Element elem = (Element)node;
            getElementURLs(elem, xmlcDoc);
            String id = xmlcDoc.getElementId(elem);
            if ((id != null) && (id.length() > 0)) {
                ids.addElement(id + " => "
                               + xmlcDoc.nodeClassToInterface(node));
            }
        }

        for (Node child = node.getFirstChild(); child != null;
             child = child.getNextSibling()) {
            getNodeInfo(child, xmlcDoc);
        }
    }

    /**
     * Print document information.
     */
    protected void printInfo(PrintWriter out) {
        int idx;

        out.println("Element IDs:");
        for (idx = 0; idx < ids.size(); idx++) {
            out.println("    " + ids.elementAt(idx));
        }
        out.println("Document URLs:");
        for (idx = 0; idx < urls.size(); idx++) {
            out.println("    " + urls.elementAt(idx));
        }
    }
}
