/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id$
 */

package org.enhydra.xml.xmlc.compiler;

import org.enhydra.xml.xmlc.XMLCError;
import java.io.Reader;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.FileInputStream;
import java.io.BufferedReader;
import java.io.IOException;
import java.net.URL;
import org.xml.sax.InputSource;

/**
 * Class providing various methods for input handling.
 */
public class InputHandling {
    /**
     * Disallow instantiation.
     */
    private InputHandling() {
    }

    /**
     * Open a bytestream given a system id.  If it appears to
     * have a protocol, use URL to open, other open as a file.
     */
    private static InputStream openSystemId(String systemId)
            throws IOException {
        if (systemId.startsWith("http:")
            || systemId.startsWith("ftp:")
            || systemId.startsWith("file:")) {

            URL url = new URL(systemId);
            return url.openStream();
        } else {
            return new FileInputStream(systemId);
        }
    }

    /**
     * Given an InputSource, obtain a Reader for it.
     */
    public static Reader obtainReader(InputSource source)
            throws IOException {
        // Don't currently support an open file in the source,
        // as there are places that read the file twice (Parse.isXMLDocument()).
        // This needs to be modified just buffer the input if necessary.
        if ((source.getCharacterStream() != null)
            || (source.getByteStream() != null)) {
            throw new XMLCError("InputSource with open stream not currently supported");
        }

        // First: Character stream
        Reader charStream = source.getCharacterStream();
        if (charStream == null) {
            // Second: Byte stream
            InputStream byteStream = source.getByteStream();
            if (byteStream == null) {
                // Third: System Id
                if (source.getSystemId() != null) {
                    byteStream = openSystemId(source.getSystemId());
                } else {
                    throw new XMLCError("Invalid InputSource");
                }
            }

            // Got a byte stream now set the encoding.
            if (source.getEncoding() != null) {
                charStream = new InputStreamReader(byteStream,
                                                   source.getEncoding());
            } else {
                //FIXME: Should we use a recognization alogrithm for HTML
                //to obtain the encoding.
                charStream = new InputStreamReader(byteStream);
            }
        }
        return new BufferedReader(charStream);
    }
}
