/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: OutputMonitorThread.java,v 1.2 2000/01/22 07:11:35 markd Exp $
 */

package org.enhydra.xml.xmlc.compiler;

import java.io.*;

/**
 * Output monitoring thread.
 */
class OutputMonitorThread extends Thread {
    private BufferedReader input;
    private PrintWriter output;
    private StringBuffer outputBuf;
    private IOException ioException = null;
    
    /**
     * Construct an output monitor thread object.
     * @param in Stream to read from.
     * @param out Stream to write to.  If null, don't copy to an
     *               output stream.
     * @param outBuf Buffer to collect output in. If null, don't collect.
     */
    OutputMonitorThread(InputStream in,
                        OutputStream out,
                        StringBuffer outBuf) {
        input = new BufferedReader(new InputStreamReader(in));
        if (out != null) {
            output = new PrintWriter(new OutputStreamWriter(out), true);
        }
        outputBuf = outBuf;
    }
    
    /**
     * Get an exception, if one terminated the thread, otherwise
     * null indicates no errors.
     */
    IOException getException() {
        return ioException;
    }


    /**
     * Copy the stream until eof.
     */
    private void copyStream() throws IOException {
        String line;
        while ((line = input.readLine()) != null) {
            if (output != null) {
                output.println(line);
            }
            if (outputBuf != null) {
                outputBuf.append(line);
                outputBuf.append('\n');
            }
        }
    }

    /**
     * Run the copy thread.
     */
    public void run() {
        try {
            copyStream();
        } catch (IOException except) {
            ioException = except;
        }
        if (output != null) {
            output.flush();
        }
        stop();
    }
}
