/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: StringFields.java,v 1.2 2000/01/22 07:11:35 markd Exp $
 */

package org.enhydra.xml.xmlc.compiler;

/**
 * Generate a static field definition for a string constant.
 */
class StringFields {
    /**
     * Prefix for field name.
     */
    private String prefix;

    /**
     * Number to assign to the next field.
     */
    private int nextFieldNum = 0;

    /**
     * Construct a new field generator.
     * @param fieldPrefix Field prefix for the generated field names.
     */
    public StringFields(String fieldPrefix) {
        prefix = fieldPrefix;
    }

    /**
     * Generate a field definition for a String constant.
     *
     * @param text Text to quote.
     * @return String field definition.
     */
    public String getFieldDef(String text) {
        int fieldNum = nextFieldNum++;
        return "private static final String "
            + prefix + fieldNum + " = "
            + JavaLang.createStringConst(text);
    }
}
