/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: URLMapping.java,v 1.2 2000/01/22 07:11:35 markd Exp $
 */

package org.enhydra.xml.xmlc.compiler;

/**
 * Specify a mapping from one URL to another and/or a URL to edit by
 * by element id.
 */
public class URLMapping extends URLEdit {
    /**
     * Original URL to map.  Is null if all URLs in are to be mapped.
     */
    private String originalURL;

    /**
     * New URL used to replace the original.
     */
    private String newURL;

    /**
     * Constructor.
     *
     * @param elementId Element id of URL to set.  Is null if all matching
     *  URLs are to be mapped.
     * @param originalURL Original URL to map. Is null if all URLs in are to
     *  be mapped.
     * @param newURL New URL used to replace the original.
     */
    public URLMapping(String elementId,
                      String originalURL,
                      String newURL) {
        super(elementId);
        this.originalURL = originalURL;
        this.newURL = newURL;
    }

    /**
     * Get the orginal URL to map.
     */
    public String getOriginalURL() {
        return originalURL;
    }

    /**
     * New URL used to replace the original.
     */
    public String getNewURL() {
        return newURL;
    }

    /**
     * Return a printable version.
     */
    public String toString() {
        return "id=\"" + getElementId()
            + "\", original=\"" + originalURL
            + "\", new=\"" + newURL + "\"";
    }
}
