/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: URLRegexpMapping.java,v 1.2 2000/01/22 07:11:35 markd Exp $
 */

package org.enhydra.xml.xmlc.compiler;

import org.enhydra.xml.xmlc.XMLCException;
import gnu.regexp.*;

/**
 * A mapping of a URL based on a regular expression.
 *
 * Based on code contributed by Richard Kunze &lt;kunze@opus5.de&gt;.
 */
public class URLRegexpMapping extends URLEdit {
    /*
     * Regular expression and subsitution. 
     */
    private String regexpSrc;
    private RE regexp;
    private String substitution;

    /**
     * Construct a new URL regular expression mapping.
     * @param elementId Element id of URL to set.  Is null if all matching
     *  URLs are to be mapped.
     * @param urlRegexp Regular regular expression.
     * @param urlSubsitution Substitution pattern.
     */
    public URLRegexpMapping(String elementId,
                            String urlRegexp,
                            String urlSubstitution) throws XMLCException {
        super(elementId);
        regexpSrc = urlRegexp;
        substitution = urlSubstitution;
        try {
            regexp = new RE(urlRegexp, 0,
                            RESyntax.RE_SYNTAX_POSIX_EXTENDED);
        } catch (REException except) {
            throw new XMLCException(except);
        }
    }

    /**
     * Get the source (uncompiled) regular expression.
     */
    public String getRegexpSrc() {
        return regexpSrc;
    }
    
    /**
     * Get URL substitution string
     */
    public String getSubstitution() {
        return substitution;
    }
    
    /**
     * Substitute a URL based on the regular expression.
     *
     * @return The updated URL or null if the URL doesn't match.
     */
    public String mapURL(String url) throws XMLCException {
        if (regexp.getMatch(url) == null) {
            return null;
        }
        return regexp.substituteAll(url, substitution);
    }

    /**
     * Return a printable version.
     */
    public String toString() {
        return "id=\"" + getElementId()
           + "\", re=\"" + regexp.toString()
           + "\", subst=\"" + substitution + "\"";
    }
}
