/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: DefaultHTMLDomFactory.java,v 1.2 2000/03/07 19:36:17 markd Exp $
 */

package org.enhydra.xml.xmlc.dom;

import org.w3c.dom.Element;
import java.util.StringTokenizer;

/**
 * Default DOM factory class for HTML documents.
 */
public class DefaultHTMLDomFactory
    extends org.enhydra.xml.xmlc.dom.xerces.XercesDomFactory
    implements XMLCDomFactory {

    /**
     * HTML URL attributes.
     */
    private static String[] urlAttributes = {
        "action", "archive", "background", "cite", "classid", "codebase",
        "data", "href", "longdesc", "onblur", "onchange", "onclick",
        "ondblclick", "onfocus", "onkeydown", "onkeypress", "onkeyup",
        "onload", "onmousedown", "onmousemove", "onmouseout", "onmouseover",
        "onmouseup","onreset", "onselect", "onsubmit", "onunload", "profile",
        "src", "usemap"
    };
    
    /**
     * @see XMLCDomFactory#getBaseClassName
     */
    public String getBaseClassName() {
        return "org.enhydra.xml.xmlc.html.HTMLObjectImpl";
    }

    /**
     * @see XMLCDomFactory#getBaseInterfaceName
     */
    public String getBaseInterfaceName() {
        return "org.enhydra.xml.xmlc.html.HTMLObject";
    }

    /**
     * @see XMLCDomFactory#getElementClassNames
     */
    public String[] getElementClassNames(Element element) {
        //FIXME: This code would be real useful in XMLCUtil or HTMLObject.
        String classNames = element.getAttribute("class");
        if ((classNames == null) || (classNames.length() ==0)) {
            return null;
        }

        // Parse the class name.
        StringTokenizer tokens = new StringTokenizer(classNames);
        String[] names = new String[tokens.countTokens()];
        for (int idx = 0; idx < names.length; idx++) {
            names[idx] = tokens.nextToken();
        }
        return names;
    }

    /**
     * @see XMLCDomFactory#getElementURLAttrs
     */
    public String[] getElementURLAttrs(Element element) {
        return urlAttributes;
    }

    /**
     * @see XMLCDomFactory#needsCreateTextSetMethod
     */
    public boolean needsCreateTextSetMethod(Element element) {
        return element.getTagName().equalsIgnoreCase("span");
    }
}
