/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: XMLCDomFactoryCache.java,v 1.1.2.1 2000/03/23 11:03:45 markd Exp $
 */

package org.enhydra.xml.xmlc.dom;

import org.enhydra.xml.xmlc.XMLCError;
import java.util.Hashtable;

/**
 * Class that provides a cache of XMLCDomFactory objects.  Since
 * these classes are simple, they can normally be reentrant.
 * This cache provides a mechanism to maintain only one instance of
 * each class.  Currently, instances are never freed from this cache.
 */
public class XMLCDomFactoryCache {
    /**
     * Cache of factories.
     */
    private static Hashtable cache = new Hashtable();

    /**
     * Disallow instanciation.
     */
    private XMLCDomFactoryCache() {
    }

    /**
     * Generate an error message when we can't create an
     * instance of an XMLCDomFactory class.
     */
    private static void handleCreateError(String className,
                                          Exception except) {
        throw new XMLCError("Can't create an instance of \""
                            + className + "\": "
                            + except.getClass().getName(),
                            except);
    }

    /**
     * Create an instance of an XMLCDomFactory.  Don't synchronize, as its ok
     * to create more than one.
     */
    private static XMLCDomFactory createFactory(String className) {
        try {
            Class cl = Class.forName(className);
            return (XMLCDomFactory)cl.newInstance();
        } catch (ClassNotFoundException except) {
            handleCreateError(className, except);
        } catch (IllegalAccessException except) {
            handleCreateError(className, except);
        } catch (InstantiationException except) {
            handleCreateError(className, except);
        } catch (ClassCastException except) {
            handleCreateError(className, except);
        }
        return null; // Never makes it here.
    }

    /**
     * Get an instance of an XMLCDomFactory given it's class.
     */
    public static XMLCDomFactory getFactory(String className) {
        XMLCDomFactory factory = (XMLCDomFactory)cache.get(className);
        if (factory == null) {
            factory = createFactory(className);
            cache.put(className, factory);
        }
        return factory;
    }
}
