/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: XercesDomFactory.java,v 1.5.2.2 2000/03/28 23:49:28 markd Exp $
 */

package org.enhydra.xml.xmlc.dom.xerces;

import org.enhydra.xml.xmlc.XMLCError;
import org.enhydra.xml.xmlc.dom.XMLCDomFactory;
import org.w3c.dom.DocumentType;
import org.w3c.dom.Document;
import org.w3c.dom.Node;
import org.w3c.dom.DOMImplementation;
import org.w3c.dom.html.HTMLDocument;
import org.apache.xerces.dom.DocumentImpl;
import org.apache.xerces.dom.DOMImplementationImpl;
import org.apache.html.dom.HTMLDocumentImpl;


/**
 * Xerces factory for creating DocumentType and Document objects.
 */
public abstract class XercesDomFactory implements XMLCDomFactory {
    /*
     * Suffix attached to interface name to form the implementation name.
     */
    private static final String IMPL_CLASS_SUFFIX = "Impl";

    /*
     * Xerces DOM to W3C package name map.
     */
    private static final String[][] DOM_PACKAGES_DOT_MAP = {
        {"org.apache.xerces.dom.", "org.w3c.dom."},
        {"org.apache.html.dom.", "org.w3c.dom.html."},
    };

    /**
     * @see XMLCDomFactory#createDocumentType
     */
    public DocumentType createDocumentType(String qualifiedName,
                                           String publicId, 
                                           String systemId,
                                           String internalSubset) {
        DOMImplementation domImpl
            = DOMImplementationImpl.getDOMImplementation();
        return domImpl.createDocumentType(qualifiedName, publicId,
                                          systemId, internalSubset);
    }

    /**
     * @see XMLCDomFactory#createDocument
     */
    public Document createDocument(String qualifiedName,
                                   DocumentType docType) {
        if ((qualifiedName == null) && (docType == null)) {
            // We don't use HTMLDOMImplementation as it insists on
            // adding <HEAD> and <TITLE>.
            return new HTMLDocumentImpl();
        } else {
            DOMImplementation domImpl
                = DOMImplementationImpl.getDOMImplementation();
            return domImpl.createDocument(null, qualifiedName, docType);
        }
    }

    /**
     * @see XMLCDomFactory#setErrorChecking
     */
    public void setErrorChecking(Document doc,
                                 boolean check) {
        DocumentImpl xercesDoc = (DocumentImpl)doc;
        xercesDoc.setErrorChecking(check);
        xercesDoc.setMutationEvents(check);
    }


    /**
     * @see XMLCDomFactory#nodeClassToInterface
     */
    public String nodeClassToInterface(Node node) {
        String className = node.getClass().getName();
        
        // Check using suffix.
        int packageIdx;
        for (packageIdx = 0; packageIdx < DOM_PACKAGES_DOT_MAP.length; packageIdx++) {
            if (className.startsWith(DOM_PACKAGES_DOT_MAP[packageIdx][0])) {
                break;
            }
        }
        if (packageIdx == DOM_PACKAGES_DOT_MAP.length) {
            throw new XMLCError("Can't determine DOM interface for node of class \""
                                + className
                                + "\" (maybe be mismatch between XMLC code DOM implementation)");
        }

        // Remove the suffix to get the base class name.
        int suffixIdx = className.lastIndexOf(IMPL_CLASS_SUFFIX);
        if (suffixIdx < 0) {
            throw new XMLCError("Class \"" + className
                                + "\" does not have suffix \"" + IMPL_CLASS_SUFFIX
                                + "\" (maybe be mismatch between XMLC code DOM implementation)");
        }
        
        return DOM_PACKAGES_DOT_MAP[packageIdx][1]
            + className.substring(DOM_PACKAGES_DOT_MAP[packageIdx][0].length(),
                                  suffixIdx);
    }
}
