/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: HTMLDocumentFactory.java,v 1.5 2000/02/21 18:55:41 markd Exp $
 */

package org.enhydra.xml.xmlc.html;

import org.enhydra.xml.xmlc.dom.XMLCDomFactory;
import org.enhydra.xml.xmlc.dom.DefaultHTMLDomFactory;
import org.enhydra.xml.xmlc.*;
import org.w3c.dom.*;
import org.w3c.dom.html.*;

/**
 * Factory class for constructing new HTMLDocument objects without
 * needing to know the implementing class.
 */
public class HTMLDocumentFactory {
    /**
     * Factory for creating documents.
     */
    private static XMLCDomFactory domFactory
        = new DefaultHTMLDomFactory();

    /**
     * Constructor that prevents instantiation.
     */
    private HTMLDocumentFactory() {
    }

    /**
     * Create a new HTMLDocument object.  The document will contain an
     * empty HTML element.
     */
    static public HTMLDocument createDocument() {
        return (HTMLDocument)domFactory.createDocument(null, null);
    }

    /**
     * Create a new HTMLDocument object, initialized with
     * empty HTML, HEAD, TITLE and BODY elements.
     * @param title The title string to set in the header.
     */
    static public HTMLDocument createBasicDocument(String title) {
        HTMLDocument doc = createDocument();

        // This creates head and title
        doc.setTitle(title);
        // This creates body
        doc.getBody();

        return doc;
    }

    /**
     * Create a new HTMLDocument object, initialized with
     * empty HTML, HEAD, TITLE and BODY elements.
     */
    static public HTMLDocument createBasicDocument() {
        return createBasicDocument("");
    }
}
