/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: HTMLParserBase.java,v 1.4.2.1 2000/04/04 05:29:53 markd Exp $
 */

package org.enhydra.xml.xmlc.html;

import org.enhydra.xml.xmlc.*;
import org.enhydra.xml.xmlc.compiler.*;
import org.enhydra.xml.xmlc.parsers.*;
import org.enhydra.xml.xmlc.dom.*;
import java.io.*;
import java.util.*;
import java.net.*;
import org.w3c.dom.*;
import org.w3c.dom.html.*;
import org.xml.sax.InputSource;
import org.enhydra.xml.io.Encoding;

/**
 * Abstract class used to constructor XMLCParser objects for HTML.
 * Methods in this class are the only ones that do DOM implementation-
 * specific operations.
 */
abstract public class HTMLParserBase implements XMLCParser, HTMLParser {
    /**
     * Determine if an element name is a frameset-only element.
     */
    public static boolean isFrameSetElement(String element) {
        return element.equalsIgnoreCase("frameset")
            || element.equalsIgnoreCase("noframes");

    }

    /**
     * Create a XMLCDocument object.
     */
    protected XMLCDocument createXMLCDocument(String baseClass) throws XMLCException {
        return new XMLCDocument(null, baseClass, null, true);
    }

    /**
     * Mark the document as a frameset or standard HTML document.
     */
    protected void setFrameSet(XMLCDocument xmlcDoc,
                               boolean frameSet) {
        HTMLDocBuilder docBuilder
            = (HTMLDocBuilder)xmlcDoc.getDocBuilder();
        docBuilder.setFrameSet(frameSet);
    }

    /**
     * Set the encoding in the document base on the one specified
     * in the InputSource.
     */
    protected void setEncoding(XMLCDocument xmlcDoc,
                               InputSource input) {
        //FIXME: Should this be defaulted to ASCII??
        String javaEncoding = input.getEncoding();
        if (javaEncoding != null) {
            String htmlEncoding = Encoding.java2XmlEncoding(javaEncoding);
            xmlcDoc.getDocBuilder().setEncoding(htmlEncoding);
        }
    }

    /**
     * Generate error exception for parse errors.
     */
    protected void handlePrarseErrors(ErrorReporter reporter) throws XMLCException {
        String errText = 
            (reporter.getErrorCnt() > 1) ? "errors" : "error";
        throw new XMLCException("" + reporter.getErrorCnt()
                                + " parse " + errText
                                + " in HTML file");
    }
}
