/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: SwingHTMLParser.java,v 1.5.2.1 2000/04/04 05:29:54 markd Exp $
 */

package org.enhydra.xml.xmlc.html.parsers.swing;

import org.enhydra.xml.xmlc.*;
import org.enhydra.xml.xmlc.html.*;
import org.enhydra.xml.xmlc.compiler.*;
import org.enhydra.xml.xmlc.parsers.ParseTracer;
import org.enhydra.xml.xmlc.parsers.XMLCParser;
import org.enhydra.xml.xmlc.dom.XMLCDocument;
import org.enhydra.xml.io.Encoding;
import org.w3c.dom.*;
import org.w3c.dom.html.*;
import org.xml.sax.InputSource;
import java.io.*;
import java.util.StringTokenizer;

/**
 * XMLCParser object for HTML and HTML framesets using the Swing HTML parser.
 */
public class SwingHTMLParser extends HTMLParserBase implements XMLCParser {
    /**
     * Get the set of options supported by this parser.
     */
    public int getSupportedOptions() {
        return OPT_VALIDATE_DOCUMENT;
    }

    /**
     * Parse a HTML file.
     * @see XMLCParser#parse
     */
    public XMLCDocument parse(InputSource input,
                              int options,
                              String documentClass,
                              String baseClass,
                              String[] xCatalog,
                              ErrorReporter errorReporter,
                              ParseTracer tracer)
        throws IOException, XMLCException {

        if (documentClass != null) {
            // FIXME: Put this check in some place common..
            throw new XMLCException("Document class may not be specified for HTML documents");
        }
        if (xCatalog.length != 0) {
            throw new XMLCException("XCatalog not support for HTML");
        }

        LineNumberMapReader reader = new LineNumberMapReader(input);
        XMLCDocument xmlcDoc = createXMLCDocument(baseClass);
        setEncoding(xmlcDoc, input);

        SwingParser parser = new SwingParser();
        parser.parse(xmlcDoc, errorReporter, tracer, reader);
        if (errorReporter.getErrorCnt() != 0) {
            handlePrarseErrors(errorReporter);
        }
        
        setFrameSet(xmlcDoc, parser.isFrameSet());

        return xmlcDoc;
    }


    /**
     * Specify the list of proprietary tags and attributes.  This
     * parser ignores this specification.
     * @see HTMLParser
     */
    public void setProprietaryTags(HTMLProprietaryTags tagsAttrs) throws XMLCException {
        // Just ignore
    }
}
