/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: ParseTracer.java,v 1.2 2000/01/22 07:11:40 markd Exp $
 */

package org.enhydra.xml.xmlc.parsers;

import java.io.*;

/**
 * Object used to trace parser calls.  Handles indentation for logging the
 * parsing of nested elements.
 */
public class ParseTracer {
    /**
     * Verbose trace output.
     */
    private PrintWriter out;

    /**
     * Current indent level.
     */
    private int indent = 0;

    /**
     * Create tracer.  If traceOut is null, it is created
     * disabled.
     */
    public ParseTracer(PrintWriter traceOut) {
        out = traceOut;
    }

    /**
     * Determine if tracing is enabled.
     */
    public boolean enabled() {
        return (out != null);
    }

    /**
     * Enter a nesting, increment the indent count.
     */
    public void enter() {
        indent++;
    }

    /**
     * Leave a nesting, decrement the indent count.
     */
    public void leave() {
        indent--;
    }

    /**
     * Generate trace output with indentation.
     */
    public void trace(String str) {
        if (out != null) {
            out.print("==>");
            for (int cnt = 0; cnt < indent; cnt++) {
                out.print("    ");
            }
            out.println(str);
        }
    }
    /**
     * Generate a general trace message at current indentation level.
     */
    public void println(String str) {
        if (out != null) {
            out.print("***");
            for (int cnt = 0; cnt < indent; cnt++) {
                out.print("    ");
            }
            out.println(str);
        }
    }
}
