/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: XMLCParser.java,v 1.4.2.1 2000/04/04 05:29:55 markd Exp $
 */

package org.enhydra.xml.xmlc.parsers;

import org.enhydra.xml.xmlc.XMLCException;
import org.enhydra.xml.xmlc.dom.XMLCDocument;
import org.enhydra.xml.xmlc.compiler.ErrorReporter;
import java.io.IOException;
import org.xml.sax.SAXException;
import org.xml.sax.InputSource;

/**
 * Interface for a class that specifies how to parse an XML file and provide
 * information needed to compile that file into a XMLC object.  The object
 * must have a constructor that takes no arguments and an instance of the
 * object will only be use to parse a single document and not used
 * recursively.
 */
public interface XMLCParser {
    /**
     * Option to parser to specify that the file should be validated.
     */
    public static final int OPT_VALIDATE_DOCUMENT = 0x01;

    /**
     * Option to parser to specify that the file should not be validated.
     */
    public static final int OPT_NO_VALIDATE_DOCUMENT = 0x02;

    /**
     * Get the set of options supported by this parser.
     */
    public int getSupportedOptions();

    /**
     * Parse a XML file (or any file, such as HTML, that can be converted into
     * XML).
     *
     * @param input The file to parse.
     * @param options Options controling parsing.  Pre-check for legality
     *  as specified by getSupportedOptions().
     * @param documentClass Class name for Document.
     * @param baseClass Base class for generate object,
     *  maybe null for default.
     * @param xCatalog XCatalog files to use for entity resolution.
     * @param errorReporter Object for reporting errors during the parse.
     * @param tracer Object for parser info tracing.
     * @return A XMLC document object that contains the actual DOM Document.
     * @exception XMLCException Thrown for fatal errors found parsing the
     *  document.
     */
    public XMLCDocument parse(InputSource input,
                              int options,
                              String documentClass,
                              String baseClass,
                              String[] xCatalog,
                              ErrorReporter errorReporter,
                              ParseTracer tracer)
        throws IOException, XMLCException, SAXException;
}
