#
# Enhydra Java Application Server 
# The Initial Developer of the Original Code is Lutris Technologies Inc. 
# Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
# Inc. 
# All Rights Reserved. 
#
# The contents of this file are subject to the Enhydra Public License Version
# 1.0 (the "License"); you may not use this file except in compliance with the
# License. You may obtain a copy of the License at
# http://www.enhydra.org/software/license/epl.html 
#
# Software distributed under the License is distributed on an "AS IS" basis,
# WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
# License for the specific language governing rights and limitations under the
# License. 
#
# $Id: common.mk,v 1.1 2000/03/02 07:47:26 markd Exp $
#

#
# Tests are executed and compared to a set of know results.  Scripts execute
# common tests tasks as a unit. The main set of tests are executed several
# times with different sets of parameters.  Each execution is refered to
# as a `test group'.  The results output is normally expected to be
# the same between test groups, however the different parsers can produce
# different results, so expected results are kept for each parser.
#
# Different test group are executed by recursively calling this makefile.
# The make parameters that define a test group are:
# 
#  PARSER - `tidy', or `swing' - The name of the parser..
#  RECOMP - `recomp' or `comp'. Compile with or without the -for-recomp
#            option.  As many tests as possible are run with the -for-recomp
#            option, since it has to save and process options.
#  STANDALONE - `sa' or `eh' - Run standalone jar or with enhydra jar.  This
#             file only runs the standalong tests if jar has been built.
#
# This make file recursively calls itself twice with the PARSER
# variable set to the different parsers.
#
# Set XMLC_STANDALONE=YES to test standalone distribution
#

JARNAME = tests

# Disable messages from TYA JIT on *BSD/Linux
TYA_LOGFILE=/dev/null
export TYA_LOGFILE

#
# Default parameters if not set.
#
ifeq (${RECOMP},)
    RECOMP=comp
endif
ifeq (${XMLC_STANDALONE},YES)
    STANDALONE=sa
endif
ifeq (${STANDALONE},)
    STANDALONE=eh
endif

GROUP_PKG=${PARSER}.${RECOMP}.${STANDALONE}
GROUP_DIR=${PARSER}/${RECOMP}/${STANDALONE}
TEST_PACKAGE=${PACKAGE}.${GROUP_PKG}

OUTDIR=output/${GROUP_DIR}
EXPECTDIR=expected/${PARSER}
TMP_DIR = tmp

XMLC_FLAGS = -sourceout ${TMP_DIR} -parser ${PARSER}

# Pick CLASSPATH to use in certain tests that need it explictly
# set (most tests pick it up from the test scripts).
TEST_CLASSES=${ROOT}/classes/tests
ifeq (${XMLC_STANDALONE},YES)
    XMLC_JAR="${XMLC_OUTPUT}/lib/xmlc.jar"
    TEST_CLASSPATH=${XMLC_JAR}${PS}${TEST_CLASSES}
    XMLC=${XMLC_BIN}/xmlc
else
    TEST_CLASSPATH=${TEST_CLASSES}${PS}${ENHYDRA_CLASSPATH}
endif
export XMLC_STANDALONE


#  XMLC common options.
XMLC_FLAGS = -sourceout ${TMP_DIR} -parser ${PARSER}

# Use compiler to dump
DUMPDOM = ${XMLC_CMD} -parser ${PARSER} -dump -methods -docout docout.tmp
RUNOBJECT = ../run-object
BASIC_TESTS = ./html-basic-test
GROUP_ARGS= ${PARSER} ${RECOMP} ${STANDALONE}
