/*
 * Enhydra Java Application Server 
 * The Initial Developer of the Original Code is Lutris Technologies Inc. 
 * Portions created by Lutris are Copyright (C) 1997-2000 Lutris Technologies
 * Inc. 
 * All Rights Reserved. 
 *
 * The contents of this file are subject to the Enhydra Public License Version
 * 1.0 (the "License"); you may not use this file except in compliance with the
 * License. You may obtain a copy of the License at
 * http://www.enhydra.org/software/license/epl.html 
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under the
 * License. 
 *
 * $Id: PerfRunner.java,v 1.1 2000/03/04 03:22:53 markd Exp $
 */

package org.enhydra.xml.xmlc.tests.perf;

import org.enhydra.xml.xmlc.*;
import org.enhydra.xml.xmlc.html.*;
import org.w3c.dom.*;
import org.w3c.dom.html.*;
import java.util.Date;

/**
 * Run XMLC generated objects for performance testing.
 */
public class PerfRunner {
    /**
     * Test class names
     */
    private static String BIGPAGE1_CLASS
        = "org.enhydra.xml.xmlc.tests.perf.BigPage1HTML";

    /**
     * Constants controling number of tests.
     */
    private static final int REPEAT_COUNT = 20;
    private static final int TEST_COUNT = 4;


    /**
     * Create a XMLC document object and convert it to a string a specified
     * number of times.
     */
    private void testInstantiation(Class docClass,
                                   int repeatCount) {
        XMLCFactory factory = new XMLCStdFactory(null, null);
        
        for (int cnt = 0; cnt < repeatCount; cnt++) {
            XMLObject xmlcObj = factory.create(docClass);
            String docStr = xmlcObj.toString();
        }
    }

    /**
     *  Run testInstantiation a number of times.
     */
    private void runTestInstantiation(String docClassName,
                                      int testCount,
                                      int repeatCount) 
        throws ClassNotFoundException {
        Class docClass = Class.forName(docClassName);
        long times[] = new long[testCount];
        
        for (int cnt = 0; cnt < testCount; cnt++) {
            long start = System.currentTimeMillis();

            testInstantiation(docClass, repeatCount);
            
            times[cnt] = System.currentTimeMillis() - start;
        }
        
        double aveSec = 0;
        for (int cnt = 0; cnt < testCount; cnt++) {
            double timeSec = (times[cnt]/(1000.0*testCount*repeatCount));
            System.out.println("Pass " + cnt + ": " + timeSec + " sec/iteration");
            aveSec += timeSec;
        }
        System.out.println("Ave: " + aveSec + " sec = " + 1.0/aveSec + "/sec");
    }


    public static void main(String[] args)
        throws ClassNotFoundException {
        PerfRunner tests = new PerfRunner();
        tests.runTestInstantiation(BIGPAGE1_CLASS, TEST_COUNT, REPEAT_COUNT);
    }
}
